permissionNewGoal top-level property
Implementation
Permission permissionNewGoal = Permission(
uid: 'goals-new',
name: 'New Goal',
description: 'Permission to create a new goal and send for verification',
);
Permission permissionNewGoal = Permission(
uid: 'goals-new',
name: 'New Goal',
description: 'Permission to create a new goal and send for verification',
);