Absence class
Describes the parameters that are part of a standard response
- Available extensions
Constructors
-
Absence({String? entityUuid, EmployeeMetadata? metadata, ApprovalMetadata? approvalMetadata, STANDARD_LIFECYCLE_STATUS? status, Iterable<
LogbookLogConciseSLC> ? logs, Int64? completedOn, Int64? vaultFolderId, String? referenceId, String? finalRefNumber, Int64? userId, Int64? leaveRequestId, Int64? fromTimestamp, Int64? toTimestamp, Int64? uomId, Int64? quantity, String? description, Iterable<FormFieldDatum> ? formData}) -
factory
-
Absence.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- Absence.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- approvalMetadata ↔ ApprovalMetadata
-
Stores the approval metadata
getter/setter pair
- completedOn ↔ Int64
-
The timestamp of when this absence was marked as completed
getter/setter pair
- description ↔ String
-
The description of the absence
getter/setter pair
- entityUuid ↔ String
-
Stores a globally unique entity UUID. This will be set at the organization level
getter/setter pair
- finalRefNumber ↔ String
-
The unique reference number that has been automatically generated
getter/setter pair
-
formData
→ PbList<
FormFieldDatum> -
The list of dynamic forms
no setter
- fromTimestamp ↔ Int64
-
The UNIX timestamp from when the user is absent
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - leaveRequestId ↔ Int64
-
The ID of the optional associated leave request
getter/setter pair
-
logs
→ PbList<
LogbookLogConciseSLC> -
Stores the logs of every operation performed on this absence
no setter
- metadata ↔ EmployeeMetadata
-
Stores the metadata of this absence
getter/setter pair
- quantity ↔ Int64
-
Stores the quantity of absence (in cents)
getter/setter pair
- referenceId ↔ String
-
The reference_id of the absence
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ STANDARD_LIFECYCLE_STATUS
-
The status of this absence
getter/setter pair
- toTimestamp ↔ Int64
-
The UNIX timestamp until when the user is absent
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- uomId ↔ Int64
-
Stores the unit of material ID
getter/setter pair
- userId ↔ Int64
-
The ID of the user who has been marked as absent
getter/setter pair
- vaultFolderId ↔ Int64
-
The associated vault folder ID
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearApprovalMetadata(
) → void -
clearCompletedOn(
) → void -
clearDescription(
) → void -
clearEntityUuid(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearFinalRefNumber(
) → void -
clearFromTimestamp(
) → void -
clearLeaveRequestId(
) → void -
clearMetadata(
) → void -
clearQuantity(
) → void -
clearReferenceId(
) → void -
clearStatus(
) → void -
clearToTimestamp(
) → void -
clearUomId(
) → void -
clearUserId(
) → void -
clearVaultFolderId(
) → void -
clone(
) → Absence - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(Absence)) → Absence -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → Absence - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureApprovalMetadata(
) → ApprovalMetadata -
ensureMetadata(
) → EmployeeMetadata -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasApprovalMetadata(
) → bool -
hasCompletedOn(
) → bool -
hasDescription(
) → bool -
hasEntityUuid(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasFinalRefNumber(
) → bool -
hasFromTimestamp(
) → bool -
hasLeaveRequestId(
) → bool -
hasMetadata(
) → bool -
hasQuantity(
) → bool -
hasReferenceId(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasStatus(
) → bool -
hasToTimestamp(
) → bool -
hasUomId(
) → bool -
hasUserId(
) → bool -
hasVaultFolderId(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → Absence -
getDefault(
) → Absence