sdk/absences.scailo.pbgrpc library

Classes

Absence
Describes the parameters that are part of a standard response
ABSENCE_SORT_KEY
Describes the available sort keys
AbsencesList
Describes the message consisting of the list of records
AbsencesServiceBase
AbsencesServiceClient
Describes the common methods applicable on each absence
AbsencesServiceCountReq
Describes the base request payload of a count search
AbsencesServiceCreateRequest
Describes the parameters necessary to create a record
AbsencesServiceFilterReq
Describes the base request payload of a filter search
AbsencesServicePaginationReq
Describes a pagination request to retrieve records
AbsencesServicePaginationResponse
Describes the response to a pagination request
AbsencesServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
AbsencesServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.