AbsencesServiceClient class

Describes the common methods applicable on each absence

Annotations
  • @GrpcServiceName.new('Scailo.AbsencesService')

Constructors

AbsencesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Complete
count(AbsencesServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(AbsencesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Send Email rpc SendEmail (Identifier) returns (IdentifierResponse); Create a magic link
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(AbsencesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
draft(AbsencesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(AbsencesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
filter(AbsencesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<AbsencesList>
View all that match the given filter criteria
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Repeat
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(AbsencesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(AbsencesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<AbsencesList>
View all that match the given search key
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<AbsencesList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<AbsencesList>
View all with the given entity UUID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<Absence>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Absence>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<Absence>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Absence>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<AbsencesList>
View all records with the given IDs
viewWithPagination(AbsencesServicePaginationReq request, {CallOptions? options}) → ResponseFuture<AbsencesServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.