code property

  1. @TagNumber.new(11)
String get code

@description The unique alphanumeric identifier used for system classification. This is typically a short string or mnemonic used in logic and filtering.

@example "TECH_SUP_01"

Implementation

@$pb.TagNumber(11)
$core.String get code => $_getSZ(6);
  1. @TagNumber.new(11)
set code (String value)

Implementation

@$pb.TagNumber(11)
set code($core.String value) => $_setString(6, value);