fgColor property
The color of the text that is displayed for easy recognition
Implementation
@$pb.TagNumber(12)
$core.String get fgColor => $_getSZ(7);
Implementation
@$pb.TagNumber(12)
set fgColor($core.String value) => $_setString(7, value);
The color of the text that is displayed for easy recognition
@$pb.TagNumber(12)
$core.String get fgColor => $_getSZ(7);
@$pb.TagNumber(12)
set fgColor($core.String value) => $_setString(7, value);