fgColor property
The color of the text that is displayed for easy recognition
Implementation
@$pb.TagNumber(22)
$core.String get fgColor => $_getSZ(9);
Implementation
@$pb.TagNumber(22)
set fgColor($core.String value) => $_setString(9, value);
The color of the text that is displayed for easy recognition
@$pb.TagNumber(22)
$core.String get fgColor => $_getSZ(9);
@$pb.TagNumber(22)
set fgColor($core.String value) => $_setString(9, value);