isLeaf property
Stores if this is a leaf action code or a non-leaf action code
Implementation
@$pb.TagNumber(17)
$core.bool get isLeaf => $_getBF(7);
Implementation
@$pb.TagNumber(17)
set isLeaf($core.bool value) => $_setBool(7, value);
Stores if this is a leaf action code or a non-leaf action code
@$pb.TagNumber(17)
$core.bool get isLeaf => $_getBF(7);
@$pb.TagNumber(17)
set isLeaf($core.bool value) => $_setBool(7, value);