fgColor property
The color of the text that is displayed for easy recognition
Implementation
@$pb.TagNumber(12)
$core.String get fgColor => $_getSZ(4);
Implementation
@$pb.TagNumber(12)
set fgColor($core.String value) => $_setString(4, value);
The color of the text that is displayed for easy recognition
@$pb.TagNumber(12)
$core.String get fgColor => $_getSZ(4);
@$pb.TagNumber(12)
set fgColor($core.String value) => $_setString(4, value);