ActionsCodesServiceBase class abstract

Annotations
  • @GrpcServiceName.new('Scailo.ActionsCodesService')

Constructors

ActionsCodesServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
approve(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
approve_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
commentAdd(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
commentAdd_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
count(ServiceCall call, ActionsCodesServiceCountReq request) Future<CountResponse>
count_Pre(ServiceCall $call, Future<ActionsCodesServiceCountReq> $request) Future<CountResponse>
countInStatus(ServiceCall call, CountInSLCStatusRequest request) Future<CountResponse>
countInStatus_Pre(ServiceCall $call, Future<CountInSLCStatusRequest> $request) Future<CountResponse>
create(ServiceCall call, ActionsCodesServiceCreateRequest request) Future<IdentifierResponse>
create_Pre(ServiceCall $call, Future<ActionsCodesServiceCreateRequest> $request) Future<IdentifierResponse>
discard(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
discard_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
downloadAsCSV(ServiceCall call, ActionsCodesServiceFilterReq request) Future<StandardFile>
downloadAsCSV_Pre(ServiceCall $call, Future<ActionsCodesServiceFilterReq> $request) Future<StandardFile>
draft(ServiceCall call, ActionsCodesServiceCreateRequest request) Future<IdentifierResponse>
draft_Pre(ServiceCall $call, Future<ActionsCodesServiceCreateRequest> $request) Future<IdentifierResponse>
draftUpdate(ServiceCall call, ActionsCodesServiceUpdateRequest request) Future<IdentifierResponse>
draftUpdate_Pre(ServiceCall $call, Future<ActionsCodesServiceUpdateRequest> $request) Future<IdentifierResponse>
filter(ServiceCall call, ActionsCodesServiceFilterReq request) Future<ActionsCodesList>
filter_Pre(ServiceCall $call, Future<ActionsCodesServiceFilterReq> $request) Future<ActionsCodesList>
halt(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
halt_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
importFromCSV(ServiceCall call, StandardFile request) Future<IdentifierUUIDsList>
importFromCSV_Pre(ServiceCall $call, Future<StandardFile> $request) Future<IdentifierUUIDsList>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
restore_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
revisionUpdate(ServiceCall call, ActionsCodesServiceUpdateRequest request) Future<IdentifierResponse>
revisionUpdate_Pre(ServiceCall $call, Future<ActionsCodesServiceUpdateRequest> $request) Future<IdentifierResponse>
searchAll(ServiceCall call, ActionsCodesServiceSearchAllReq request) Future<ActionsCodesList>
searchAll_Pre(ServiceCall $call, Future<ActionsCodesServiceSearchAllReq> $request) Future<ActionsCodesList>
sendForRevision(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForRevision_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
sendForVerification(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForVerification_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
toString() String
A string representation of this object.
inherited
verify(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
verify_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
viewAll(ServiceCall call, ActiveStatus request) Future<ActionsCodesList>
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request) Future<ActionsCodesList>
viewAllForEntityUUID(ServiceCall call, IdentifierUUID request) Future<ActionsCodesList>
viewAllForEntityUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ActionsCodesList>
viewByID(ServiceCall call, Identifier request) Future<ActionCode>
viewByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<ActionCode>
viewByUUID(ServiceCall call, IdentifierUUID request) Future<ActionCode>
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ActionCode>
viewEssentialByID(ServiceCall call, Identifier request) Future<ActionCode>
viewEssentialByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<ActionCode>
viewEssentialByUUID(ServiceCall call, IdentifierUUID request) Future<ActionCode>
viewEssentialByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ActionCode>
viewFromIDs(ServiceCall call, IdentifiersList request) Future<ActionsCodesList>
viewFromIDs_Pre(ServiceCall $call, Future<IdentifiersList> $request) Future<ActionsCodesList>
viewWithPagination(ServiceCall call, ActionsCodesServicePaginationReq request) Future<ActionsCodesServicePaginationResponse>
viewWithPagination_Pre(ServiceCall $call, Future<ActionsCodesServicePaginationReq> $request) Future<ActionsCodesServicePaginationResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited