logs property
Stores the logs of every operation performed on this activity
Implementation
@$pb.TagNumber(5)
$pb.PbList<LogbookLogActivityLC> get logs => $_getList(3);
Stores the logs of every operation performed on this activity
@$pb.TagNumber(5)
$pb.PbList<LogbookLogActivityLC> get logs => $_getList(3);