sdk/activities_groups.scailo.pb library

Classes

ActivitiesGroupsList
Describes the message consisting of the list of records
ActivitiesGroupsServiceCountReq
Describes the base request payload of a count search
ActivitiesGroupsServiceCreateRequest
Describes the parameters necessary to create a record
ActivitiesGroupsServiceFilterReq
Describes the base request payload of a filter search
ActivitiesGroupsServicePaginationReq
Describes a pagination request to retrieve records
ActivitiesGroupsServicePaginationResponse
Describes the response to a pagination request
ActivitiesGroupsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ActivitiesGroupsServiceUpdateRequest
Describes the parameters necessary to update a record
ACTIVITY_GROUP_SORT_KEY
Describes the available sort keys
ActivityGroup
Describes the parameters that are part of a standard response
ActivityGroupStatistics
Describes the parameters that are part of an activity group's statistics payload

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.