logs property
ActivitiesGroups the logs of every operation performed on this activity group
Implementation
@$pb.TagNumber(5)
$pb.PbList<$1.LogbookLogConciseSLC> get logs => $_getList(4);
ActivitiesGroups the logs of every operation performed on this activity group
@$pb.TagNumber(5)
$pb.PbList<$1.LogbookLogConciseSLC> get logs => $_getList(4);