sdk/announcements.scailo.pb library

Classes

Announcement
Describes the parameters that are part of a standard response
ANNOUNCEMENT_SORT_KEY
Describes the available sort keys
AnnouncementsList
Describes the message consisting of the list of records
AnnouncementsServiceCountReq
Describes the base request payload of a count search
AnnouncementsServiceCreateRequest
Describes the parameters necessary to create a record
AnnouncementsServiceFilterReq
Describes the base request payload of a filter search
AnnouncementsServicePaginationReq
Describes a pagination request to retrieve records
AnnouncementsServicePaginationResponse
Describes the response to a pagination request
AnnouncementsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
AnnouncementsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.