sdk/asset_indents.scailo.pb library

Classes

ASSET_INDENT_ITEM_SORT_KEY
Describes the available sort keys
ASSET_INDENT_ITEM_STATUS
Describes the applicable statuses of asset indent items
ASSET_INDENT_SORT_KEY
Describes the available sort keys
AssetIndent
Describes the parameters that are part of a standard response
AssetIndentIssuedStatistics
Describes the issued statistics of the asset indent
AssetIndentIssuedStatisticsList
Describes the list of issued statistics of the asset indent
AssetIndentItem
Describes the parameters that constitute an item associated to a asset indent
AssetIndentItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
AssetIndentItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective asset indent item
AssetIndentItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
AssetIndentsItemsList
Describes the message consisting of the list of asset indent items
AssetIndentsList
Describes the message consisting of the list of asset indents
AssetIndentsServiceCountReq
Describes the base request payload of a count search
AssetIndentsServiceCreateRequest
Describes the parameters necessary to create a record
AssetIndentsServiceFilterReq
Describes the base request payload of a filter search
AssetIndentsServiceItemCreateRequest
Describes the parameters required to add an item to a asset indent
AssetIndentsServiceItemUpdateRequest
Describes the parameters required to update an item in a asset indent
AssetIndentsServicePaginatedItemsResponse
Describes the response to a pagination items request
AssetIndentsServicePaginationReq
Describes a pagination request to retrieve records
AssetIndentsServicePaginationResponse
Describes the response to a pagination request
AssetIndentsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
AssetIndentsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.