sdk/associates.scailo.pbgrpc library

Classes

Associate
Describes the data structure of each associate on the platform
ASSOCIATE_ORG_REF_FROM
Describes the available options that a associate can be associated with
ASSOCIATE_SORT_KEY
Describes the available sort keys for retrieving associates
AssociatePaginationResp
Describes the data structure that responds to a pagination request
AssociatesList
Describes the data structure that stores a list of associates
AssociatesServiceBase
AssociatesServiceClient
Describes the methods applicable on each associate
AssociatesServiceCountReq
Describes the base request payload of a count search
AssociatesServiceCreateRequest
Describes the necessary data structure during creation of a associate
AssociatesServiceFilterReq
Describes the base request payload of a filter search
AssociatesServiceImportRequest
Describes the necessary data structure to import a list of associates
AssociatesServicePaginationReq
Describes a pagination request to retrieve records
AssociatesServiceSearchAllReq
Describes the request payload for performing a generic search operation on associates
AssociatesServiceUpdateRequest
Describes the data structure to perform the update (draft/revision) operation on a associate

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.