AssociatesServiceClient class

Describes the methods applicable on each associate

Annotations
  • @GrpcServiceName.new('Scailo.AssociatesService')

Constructors

AssociatesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
checkAddPermission(Empty request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Check if the user has permission to add an associate
checkModifyPermission(Empty request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Check if the user has permission to modify an associate
count(AssociatesServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
View all that match the given count criteria
create(AssociatesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<Associate>
Create a associate
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard the associate
downloadAsCSV(AssociatesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
downloadVCard(Identifier request, {CallOptions? options}) → ResponseFuture<BytesResponse>
Download Associate by ID as a vCard
filter(AssociatesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<AssociatesList>
View all that match the given filter criteria
importFromCSV(StandardFile request, {CallOptions? options}) → ResponseFuture<IdentifierUUIDsList>
Import records using a CSV file (duplicate codes will be skipped)
importFromReq(AssociatesServiceImportRequest request, {CallOptions? options}) → ResponseFuture<AssociatesList>
Import associates
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore the associate
searchAll(AssociatesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<AssociatesList>
View all associates that match the given search key
toString() String
A string representation of this object.
inherited
update(AssociatesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<Associate>
Update a associate
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<AssociatesList>
View all associates
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<AssociatesList>
View all associates with the given entity UUID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<Associate>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Associate>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<Associate>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Associate>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<AssociatesList>
View all records with the given IDs
viewWithPagination(AssociatesServicePaginationReq request, {CallOptions? options}) → ResponseFuture<AssociatePaginationResp>
View associates with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.