AttendancesServiceClient class

Describes the common methods applicable on each attendance

Annotations
  • @GrpcServiceName.new('Scailo.AttendancesService')

Constructors

AttendancesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Complete
confirmEntryImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Confirm that the entry image of the given attendance UUID belongs to the user
confirmExitImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Confirm that the exit image of the given attendance UUID belongs to the user
count(AttendancesServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
View all that match the given count criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(AttendancesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Send Email rpc SendEmail (Identifier) returns (IdentifierResponse); Create a magic link
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(AttendancesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
draft(AttendancesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(AttendancesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
employeeHasOpenAttendance(Identifier request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if a user (with the given identifier) has an open attendance (attendance with only entry and no exit)
filter(AttendancesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<AttendancesList>
View all that match the given filter criteria
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordImageEntry(AttendancesServiceImageEntryRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Store entry time
recordImageExit(AttendancesServiceImageExitRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Store exit time
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Repeat
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(AttendancesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(AttendancesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<AttendancesList>
View all that match the given search key
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<AttendancesList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<AttendancesList>
View all with the given entity UUID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<Attendance>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Attendance>
View by UUID
viewEntryGPSCoordinates(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GPSCoordinatesResponse>
View entry GPS coordinates for attendance UUID
viewEntryGPSStaticImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View entry GPS static image from Google Maps
viewEntryImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View entry image for attendance UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<Attendance>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Attendance>
View only essential components (without logs) that matches the given UUID
viewExitGPSCoordinates(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GPSCoordinatesResponse>
View exit GPS coordinates for attendance UUID
viewExitGPSStaticImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View exit GPS static image from Google Maps
viewExitImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View exit image for attendance UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<AttendancesList>
View all records with the given IDs
viewOpenAttendanceForUser(Identifier request, {CallOptions? options}) → ResponseFuture<Attendance>
View the open attendance for a user (with the given identifier), if available. Returns an empty instance if no attendance is available
viewWithPagination(AttendancesServicePaginationReq request, {CallOptions? options}) → ResponseFuture<AttendancesServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.