sdk/base.scailo.pb library

Classes

ActiveStatus
Describes the status of the records returned to a request
AMENDMENT_LOG_REF_FOR
Stores the possible values of an amendment log reference
AmendmentLog
Describes the data payload within an amendment log
AmendmentLogsList
Describes the list of amendment logs
ApprovalMetadata
Describes the approval metadata of each resource
Base64String
Describes the message that consists of a base64 string. Useful for relaying an image as a base64 string.
BOOL_FILTER
Describes the filter applicable on boolean properties (true, false, or any)
BooleanResponse
Describes the boolean response
BytesResponse
Describes a generic response that consists of bytes as payload
CloneRequest
Describes the data model to handle cloning of properties of a source record (denoted by source ID) into a target record (denoted by the target ID)
CountInSLCStatusRequest
Describes the payload for a request to determine the count of records in the given status
CountResponse
Describes the count response
DualQuantitiesResponse
Describes the dual quantity response. Primary quantity represents quantity in internal UoM and secondary quantity represents quantity in either vendor UoM or client UoM, depending on the context
EmployeeMetadata
Describes the employee metadata of each resource
Empty
Describes an empty object
FORM_FIELD_ELEMENT
Describes the available form field elements
FORM_TYPE
Describes the available form types
GPSCoordinatesResponse
Describes a generic response that represents a GPS coordinate
Identifier
Describes the standard identifier
IdentifierResponse
Describes the response that consists of the ID and the UUID of the record
IdentifiersList
Describes the list of standard identifiers, used for identifying associated items
IdentifierUUID
Describes the UUID identifier
IdentifierUUIDsList
Describes the list of UUID identifiers, used for identifying associated items
IdentifierUUIDWithFile
Describes the standard UUID identifier with a file. Useful for uploading CSV files to records identified by the identifier UUID
IdentifierUUIDWithUserComment
Describes the UUID identifier with a user comment. Useful when an operation needs to be performed, and a user comment needs to be recorded
IdentifierWithEmailAttributes
Describes the standard identifier with email attributes. Useful when a record (identified by the identifier) needs to be mailed with the given subject, and the list of email addresses.
IdentifierWithFile
Describes the standard identifier with a file. Useful for uploading CSV files to records identified by the identifier
IdentifierWithSearchKey
Describes the standard identifier with a search key. Useful when searching within sub records of a parent item (such as shift group shifts, etc)
IdentifierWithUserComment
Describes the standard identifier with a user comment. Useful when an operation needs to be performed, and a user comment needs to be recorded
IdentifierZeroable
Describes the standard identifier that can also be a zero
ImageResponse
Describes a generic response that consists of info of an image
INVENTORY_INTERACTION_CATEGORY
Stores all the possible categories of inventory interactions
INVENTORY_ISSUED_PURPOSE
Stores all the possible issued purposes
INVENTORY_LIFECYCLE
Describes the lifecycle status of each inventory
INVENTORY_SORT_KEY
Describes the available sort keys
InventoryInteraction
Stores the parameters present within an inventory interaction
InventoryInteractionsList
Describes the list of inventory interactions
InventoryPartitionRequest
Describes the parameters required to partition an inventory lot
LOGBOOK_OPERATION
Describes all the possible values within a logbook operation
LogbookLogComplete
Describes each parameter that's part of the logbook (includes historical data of the object)
LogbookLogConciseGenericCreateRequest
Describes the parameters that are required to create a generic lifecycle log entry
LogbookLogConciseSLC
Describes each parameter that's part of the logbook (does not include historical data of the object) with the operation being a standard lifecycle status
LogbookLogConciseSLCCreateRequest
Describes the parameters that are required to create a standard lifecycle log entry
LogbookLogInventoryLC
Describes each parameter that's part of the logbook (does not include historical data of the object) with the operation being a inventory lifecycle status
MonthAndDayFilter
Describes the payload that will be used to filter records on the basis of the given month and day
PriceResponse
Describes a generic response that consists of price as payload
QuantityResponse
Describes the quantity response
ReorderItemsRequest
Describes the data model to handle reordering of items
RepeatWithDeliveryDate
Describes the payload necessary for performing Repeat requests with a specific delivery date
SimpleSearchReq
Describes a simple search request
SORT_ORDER
Describes the order in which the records need to be returned
STANDARD_LIFECYCLE_STATUS
Describes the standard lifecycle status of each record
StandardFile
Describes the payload that consists of a file
StringResponse
Describes a generic response that consists of string as payload
StringsList
Describes the list of simple strings, used for underlying associated items
SumResponse
Describes the sum reponse
UpdateOwnPasswordReq
Describes the payload that is requred to update the user's own password
UpdatePasswordReq
Describes the payload that is required to update the password of a user (by an administrator)
UploadPictureReq
Describes the payload that is required to upload a picture associated to a resource (such as profile picture or signature)

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.