deleteExisting property

  1. @TagNumber.new(3)
bool get deleteExisting

Stores if the existing items in the target resource need to be deleted before cloning from the source resource

Implementation

@$pb.TagNumber(3)
$core.bool get deleteExisting => $_getBF(2);
  1. @TagNumber.new(3)
set deleteExisting (bool value)

Implementation

@$pb.TagNumber(3)
set deleteExisting($core.bool value) => $_setBool(2, value);