InventoryInteraction class

Stores the parameters present within an inventory interaction

Available extensions

Constructors

InventoryInteraction({String? entityUuid, EmployeeMetadata? metadata, INVENTORY_INTERACTION_CATEGORY? category, String? inventoryRefUuid, String? issuedInventoryHash, INVENTORY_ISSUED_PURPOSE? issuedRefPurpose, Int64? issuedRefId, Int64? internalQuantity})
factory
InventoryInteraction.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
InventoryInteraction.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

category ↔ INVENTORY_INTERACTION_CATEGORY
Stores the category
getter/setter pair
entityUuid ↔ String
@description The organization's globally unique identifier.
getter/setter pair
hashCode → int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
internalQuantity ↔ Int64
Stores the quantity of this item (in cents). Can be negative since this could also be an adjustment
getter/setter pair
inventoryRefUuid ↔ String
Stores the UUID of the inventory item
getter/setter pair
isFrozen → bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
issuedInventoryHash ↔ String
Stores the hash of the inventory item that has been issued from this parent item
getter/setter pair
issuedRefId ↔ Int64
Stores the ID of the corresponding issued_ref_purpose item, for e.g., the stock-issuance ID
getter/setter pair
issuedRefPurpose ↔ INVENTORY_ISSUED_PURPOSE
Stores the purpose for which this new item has been issued, for e.g. 'stock-issuance'
getter/setter pair
metadata ↔ EmployeeMetadata
Stores the metadata of this interaction
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCategory() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInternalQuantity() → void
clearInventoryRefUuid() → void
clearIssuedInventoryHash() → void
clearIssuedRefId() → void
clearIssuedRefPurpose() → void
clearMetadata() → void
clone() → InventoryInteraction
Creates a deep copy of the fields in this message.
copyWith(void updates(InventoryInteraction)) → InventoryInteraction
Apply updates to a copy of this message.
createEmptyInstance() → InventoryInteraction
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureMetadata() → EmployeeMetadata
extensionsAreInitialized() → bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) → int?
inherited
hasCategory() → bool
hasEntityUuid() → bool
hasExtension(Extension extension) → bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) → bool
Whether this message has a field associated with tagNumber.
inherited
hasInternalQuantity() → bool
hasInventoryRefUuid() → bool
hasIssuedInventoryHash() → bool
hasIssuedRefId() → bool
hasIssuedRefPurpose() → bool
hasMetadata() → bool
hasRequiredFields() → bool
Whether the message has required fields.
inherited
isInitialized() → bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() → String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() → String
Returns a String representation of this message.
inherited
writeToBuffer() → Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() → String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() → Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited