previousData property
The marshalled object at the time the log was created
Implementation
@$pb.TagNumber(15)
$core.List<$core.int> get previousData => $_getN(6);
The marshalled object at the time the log was created
@$pb.TagNumber(15)
$core.List<$core.int> get previousData => $_getN(6);