sdk/client_streams.scailo.pb library

Classes

CLIENT_STREAM_LIFECYCLE
Describes the lifecycle status of each client stream
CLIENT_STREAM_MESSAGE_SORT_KEY
Describes the available sort keys
CLIENT_STREAM_MESSAGE_TYPE
Describes the available message types for a client stream message
CLIENT_STREAM_REF_FROM
Describes the available client stream references
CLIENT_STREAM_SORT_KEY
Describes the available sort keys
ClientStream
Describes the parameters that are part of a standard response
ClientStreamClientSubscriber
Describes the parameters that constitute a client stream client subscriber
ClientStreamClientSubscribersList
Describes the message consisting of the list of client stream client subscribers
ClientStreamInternalSubscriber
Describes the parameters that constitute an internal subscriber
ClientStreamInternalSubscribersList
Describes the message consisting of the list of internal subscribers
ClientStreamMessage
Describes the parameters that constitute a message associated to an client stream
ClientStreamMessageReceipt
Describes the parameters that constitute a message receipt
ClientStreamMessageReceiptsList
Describes the message consisting of the list of client stream message receipts
ClientStreamMessagesList
Describes the message consisting of the list of client stream messages
ClientStreamMessagesSearchRequest
Describes the request payload to retrieve messages.
ClientStreamsList
Describes the message consisting of the list of records
ClientStreamsServiceClientSubscriberCreateRequest
Describes the parameters necessary to create a client stream client subscriber
ClientStreamsServiceCountReq
Describes the base request payload of a count search
ClientStreamsServiceCreateRequest
Describes the parameters necessary to create a record
ClientStreamsServiceFilterReq
Describes the base request payload of a filter search
ClientStreamsServiceImportInternalSubscribersRequest
Describes the data model to handle importing of internal subscribers from the given identifier representing a team or a department
ClientStreamsServiceInternalSubscriberCreateRequest
Describes the parameters necessary to create an internal subscriber
ClientStreamsServiceMessageCreateRequest
Describes the parameters required to add a message to an client stream
ClientStreamsServicePaginatedMessagesResponse
Describes the response to a pagination messages request
ClientStreamsServicePaginationReq
Describes a pagination request to retrieve records
ClientStreamsServicePaginationResponse
Describes the response to a pagination request
ClientStreamsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ClientStreamsServiceUpdateRequest
Describes the parameters necessary to update a record
LogbookLogClientStreamLC
Describes each parameter that's part of the logbook (does not include historical data of the object) with the operation being an client stream lifecycle status

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.