deleteExisting property
Stores if the existing internal subscribers in the client stream need to be deleted before adding from the source record
Implementation
@$pb.TagNumber(4)
$core.bool get deleteExisting => $_getBF(3);
Implementation
@$pb.TagNumber(4)
set deleteExisting($core.bool value) => $_setBool(3, value);