CLIENT_STREAM_REF_FROM class

Describes the available client stream references

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) CLIENT_STREAM_REF_FROM?

Constants

CLIENT_STREAM_REF_FROM_ANY_UNSPECIFIED → const CLIENT_STREAM_REF_FROM
Used only in filters
CLIENT_STREAM_REF_FROM_CREDIT_NOTE → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a credit note
CLIENT_STREAM_REF_FROM_GOODS_DISPATCH → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a goods dispatch
CLIENT_STREAM_REF_FROM_SALES_ENQUIRY → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a sales enquiry
CLIENT_STREAM_REF_FROM_SALES_INVOICE → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a sales invoice
CLIENT_STREAM_REF_FROM_SALES_ORDER → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a sales order
CLIENT_STREAM_REF_FROM_SALES_QUOTATION → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a sales quotation
CLIENT_STREAM_REF_FROM_SALES_RECEIPT → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a sales receipt
CLIENT_STREAM_REF_FROM_SALES_RETURN → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a sales return
CLIENT_STREAM_REF_FROM_WORK_ORDER → const CLIENT_STREAM_REF_FROM
Denotes that the reference is from a work order
values → const List<CLIENT_STREAM_REF_FROM>