logs property
Stores the logs of every operation performed on this component
Implementation
@$pb.TagNumber(5)
$pb.PbList<$1.LogbookLogInventoryLC> get logs => $_getList(3);
Stores the logs of every operation performed on this component
@$pb.TagNumber(5)
$pb.PbList<$1.LogbookLogInventoryLC> get logs => $_getList(3);