ComponentsServiceFilterReq class

Describes the base request payload of a filter search

Available extensions

Constructors

ComponentsServiceFilterReq({BOOL_FILTER? isActive, Int64? count, Int64? offset, SORT_ORDER? sortOrder, INVENTORY_SORT_KEY? sortKey, String? entityUuid, INVENTORY_LIFECYCLE? status, Int64? storeIntakeAtStart, Int64? storeIntakeAtEnd, Int64? discardedAtStart, Int64? discardedAtEnd, Int64? parentRefId, COMPONENT_REF_FROM? refFrom, Int64? refId, Int64? familyId, String? code, String? internalItemCode, String? hash, Int64? quantityRemainingMin, Int64? quantityRemainingMax, Int64? secondaryUomId, Int64? shelfLifeTimestampStart, Int64? shelfLifeTimestampEnd, Int64? warrantyTimestampStart, Int64? warrantyTimestampEnd, Int64? storeId, Int64? storageId, BOOL_FILTER? isQcReportPublic, Int64? locationId, Int64? vendorId, Int64? creationTimestampStart, Int64? creationTimestampEnd, Int64? modificationTimestampStart, Int64? modificationTimestampEnd, Iterable<FormFieldDatumFilterRequest>? formData})
factory
ComponentsServiceFilterReq.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
ComponentsServiceFilterReq.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

code String
The auto generated code of the component
getter/setter pair
count ↔ Int64
The number of records that need to be sent in the response. Returns all records if it is set to -1
getter/setter pair
creationTimestampEnd ↔ Int64
The maximum timestamp that needs to be considered to filter by creation
getter/setter pair
creationTimestampStart ↔ Int64
The minimum timestamp that needs to be considered to filter by creation
getter/setter pair
discardedAtEnd ↔ Int64
The end range of discarded timestamp
getter/setter pair
discardedAtStart ↔ Int64
The start range of discarded timestamp
getter/setter pair
entityUuid String
The entity UUID that is to be used to filter records
getter/setter pair
familyId ↔ Int64
Stores the ID of the associated family
getter/setter pair
formData → PbList<FormFieldDatumFilterRequest>
The list of form data filters
no setter
hash String
The computed hash of the component
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
internalItemCode String
Filter by the exact internal code
getter/setter pair
isActive BOOL_FILTER
If true, then returns only active records. If false, then returns only inactive records
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isQcReportPublic BOOL_FILTER
Stores if the associated QC report should be public
getter/setter pair
locationId ↔ Int64
Filter by the location ID
getter/setter pair
modificationTimestampEnd ↔ Int64
The maximum timestamp that needs to be considered to filter by modification
getter/setter pair
modificationTimestampStart ↔ Int64
The minimum timestamp that needs to be considered to filter by modification
getter/setter pair
offset ↔ Int64
The number that need to be offset by before fetching the records
getter/setter pair
parentRefId ↔ Int64
The ID of the parent inventory item
getter/setter pair
quantityRemainingMax ↔ Int64
The maximum remaining quantity (in cents)
getter/setter pair
quantityRemainingMin ↔ Int64
The minimum remaining quantity (in cents)
getter/setter pair
refFrom COMPONENT_REF_FROM
Stores the reference from
getter/setter pair
refId ↔ Int64
Stores the ID of the reference
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryUomId ↔ Int64
Stores an optional secondary unit of component
getter/setter pair
shelfLifeTimestampEnd ↔ Int64
The end range of shelf life timestamp
getter/setter pair
shelfLifeTimestampStart ↔ Int64
The start range of shelf life timestamp
getter/setter pair
sortKey INVENTORY_SORT_KEY
The sort key that is to be used to fetch the pagination response
getter/setter pair
sortOrder SORT_ORDER
The sort order that is to be used to fetch the pagination response
getter/setter pair
status INVENTORY_LIFECYCLE
The status of this component
getter/setter pair
storageId ↔ Int64
Stores an optional ID of the associated storage that the component is stored in
getter/setter pair
storeId ↔ Int64
Stores the store to which the component is sent to
getter/setter pair
storeIntakeAtEnd ↔ Int64
The end range of store intake timestamp
getter/setter pair
storeIntakeAtStart ↔ Int64
The start range of store intake timestamp
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
vendorId ↔ Int64
Filter by the given vendor ID
getter/setter pair
warrantyTimestampEnd ↔ Int64
The end range of the warranty timestamp
getter/setter pair
warrantyTimestampStart ↔ Int64
The start range of the warranty timestamp
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCode() → void
clearCount() → void
clearCreationTimestampEnd() → void
clearCreationTimestampStart() → void
clearDiscardedAtEnd() → void
clearDiscardedAtStart() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFamilyId() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHash() → void
clearInternalItemCode() → void
clearIsActive() → void
clearIsQcReportPublic() → void
clearLocationId() → void
clearModificationTimestampEnd() → void
clearModificationTimestampStart() → void
clearOffset() → void
clearParentRefId() → void
clearQuantityRemainingMax() → void
clearQuantityRemainingMin() → void
clearRefFrom() → void
clearRefId() → void
clearSecondaryUomId() → void
clearShelfLifeTimestampEnd() → void
clearShelfLifeTimestampStart() → void
clearSortKey() → void
clearSortOrder() → void
clearStatus() → void
clearStorageId() → void
clearStoreId() → void
clearStoreIntakeAtEnd() → void
clearStoreIntakeAtStart() → void
clearVendorId() → void
clearWarrantyTimestampEnd() → void
clearWarrantyTimestampStart() → void
clone() ComponentsServiceFilterReq
Creates a deep copy of the fields in this message.
copyWith(void updates(ComponentsServiceFilterReq)) ComponentsServiceFilterReq
Apply updates to a copy of this message.
createEmptyInstance() ComponentsServiceFilterReq
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasCode() bool
hasCount() bool
hasCreationTimestampEnd() bool
hasCreationTimestampStart() bool
hasDiscardedAtEnd() bool
hasDiscardedAtStart() bool
hasEntityUuid() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFamilyId() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasHash() bool
hasInternalItemCode() bool
hasIsActive() bool
hasIsQcReportPublic() bool
hasLocationId() bool
hasModificationTimestampEnd() bool
hasModificationTimestampStart() bool
hasOffset() bool
hasParentRefId() bool
hasQuantityRemainingMax() bool
hasQuantityRemainingMin() bool
hasRefFrom() bool
hasRefId() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSecondaryUomId() bool
hasShelfLifeTimestampEnd() bool
hasShelfLifeTimestampStart() bool
hasSortKey() bool
hasSortOrder() bool
hasStatus() bool
hasStorageId() bool
hasStoreId() bool
hasStoreIntakeAtEnd() bool
hasStoreIntakeAtStart() bool
hasVendorId() bool
hasWarrantyTimestampEnd() bool
hasWarrantyTimestampStart() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited