ComponentsServiceBase class abstract

Annotations
  • @GrpcServiceName.new('Scailo.ComponentsService')

Constructors

ComponentsServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
commentAdd(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
commentAdd_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
consume(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
consume_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
count(ServiceCall call, ComponentsServiceCountReq request) Future<CountResponse>
count_Pre(ServiceCall $call, Future<ComponentsServiceCountReq> $request) Future<CountResponse>
create(ServiceCall call, ComponentsServiceCreateRequest request) Future<IdentifierResponse>
create_Pre(ServiceCall $call, Future<ComponentsServiceCreateRequest> $request) Future<IdentifierResponse>
discard(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
discard_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
downloadAsCSV(ServiceCall call, ComponentsServiceFilterReq request) Future<StandardFile>
downloadAsCSV_Pre(ServiceCall $call, Future<ComponentsServiceFilterReq> $request) Future<StandardFile>
downloadImportTemplate(ServiceCall call, Empty request) Future<StandardFile>
downloadImportTemplate_Pre(ServiceCall $call, Future<Empty> $request) Future<StandardFile>
downloadLabelByID(ServiceCall call, Identifier request) Future<StandardFile>
downloadLabelByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<StandardFile>
downloadLabelByUUID(ServiceCall call, IdentifierUUID request) Future<StandardFile>
downloadLabelByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<StandardFile>
downloadQCReportByID(ServiceCall call, Identifier request) Future<StandardFile>
downloadQCReportByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<StandardFile>
downloadQCReportByUUID(ServiceCall call, IdentifierUUID request) Future<StandardFile>
downloadQCReportByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<StandardFile>
filter(ServiceCall call, ComponentsServiceFilterReq request) Future<ComponentsList>
filter_Pre(ServiceCall $call, Future<ComponentsServiceFilterReq> $request) Future<ComponentsList>
filterFamiliesInProductionPlan(ServiceCall call, FilterFamiliesReqForIdentifier request) Future<FamiliesList>
filterFamiliesInProductionPlan_Pre(ServiceCall $call, Future<FilterFamiliesReqForIdentifier> $request) Future<FamiliesList>
importFromCSV(ServiceCall call, StandardFile request) Future<IdentifierUUIDsList>
importFromCSV_Pre(ServiceCall $call, Future<StandardFile> $request) Future<IdentifierUUIDsList>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
partition(ServiceCall call, InventoryPartitionRequest request) Future<IdentifierResponse>
partition_Pre(ServiceCall $call, Future<InventoryPartitionRequest> $request) Future<IdentifierResponse>
reject(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
reject_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
returnMaterial(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
returnMaterial_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
scrap(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
scrap_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
searchAll(ServiceCall call, ComponentsServiceSearchAllReq request) Future<ComponentsList>
searchAll_Pre(ServiceCall $call, Future<ComponentsServiceSearchAllReq> $request) Future<ComponentsList>
sendForQC(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForQC_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
sendForRework(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForRework_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
sendToStore(ServiceCall call, ComponentsServiceSendToStoreRequest request) Future<IdentifierResponse>
sendToStore_Pre(ServiceCall $call, Future<ComponentsServiceSendToStoreRequest> $request) Future<IdentifierResponse>
splitLot(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
splitLot_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
toString() String
A string representation of this object.
inherited
update(ServiceCall call, ComponentsServiceUpdateRequest request) Future<IdentifierResponse>
update_Pre(ServiceCall $call, Future<ComponentsServiceUpdateRequest> $request) Future<IdentifierResponse>
viewAll(ServiceCall call, ActiveStatus request) Future<ComponentsList>
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request) Future<ComponentsList>
viewByID(ServiceCall call, Identifier request) Future<Component>
viewByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<Component>
viewByUUID(ServiceCall call, IdentifierUUID request) Future<Component>
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<Component>
viewEssentialByID(ServiceCall call, Identifier request) Future<Component>
viewEssentialByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<Component>
viewEssentialByUUID(ServiceCall call, IdentifierUUID request) Future<Component>
viewEssentialByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<Component>
viewFamiliesInProductionPlan(ServiceCall call, IdentifierWithSearchKey request) Future<FamiliesList>
viewFamiliesInProductionPlan_Pre(ServiceCall $call, Future<IdentifierWithSearchKey> $request) Future<FamiliesList>
viewFromIDs(ServiceCall call, IdentifiersList request) Future<ComponentsList>
viewFromIDs_Pre(ServiceCall $call, Future<IdentifiersList> $request) Future<ComponentsList>
viewFromUUIDs(ServiceCall call, IdentifierUUIDsList request) Future<ComponentsList>
viewFromUUIDs_Pre(ServiceCall $call, Future<IdentifierUUIDsList> $request) Future<ComponentsList>
viewInventoryInteractions(ServiceCall call, IdentifierUUID request) Future<InventoryInteractionsList>
viewInventoryInteractions_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<InventoryInteractionsList>
viewWithPagination(ServiceCall call, ComponentsServicePaginationReq request) Future<ComponentsServicePaginationResponse>
viewWithPagination_Pre(ServiceCall $call, Future<ComponentsServicePaginationReq> $request) Future<ComponentsServicePaginationResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited