sdk/credit_notes.scailo.pb library

Classes

CREDIT_NOTE_ITEM_SORT_KEY
Describes the available sort keys
CREDIT_NOTE_ITEM_STATUS
Describes the applicable statuses of credit note items
CREDIT_NOTE_REF_FROM
Stores all the possible references from which a credit note can be added
CREDIT_NOTE_SORT_KEY
Describes the available sort keys
CreditNote
Describes the parameters that are part of a standard response
CreditNoteAncillaryParameters
Stores the UUID references of the record
CreditNoteItem
Describes the parameters that constitute an item associated to a credit note
CreditNoteItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
CreditNoteItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective credit note item
CreditNoteItemsList
Describes the message consisting of the list of credit note items
CreditNoteItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
CreditNoteReference
Describes the parameters that constitute a credit note reference
CreditNoteReferencesList
Describes the message consisting of the list of credit note references
CreditNoteReturnStatistics
Describes the returned statistics of the credit note
CreditNoteReturnStatisticsList
Describes the list of returned statistics of the credit note
CreditNotesList
Describes the message consisting of the list of credit notes
CreditNotesServiceAlreadyAddedQuantityForSourceRequest
Describes the request payload to retrieve the quantity that has already been added for the specific ref_from, ref_id and family_id
CreditNotesServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
CreditNotesServiceCountReq
Describes the base request payload of a count search
CreditNotesServiceCreateRequest
Describes the parameters necessary to create a record
CreditNotesServiceFilterReq
Describes the base request payload of a filter search
CreditNotesServiceItemCreateRequest
Describes the parameters required to add an item to a credit note
CreditNotesServiceItemUpdateRequest
Describes the parameters required to update an item in a credit note
CreditNotesServiceMultipleItemsCreateRequest
Describes the parameters required to add multiple items to a credit note
CreditNotesServiceMultipleItemsSingleton
Describes the parameters required to add an individual item as part of multiple item addition to a credit note
CreditNotesServicePaginatedItemsResponse
Describes the response to a pagination items request
CreditNotesServicePaginationReq
Describes a pagination request to retrieve records
CreditNotesServicePaginationResponse
Describes the response to a pagination request
CreditNotesServiceReferenceCreateRequest
Describes the parameters necessary to create a credit note reference
CreditNotesServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
CreditNotesServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.