CreditNotesServiceCountReq class

Describes the base request payload of a count search

Available extensions

Constructors

CreditNotesServiceCountReq({BOOL_FILTER? isActive, String? entityUuid, STANDARD_LIFECYCLE_STATUS? status, Int64? approvedOnStart, Int64? approvedOnEnd, Int64? approvedByUserId, Int64? approverRoleId, Int64? completedOnStart, Int64? completedOnEnd, String? referenceId, String? finalRefNumber, CREDIT_NOTE_REF_FROM? refFrom, Int64? refId, Int64? currencyId, Int64? bankAccountId, Int64? familyId, Int64? consigneeClientId, Int64? buyerClientId, Int64? projectId, Int64? totalValueMin, Int64? totalValueMax, Int64? creationTimestampStart, Int64? creationTimestampEnd, Int64? modificationTimestampStart, Int64? modificationTimestampEnd, Iterable<FormFieldDatumFilterRequest>? formData})
factory
CreditNotesServiceCountReq.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
CreditNotesServiceCountReq.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

approvedByUserId ↔ Int64
@optional
getter/setter pair
approvedOnEnd ↔ Int64
@optional
getter/setter pair
approvedOnStart ↔ Int64
@optional
getter/setter pair
approverRoleId ↔ Int64
@optional
getter/setter pair
bankAccountId ↔ Int64
The associated ID of the bank account
getter/setter pair
buyerClientId ↔ Int64
The associated buyer client ID of the linked sales order
getter/setter pair
completedOnEnd ↔ Int64
@optional
getter/setter pair
completedOnStart ↔ Int64
@optional
getter/setter pair
consigneeClientId ↔ Int64
Sales Order related filters The associated consignee client ID of the linked sales order
getter/setter pair
creationTimestampEnd ↔ Int64
@optional
getter/setter pair
creationTimestampStart ↔ Int64
@optional
getter/setter pair
currencyId ↔ Int64
The ID of the associated currency
getter/setter pair
entityUuid String
@optional
getter/setter pair
familyId ↔ Int64
The ID of the family
getter/setter pair
finalRefNumber String
@optional
getter/setter pair
formData → PbList<FormFieldDatumFilterRequest>
@optional
no setter
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isActive BOOL_FILTER
@optional
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
modificationTimestampEnd ↔ Int64
@optional
getter/setter pair
modificationTimestampStart ↔ Int64
@optional
getter/setter pair
projectId ↔ Int64
The ID of the associated project of the linked sales order
getter/setter pair
referenceId String
@optional
getter/setter pair
refFrom CREDIT_NOTE_REF_FROM
The associated reference
getter/setter pair
refId ↔ Int64
The associated ID of the reference
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status STANDARD_LIFECYCLE_STATUS
@optional
getter/setter pair
totalValueMax ↔ Int64
Stores the maximum value of the credit note (ignored if 0)
getter/setter pair
totalValueMin ↔ Int64
Stores the minimum value of the credit note (ignored if 0)
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearApprovedByUserId() → void
clearApprovedOnEnd() → void
clearApprovedOnStart() → void
clearApproverRoleId() → void
clearBankAccountId() → void
clearBuyerClientId() → void
clearCompletedOnEnd() → void
clearCompletedOnStart() → void
clearConsigneeClientId() → void
clearCreationTimestampEnd() → void
clearCreationTimestampStart() → void
clearCurrencyId() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFamilyId() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFinalRefNumber() → void
clearIsActive() → void
clearModificationTimestampEnd() → void
clearModificationTimestampStart() → void
clearProjectId() → void
clearReferenceId() → void
clearRefFrom() → void
clearRefId() → void
clearStatus() → void
clearTotalValueMax() → void
clearTotalValueMin() → void
clone() CreditNotesServiceCountReq
Creates a deep copy of the fields in this message.
copyWith(void updates(CreditNotesServiceCountReq)) CreditNotesServiceCountReq
Apply updates to a copy of this message.
createEmptyInstance() CreditNotesServiceCountReq
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasApprovedByUserId() bool
hasApprovedOnEnd() bool
hasApprovedOnStart() bool
hasApproverRoleId() bool
hasBankAccountId() bool
hasBuyerClientId() bool
hasCompletedOnEnd() bool
hasCompletedOnStart() bool
hasConsigneeClientId() bool
hasCreationTimestampEnd() bool
hasCreationTimestampStart() bool
hasCurrencyId() bool
hasEntityUuid() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFamilyId() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFinalRefNumber() bool
hasIsActive() bool
hasModificationTimestampEnd() bool
hasModificationTimestampStart() bool
hasProjectId() bool
hasReferenceId() bool
hasRefFrom() bool
hasRefId() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasStatus() bool
hasTotalValueMax() bool
hasTotalValueMin() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited