CreditNotesServiceItemUpdateRequest class

Describes the parameters required to update an item in a credit note

Available extensions

Constructors

CreditNotesServiceItemUpdateRequest({String? userComment, Int64? id, Int64? internalQuantity, Int64? clientUomId, Int64? clientQuantity, String? clientFamilyCode, Int64? unitPrice, Int64? taxGroupId, Int64? roundOff, String? specifications})
factory
CreditNotesServiceItemUpdateRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
CreditNotesServiceItemUpdateRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

clientFamilyCode String
The family code as represented by the client
getter/setter pair
clientQuantity ↔ Int64
Stores the quantity (in cents) being admitted in client's unit of material
getter/setter pair
clientUomId ↔ Int64
Stores the ID of the client's unit of material
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
id ↔ Int64
The ID of the record
getter/setter pair
info_ → BuilderInfo
no setter
internalQuantity ↔ Int64
The quantity (in cents) being supplied in internal unit of material
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
roundOff ↔ Int64
The applicable round off amount (optional, and can be positive or negative)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specifications String
Optional specifications
getter/setter pair
taxGroupId ↔ Int64
The ID of the associated tax group
getter/setter pair
unitPrice ↔ Int64
The unit price of the item (as supplied to the client)
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
userComment String
Stores any comment that the user might add during this operation
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearClientFamilyCode() → void
clearClientQuantity() → void
clearClientUomId() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearId() → void
clearInternalQuantity() → void
clearRoundOff() → void
clearSpecifications() → void
clearTaxGroupId() → void
clearUnitPrice() → void
clearUserComment() → void
clone() CreditNotesServiceItemUpdateRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(CreditNotesServiceItemUpdateRequest)) CreditNotesServiceItemUpdateRequest
Apply updates to a copy of this message.
createEmptyInstance() CreditNotesServiceItemUpdateRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasClientFamilyCode() bool
hasClientQuantity() bool
hasClientUomId() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasId() bool
hasInternalQuantity() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRoundOff() bool
hasSpecifications() bool
hasTaxGroupId() bool
hasUnitPrice() bool
hasUserComment() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited