DEBIT_NOTE_REF_FROM class

Stores all the possible references from which a debit note can be added

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) DEBIT_NOTE_REF_FROM?

Constants

DEBIT_NOTE_REF_FROM_ANY_UNSPECIFIED → const DEBIT_NOTE_REF_FROM
Used only in filters
DEBIT_NOTE_REF_FROM_PURCHASE_ORDER → const DEBIT_NOTE_REF_FROM
Denotes that the debit note originated from a purchase order
values → const List<DEBIT_NOTE_REF_FROM>