sdk/debit_notes.scailo.pbgrpc library

Classes

DEBIT_NOTE_ITEM_SORT_KEY
Describes the available sort keys
DEBIT_NOTE_ITEM_STATUS
Describes the applicable statuses of debit note items
DEBIT_NOTE_REF_FROM
Stores all the possible references from which a debit note can be added
DEBIT_NOTE_SORT_KEY
Describes the available sort keys
DebitNote
Describes the parameters that are part of a standard response
DebitNoteAncillaryParameters
Stores the UUID references of the record
DebitNoteItem
Describes the parameters that constitute an item associated to a debit note
DebitNoteItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
DebitNoteItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective debit note item
DebitNoteItemsList
Describes the message consisting of the list of debit note items
DebitNoteItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
DebitNoteReference
Describes the parameters that constitute a debit note reference
DebitNoteReferencesList
Describes the message consisting of the list of debit note references
DebitNoteReturnStatistics
Describes the returned statistics of the debit note
DebitNoteReturnStatisticsList
Describes the list of returned statistics of the debit note
DebitNotesList
Describes the message consisting of the list of debit notes
DebitNotesServiceAlreadyAddedQuantityForSourceRequest
Describes the request payload to retrieve the quantity that has already been added for the specific ref_from, ref_id and family_id
DebitNotesServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
DebitNotesServiceBase
DebitNotesServiceClient
Describes the common methods applicable on each debit note
DebitNotesServiceCountReq
Describes the base request payload of a count search
DebitNotesServiceCreateRequest
Describes the parameters necessary to create a record
DebitNotesServiceFilterReq
Describes the base request payload of a filter search
DebitNotesServiceItemCreateRequest
Describes the parameters required to add an item to a debit note
DebitNotesServiceItemUpdateRequest
Describes the parameters required to update an item in a debit note
DebitNotesServiceMultipleItemsCreateRequest
Describes the parameters required to add multiple items to a debit note
DebitNotesServiceMultipleItemsSingleton
Describes the parameters required to add an individual item as part of multiple item addition to a debit note
DebitNotesServicePaginatedItemsResponse
Describes the response to a pagination items request
DebitNotesServicePaginationReq
Describes a pagination request to retrieve records
DebitNotesServicePaginationResponse
Describes the response to a pagination request
DebitNotesServiceReferenceCreateRequest
Describes the parameters necessary to create a debit note reference
DebitNotesServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
DebitNotesServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.