DebitNotesServiceBase class abstract

Annotations
  • @GrpcServiceName.new('Scailo.DebitNotesService')

Constructors

DebitNotesServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
accruedValue(ServiceCall call, DebitNotesServiceCountReq request) Future<SumResponse>
accruedValue_Pre(ServiceCall $call, Future<DebitNotesServiceCountReq> $request) Future<SumResponse>
addDebitNoteItem(ServiceCall call, DebitNotesServiceItemCreateRequest request) Future<IdentifierResponse>
addDebitNoteItem_Pre(ServiceCall $call, Future<DebitNotesServiceItemCreateRequest> $request) Future<IdentifierResponse>
addDebitNoteReference(ServiceCall call, DebitNotesServiceReferenceCreateRequest request) Future<IdentifierResponse>
addDebitNoteReference_Pre(ServiceCall $call, Future<DebitNotesServiceReferenceCreateRequest> $request) Future<IdentifierResponse>
addMultipleDebitNoteItems(ServiceCall call, DebitNotesServiceMultipleItemsCreateRequest request) Future<IdentifierResponse>
addMultipleDebitNoteItems_Pre(ServiceCall $call, Future<DebitNotesServiceMultipleItemsCreateRequest> $request) Future<IdentifierResponse>
approve(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
approve_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
approveDebitNoteItem(ServiceCall call, IdentifierWithUserComment request) Future<IdentifierResponse>
approveDebitNoteItem_Pre(ServiceCall $call, Future<IdentifierWithUserComment> $request) Future<IdentifierResponse>
approveDebitNoteReference(ServiceCall call, IdentifierWithUserComment request) Future<IdentifierResponse>
approveDebitNoteReference_Pre(ServiceCall $call, Future<IdentifierWithUserComment> $request) Future<IdentifierResponse>
autofill(ServiceCall call, DebitNotesServiceAutofillRequest request) Future<IdentifierResponse>
autofill_Pre(ServiceCall $call, Future<DebitNotesServiceAutofillRequest> $request) Future<IdentifierResponse>
commentAdd(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
commentAdd_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
complete(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
complete_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
count(ServiceCall call, DebitNotesServiceCountReq request) Future<CountResponse>
count_Pre(ServiceCall $call, Future<DebitNotesServiceCountReq> $request) Future<CountResponse>
countInStatus(ServiceCall call, CountInSLCStatusRequest request) Future<CountResponse>
countInStatus_Pre(ServiceCall $call, Future<CountInSLCStatusRequest> $request) Future<CountResponse>
create(ServiceCall call, DebitNotesServiceCreateRequest request) Future<IdentifierResponse>
create_Pre(ServiceCall $call, Future<DebitNotesServiceCreateRequest> $request) Future<IdentifierResponse>
deleteDebitNoteItem(ServiceCall call, IdentifierWithUserComment request) Future<IdentifierResponse>
deleteDebitNoteItem_Pre(ServiceCall $call, Future<IdentifierWithUserComment> $request) Future<IdentifierResponse>
deleteDebitNoteReference(ServiceCall call, IdentifierWithUserComment request) Future<IdentifierResponse>
deleteDebitNoteReference_Pre(ServiceCall $call, Future<IdentifierWithUserComment> $request) Future<IdentifierResponse>
discard(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
discard_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
downloadAsCSV(ServiceCall call, DebitNotesServiceFilterReq request) Future<StandardFile>
downloadAsCSV_Pre(ServiceCall $call, Future<DebitNotesServiceFilterReq> $request) Future<StandardFile>
downloadByUUID(ServiceCall call, IdentifierUUID request) Future<StandardFile>
downloadByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<StandardFile>
downloadItemsAsCSV(ServiceCall call, IdentifierUUID request) Future<StandardFile>
downloadItemsAsCSV_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<StandardFile>
downloadItemsTemplateAsCSV(ServiceCall call, Empty request) Future<StandardFile>
downloadItemsTemplateAsCSV_Pre(ServiceCall $call, Future<Empty> $request) Future<StandardFile>
draft(ServiceCall call, DebitNotesServiceCreateRequest request) Future<IdentifierResponse>
draft_Pre(ServiceCall $call, Future<DebitNotesServiceCreateRequest> $request) Future<IdentifierResponse>
draftUpdate(ServiceCall call, DebitNotesServiceUpdateRequest request) Future<IdentifierResponse>
draftUpdate_Pre(ServiceCall $call, Future<DebitNotesServiceUpdateRequest> $request) Future<IdentifierResponse>
filter(ServiceCall call, DebitNotesServiceFilterReq request) Future<DebitNotesList>
filter_Pre(ServiceCall $call, Future<DebitNotesServiceFilterReq> $request) Future<DebitNotesList>
filterProspectiveFamilies(ServiceCall call, FilterFamiliesReqForIdentifier request) Future<FamiliesList>
filterProspectiveFamilies_Pre(ServiceCall $call, Future<FilterFamiliesReqForIdentifier> $request) Future<FamiliesList>
halt(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
halt_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
isDownloadable(ServiceCall call, IdentifierUUID request) Future<BooleanResponse>
isDownloadable_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<BooleanResponse>
modifyDebitNoteItem(ServiceCall call, DebitNotesServiceItemUpdateRequest request) Future<IdentifierResponse>
modifyDebitNoteItem_Pre(ServiceCall $call, Future<DebitNotesServiceItemUpdateRequest> $request) Future<IdentifierResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
reopen_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
reorderDebitNoteItems(ServiceCall call, ReorderItemsRequest request) Future<IdentifierResponse>
reorderDebitNoteItems_Pre(ServiceCall $call, Future<ReorderItemsRequest> $request) Future<IdentifierResponse>
repeat(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
repeat_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
restore(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
restore_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
revisionUpdate(ServiceCall call, DebitNotesServiceUpdateRequest request) Future<IdentifierResponse>
revisionUpdate_Pre(ServiceCall $call, Future<DebitNotesServiceUpdateRequest> $request) Future<IdentifierResponse>
searchAll(ServiceCall call, DebitNotesServiceSearchAllReq request) Future<DebitNotesList>
searchAll_Pre(ServiceCall $call, Future<DebitNotesServiceSearchAllReq> $request) Future<DebitNotesList>
searchItemsWithPagination(ServiceCall call, DebitNoteItemsSearchRequest request) Future<DebitNotesServicePaginatedItemsResponse>
searchItemsWithPagination_Pre(ServiceCall $call, Future<DebitNoteItemsSearchRequest> $request) Future<DebitNotesServicePaginatedItemsResponse>
sendEmail(ServiceCall call, IdentifierWithEmailAttributes request) Future<IdentifierResponse>
sendEmail_Pre(ServiceCall $call, Future<IdentifierWithEmailAttributes> $request) Future<IdentifierResponse>
sendForRevision(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForRevision_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
sendForVerification(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForVerification_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
toString() String
A string representation of this object.
inherited
uploadDebitNoteItems(ServiceCall call, IdentifierUUIDWithFile request) Future<IdentifiersList>
uploadDebitNoteItems_Pre(ServiceCall $call, Future<IdentifierUUIDWithFile> $request) Future<IdentifiersList>
verify(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
verify_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
viewAddedFamilyQuantityForSource(ServiceCall call, DebitNotesServiceAlreadyAddedQuantityForSourceRequest request) Future<DualQuantitiesResponse>
viewAddedFamilyQuantityForSource_Pre(ServiceCall $call, Future<DebitNotesServiceAlreadyAddedQuantityForSourceRequest> $request) Future<DualQuantitiesResponse>
viewAll(ServiceCall call, ActiveStatus request) Future<DebitNotesList>
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request) Future<DebitNotesList>
viewAllForEntityUUID(ServiceCall call, IdentifierUUID request) Future<DebitNotesList>
viewAllForEntityUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<DebitNotesList>
viewAncillaryParametersByUUID(ServiceCall call, IdentifierUUID request) Future<DebitNoteAncillaryParameters>
viewAncillaryParametersByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<DebitNoteAncillaryParameters>
viewApprovedDebitNoteItems(ServiceCall call, IdentifierWithSearchKey request) Future<DebitNoteItemsList>
viewApprovedDebitNoteItems_Pre(ServiceCall $call, Future<IdentifierWithSearchKey> $request) Future<DebitNoteItemsList>
viewByID(ServiceCall call, Identifier request) Future<DebitNote>
viewByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<DebitNote>
viewByReferenceID(ServiceCall call, SimpleSearchReq request) Future<DebitNote>
viewByReferenceID_Pre(ServiceCall $call, Future<SimpleSearchReq> $request) Future<DebitNote>
viewByUUID(ServiceCall call, IdentifierUUID request) Future<DebitNote>
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<DebitNote>
viewDebitNoteItemByID(ServiceCall call, Identifier request) Future<DebitNoteItem>
viewDebitNoteItemByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<DebitNoteItem>
viewDebitNoteItemHistory(ServiceCall call, DebitNoteItemHistoryRequest request) Future<DebitNoteItemsList>
viewDebitNoteItemHistory_Pre(ServiceCall $call, Future<DebitNoteItemHistoryRequest> $request) Future<DebitNoteItemsList>
viewDebitNoteReferenceByID(ServiceCall call, Identifier request) Future<DebitNoteReference>
viewDebitNoteReferenceByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<DebitNoteReference>
viewDebitNoteReferences(ServiceCall call, Identifier request) Future<DebitNoteReferencesList>
viewDebitNoteReferences_Pre(ServiceCall $call, Future<Identifier> $request) Future<DebitNoteReferencesList>
viewEssentialByID(ServiceCall call, Identifier request) Future<DebitNote>
viewEssentialByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<DebitNote>
viewEssentialByUUID(ServiceCall call, IdentifierUUID request) Future<DebitNote>
viewEssentialByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<DebitNote>
viewFromIDs(ServiceCall call, IdentifiersList request) Future<DebitNotesList>
viewFromIDs_Pre(ServiceCall $call, Future<IdentifiersList> $request) Future<DebitNotesList>
viewPaginatedApprovedDebitNoteItems(ServiceCall call, DebitNoteItemsSearchRequest request) Future<DebitNotesServicePaginatedItemsResponse>
viewPaginatedApprovedDebitNoteItems_Pre(ServiceCall $call, Future<DebitNoteItemsSearchRequest> $request) Future<DebitNotesServicePaginatedItemsResponse>
viewPaginatedUnapprovedDebitNoteItems(ServiceCall call, DebitNoteItemsSearchRequest request) Future<DebitNotesServicePaginatedItemsResponse>
viewPaginatedUnapprovedDebitNoteItems_Pre(ServiceCall $call, Future<DebitNoteItemsSearchRequest> $request) Future<DebitNotesServicePaginatedItemsResponse>
viewProspectiveDebitNoteItem(ServiceCall call, DebitNoteItemProspectiveInfoRequest request) Future<DebitNotesServiceItemCreateRequest>
viewProspectiveDebitNoteItem_Pre(ServiceCall $call, Future<DebitNoteItemProspectiveInfoRequest> $request) Future<DebitNotesServiceItemCreateRequest>
viewProspectiveFamilies(ServiceCall call, IdentifierWithSearchKey request) Future<FamiliesList>
viewProspectiveFamilies_Pre(ServiceCall $call, Future<IdentifierWithSearchKey> $request) Future<FamiliesList>
viewReturnedStatistics(ServiceCall call, IdentifierUUID request) Future<DebitNoteReturnStatisticsList>
viewReturnedStatistics_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<DebitNoteReturnStatisticsList>
viewUnapprovedDebitNoteItems(ServiceCall call, IdentifierWithSearchKey request) Future<DebitNoteItemsList>
viewUnapprovedDebitNoteItems_Pre(ServiceCall $call, Future<IdentifierWithSearchKey> $request) Future<DebitNoteItemsList>
viewWithPagination(ServiceCall call, DebitNotesServicePaginationReq request) Future<DebitNotesServicePaginationResponse>
viewWithPagination_Pre(ServiceCall $call, Future<DebitNotesServicePaginationReq> $request) Future<DebitNotesServicePaginationResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited