downloadAsCSV method

ResponseFuture<StandardFile> downloadAsCSV(
  1. DebitNotesServiceFilterReq request, {
  2. CallOptions? options,
})

CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records

Implementation

$grpc.ResponseFuture<$1.StandardFile> downloadAsCSV(
  $0.DebitNotesServiceFilterReq request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$downloadAsCSV, request, options: options);
}