repeat method

ResponseFuture<IdentifierResponse> repeat(
  1. IdentifierUUIDWithUserComment request, {
  2. CallOptions? options,
})

Creates a new record based on an existing one (cloning).

This is useful for repeating records or correcting finalized records by starting fresh.

Implementation

$grpc.ResponseFuture<$1.IdentifierResponse> repeat(
  $1.IdentifierUUIDWithUserComment request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$repeat, request, options: options);
}