sendForVerification method
ResponseFuture<IdentifierResponse>
sendForVerification(
- IdentifierUUIDWithUserComment request, {
- CallOptions? options,
Submits a record in DRAFT or REVISION status for verification.
This triggers the first stage of the approval workflow.
Status Transition: -> PREVERIFY
Side Effects:
- Notifies designated verifiers or approvers.
- Locks certain fields from being updated without returning to
REVISION.
Implementation
$grpc.ResponseFuture<$1.IdentifierResponse> sendForVerification(
$1.IdentifierUUIDWithUserComment request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$sendForVerification, request, options: options);
}