EquationsReplaceablesServiceClient class
Describes the common methods applicable on each equation replaceable
- Annotations
-
- @GrpcServiceName.new('Scailo.EquationsReplaceablesService')
Constructors
-
EquationsReplaceablesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addEquationReplaceableItem(
EquationsReplaceablesServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an item to a equation replaceable
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approveEquationReplaceableItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve an item in a equation replaceable
-
clone(
CloneRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Clone equation from an existing equation (denoted by the identifier)
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
EquationsReplaceablesServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - View all that match the given count criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
EquationsReplaceablesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
createMagicLink(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Send Email rpc SendEmail (IdentifierWithEmailAttributes) returns (IdentifierResponse); Create a magic link
-
deleteEquationReplaceableItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an item in a equation replaceable
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
EquationsReplaceablesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download equation with the given IdentifierUUID
-
downloadItemsAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
-
downloadItemsTemplateAsCSV(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload items
-
downloadTreeAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV file with the entire dependency tree. Useful for identifying quantities necessary from all the dependencies.
-
draft(
EquationsReplaceablesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
EquationsReplaceablesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
EquationsReplaceablesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesList> - View all that match the given filter criteria
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
importFromCSV(
StandardFile request, {CallOptions? options}) → ResponseFuture< IdentifierUUIDsList> - Import records using a CSV file (duplicate codes will be skipped)
-
isDownloadable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the record is downloadable (checks if the custom download function has been implemented)
-
modifyEquationReplaceableItem(
EquationsReplaceablesServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an item in a equation replaceable
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderEquationReplaceableItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder items in a equation replaceable
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
EquationsReplaceablesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
EquationsReplaceablesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesList> - View all that match the given search key
-
searchItemsWithPagination(
EquationReplaceableItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesServicePaginatedItemsResponse> - Search through equation replaceable items with pagination
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadEquationReplaceableItems(
IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture< IdentifiersList> - Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesList> - View all with the given entity UUID
-
viewApprovedEquationReplaceableItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesItemsList> - View approved equation replaceable items for given equation replaceable ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< EquationReplaceable> - View by ID
-
viewByName(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< EquationReplaceable> - View by Name (returns the latest record in case of duplicates)
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< EquationReplaceable> - View by UUID
-
viewEquationReplaceableItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< EquationReplaceableItem> - View Equation Replaceable Item by ID
-
viewEquationReplaceableItemHistory(
EquationReplaceableItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesItemsList> - View the history of the equation replaceable item
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< EquationReplaceable> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< EquationReplaceable> - View only essential components (without logs) that matches the given UUID
-
viewForFamilyID(
Identifier request, {CallOptions? options}) → ResponseFuture< EquationReplaceable> - View the latest equation for a family (denoted by the given identifier)
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesList> - View all records with the given IDs
-
viewPaginatedApprovedEquationReplaceableItems(
EquationReplaceableItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesServicePaginatedItemsResponse> - View approved equation replaceable items for given equation replaceable ID with pagination
-
viewPaginatedUnapprovedEquationReplaceableItems(
EquationReplaceableItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesServicePaginatedItemsResponse> - View unapproved equation replaceable items for given equation replaceable ID with pagination
-
viewUnapprovedEquationReplaceableItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesItemsList> - View unapproved equation replaceable items for given equation replaceable ID
-
viewWithPagination(
EquationsReplaceablesServicePaginationReq request, {CallOptions? options}) → ResponseFuture< EquationsReplaceablesServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.