sdk/equations_work_orders.scailo.pb library

Classes

EQUATION_WORK_ORDER_ITEM_SORT_KEY
Describes the available sort keys
EQUATION_WORK_ORDER_ITEM_STATUS
Describes the applicable statuses of equation work order items
EQUATION_WORK_ORDER_SORT_KEY
Describes the available sort keys
EquationsWorkOrdersItemsList
Describes the message consisting of the list of equation work order items
EquationsWorkOrdersList
Describes the message consisting of the list of equations work orders
EquationsWorkOrdersServiceCountReq
Describes the base request payload of a count search
EquationsWorkOrdersServiceCreateRequest
Describes the parameters necessary to create a record
EquationsWorkOrdersServiceFilterReq
Describes the base request payload of a filter search
EquationsWorkOrdersServiceItemCreateRequest
Describes the parameters required to add an item to a equation work order
EquationsWorkOrdersServiceItemUpdateRequest
Describes the parameters required to update an item in a equation work order
EquationsWorkOrdersServicePaginatedItemsResponse
Describes the response to a pagination items request
EquationsWorkOrdersServicePaginationReq
Describes a pagination request to retrieve records
EquationsWorkOrdersServicePaginationResponse
Describes the response to a pagination request
EquationsWorkOrdersServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
EquationsWorkOrdersServiceUpdateRequest
Describes the parameters necessary to update a record
EquationWorkOrder
Describes the parameters that are part of a standard response
EquationWorkOrderItem
Describes the parameters that constitute an item associated to a equation work order
EquationWorkOrderItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
EquationWorkOrderItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.