sdk/equipments.scailo.pb library

Classes

Equipment
Describes the parameters that are part of a standard response
EQUIPMENT_REF_FROM
Stores all the possible references from which a equipment can be added
EquipmentsList
Describes the message consisting of the list of records
EquipmentsServiceCountReq
Describes the base request payload of a count search
EquipmentsServiceCreateRequest
Describes the parameters necessary to create a record
EquipmentsServiceFilterReq
Describes the base request payload of a filter search
EquipmentsServicePaginationReq
Describes a pagination request to retrieve records
EquipmentsServicePaginationResponse
Describes the response to a pagination request
EquipmentsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
EquipmentsServiceSendToStoreRequest
Describes the parameters necessary to send a equipment to store
EquipmentsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.