sdk/expenses.scailo.pb library

Classes

Expense
Describes the parameters that are part of a standard response
EXPENSE_ITEM_SORT_KEY
Describes the available sort keys
EXPENSE_ITEM_STATUS
Describes the applicable statuses of expense items
EXPENSE_SORT_KEY
Describes the available sort keys
ExpenseItem
Describes the parameters that constitute an item associated to a expense
ExpenseItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
ExpenseItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
ExpensesItemsList
Describes the message consisting of the list of expense items
ExpensesList
Describes the message consisting of the list of expenses
ExpensesServiceCountReq
Describes the base request payload of a count search
ExpensesServiceCreateRequest
Describes the parameters necessary to create a record
ExpensesServiceFilterReq
Describes the base request payload of a filter search
ExpensesServiceItemCreateRequest
Describes the parameters required to add an item to a expense
ExpensesServiceItemUpdateRequest
Describes the parameters required to update an item in a expense
ExpensesServicePaginatedItemsResponse
Describes the response to a pagination items request
ExpensesServicePaginationReq
Describes a pagination request to retrieve records
ExpensesServicePaginationResponse
Describes the response to a pagination request
ExpensesServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ExpensesServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.