ExpensesServiceClient class

Describes the common methods applicable on each expense

Annotations
  • @GrpcServiceName.new('Scailo.ExpensesService')

Constructors

ExpensesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addExpenseItem(ExpensesServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an item to a expense
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
approveExpenseItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve an item in a expense
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Complete
count(ExpensesServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
View all that match the given count criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(ExpensesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Create a magic link
deleteExpenseItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an item in a expense
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(ExpensesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
downloadByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download expense with the given IdentifierUUID (can be used to allow public downloads)
downloadItemsAsCSV(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
downloadItemsTemplateAsCSV(Empty request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the CSV template that could be used to upload items
draft(ExpensesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(ExpensesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
filter(ExpensesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<ExpensesList>
View all that match the given filter criteria
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
isDownloadable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the record is downloadable (checks if the custom download function has been implemented)
modifyExpenseItem(ExpensesServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Modify an item in a expense
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reopen
reorderExpenseItems(ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reorder items in a expense
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Repeat
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(ExpensesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(ExpensesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<ExpensesList>
View all that match the given search key
searchItemsWithPagination(ExpenseItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<ExpensesServicePaginatedItemsResponse>
Search through expense items with pagination
sendEmail(IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send Email
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
uploadExpenseItems(IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture<IdentifiersList>
Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<ExpensesList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ExpensesList>
View all with the given entity UUID
viewApprovedExpenseItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<ExpensesItemsList>
View approved expense items for given expense ID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<Expense>
View by ID
viewByReferenceID(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<Expense>
View by Reference ID (returns the latest record in case of duplicates)
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Expense>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<Expense>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Expense>
View only essential components (without logs) that matches the given UUID
viewExpenseItemByID(Identifier request, {CallOptions? options}) → ResponseFuture<ExpenseItem>
View Expense Item by ID
viewExpenseItemHistory(ExpenseItemHistoryRequest request, {CallOptions? options}) → ResponseFuture<ExpensesItemsList>
View the history of the expense item
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<ExpensesList>
View all records with the given IDs
viewPaginatedApprovedExpenseItems(ExpenseItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<ExpensesServicePaginatedItemsResponse>
View approved expense items for given expense ID with pagination
viewPaginatedUnapprovedExpenseItems(ExpenseItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<ExpensesServicePaginatedItemsResponse>
View unapproved expense items for given expense ID with pagination
viewUnapprovedExpenseItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<ExpensesItemsList>
View unapproved expense items for given expense ID
viewWithPagination(ExpensesServicePaginationReq request, {CallOptions? options}) → ResponseFuture<ExpensesServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.