sdk/feedstocks.scailo.pb library

Classes

Feedstock
Describes the parameters that are part of a standard response
FEEDSTOCK_REF_FROM
Stores all the possible references from which a feedstock can be added
FeedstocksList
Describes the message consisting of the list of records
FeedstocksServiceCountReq
Describes the base request payload of a count search
FeedstocksServiceCreateRequest
Describes the parameters necessary to create a record
FeedstocksServiceFilterReq
Describes the base request payload of a filter search
FeedstocksServicePaginationReq
Describes a pagination request to retrieve records
FeedstocksServicePaginationResponse
Describes the response to a pagination request
FeedstocksServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
FeedstocksServiceSendToStoreRequest
Describes the parameters necessary to send a feedstock to store
FeedstocksServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.