offset property
- @TagNumber.new(2)
The number that has been offset before fetching the records. This is the same value that has been sent as part of the pagination request
Implementation
@$pb.TagNumber(2)
$fixnum.Int64 get offset => $_getI64(1);
- @TagNumber.new(2)
Implementation
@$pb.TagNumber(2)
set offset($fixnum.Int64 value) => $_setInt64(1, value);