payload property
@description The array of records for the current page.
Implementation
@$pb.TagNumber(4)
$pb.PbList<FormField> get payload => $_getList(3);
@description The array of records for the current page.
@$pb.TagNumber(4)
$pb.PbList<FormField> get payload => $_getList(3);