FormsFieldsServiceCreateRequest class

Describes the necessary data structure during creation of a form field

Available extensions

Constructors

FormsFieldsServiceCreateRequest({String? entityUuid, String? userComment, String? name, FORM_TYPE? type, Int64? sectionId, String? width, FORM_FIELD_ELEMENT? element, String? placeholder, String? regex, Iterable<String>? definedValues, String? code, bool? isReadonly, bool? isHidden, bool? isSearchable, bool? isPublic})
factory
FormsFieldsServiceCreateRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
FormsFieldsServiceCreateRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

code String
The unique code by which the form field is classified
getter/setter pair
definedValues → PbList<String>
The possible values that are applicable on the form field (in case of dropdowns, radio buttons, checkboxes)
no setter
element FORM_FIELD_ELEMENT
The type of the element
getter/setter pair
entityUuid String
Stores a globally unique entity UUID. This will be set at the organization level
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isHidden bool
Denotes if the field is hidden (field shall not be visible on the UI). The field shall be visible only through the API
getter/setter pair
isPublic bool
Denotes if the field is public (field shall be visible on any custom designed public interfaces)
getter/setter pair
isReadonly bool
Denotes if the field is readonly (changes shall not be allowed to be made on the UI). Any changes will still be made through the API
getter/setter pair
isSearchable bool
Denotes if the field is searchable (field shall not be visible on the UI in the filters view). The field will continue to be searchable through the API
getter/setter pair
name String
The name of the form field
getter/setter pair
placeholder String
The placeholder of the form field
getter/setter pair
regex String
The regex that is applicable on the form field
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionId ↔ Int64
The ID of the corresponding form section that the form field belongs to
getter/setter pair
type FORM_TYPE
The type of the form field
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
userComment String
Stores any comment that the user might add during this operation
getter/setter pair
width String
The width of the form field
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCode() → void
clearElement() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIsHidden() → void
clearIsPublic() → void
clearIsReadonly() → void
clearIsSearchable() → void
clearName() → void
clearPlaceholder() → void
clearRegex() → void
clearSectionId() → void
clearType() → void
clearUserComment() → void
clearWidth() → void
clone() FormsFieldsServiceCreateRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(FormsFieldsServiceCreateRequest)) FormsFieldsServiceCreateRequest
Apply updates to a copy of this message.
createEmptyInstance() FormsFieldsServiceCreateRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasCode() bool
hasElement() bool
hasEntityUuid() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasIsHidden() bool
hasIsPublic() bool
hasIsReadonly() bool
hasIsSearchable() bool
hasName() bool
hasPlaceholder() bool
hasRegex() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSectionId() bool
hasType() bool
hasUserComment() bool
hasWidth() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited