definedValues property
The possible values that are applicable on the form field (in case of dropdowns, radio buttons, checkboxes)
Implementation
@$pb.TagNumber(17)
$pb.PbList<$core.String> get definedValues => $_getList(9);
The possible values that are applicable on the form field (in case of dropdowns, radio buttons, checkboxes)
@$pb.TagNumber(17)
$pb.PbList<$core.String> get definedValues => $_getList(9);