viewByCode method

ResponseFuture<FormField> viewByCode(
  1. SimpleSearchReq request, {
  2. CallOptions? options,
})

Retrieves a single record via the assigned internal code.

Note: High-volume compliance data, audit records, and system logs are excluded from the response payload.

Errors:

  • NOT_FOUND: If the provided internal code does not exist.

Implementation

$grpc.ResponseFuture<$0.FormField> viewByCode(
  $1.SimpleSearchReq request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$viewByCode, request, options: options);
}