sdk/forms_fields_data.scailo.pb library
Classes
- FORM_FIELD_FILTER_OPERATOR
- Describes the form field filter operator
- FormFieldDatum
- Describes the data stored in an individual form field data row of each dynamic form
- FormFieldDatumCreateRequest
- Describes the data required for creating a dynamic form field entry
- FormFieldDatumFilterRequest
- Describes the data required to filter for records using form field data
- FormFieldDatumHistoryRequest
- Describes the data required to fetch history of the given form field and the specified resource
- FormFieldDatumList
- Describes the message consisting of the list of records
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.