selectedValues property
The list of values that have been selected by the user (in case of a checkbox or a dropdown)
Implementation
@$pb.TagNumber(23)
$pb.PbList<$core.String> get selectedValues => $_getList(6);
The list of values that have been selected by the user (in case of a checkbox or a dropdown)
@$pb.TagNumber(23)
$pb.PbList<$core.String> get selectedValues => $_getList(6);