selectedValues property

  1. @TagNumber.new(3)
PbList<String> get selectedValues

Conditional A list of identifiers for multi-selection fields. Use this for radio, checkbox, or dropdown field types.

Note: For radio buttons, this list should contain exactly one element. Example: "option_1", "option_5"

Implementation

@$pb.TagNumber(3)
$pb.PbList<$core.String> get selectedValues => $_getList(2);