sdk/forms_sections.scailo.pbgrpc library
Classes
- FORM_SECTION_SORT_KEY
- Describes the available sort keys for retrieving forms sections
- FormSection
- Describes the data structure of each form section on the platform
- FormSectionPaginationResp
- Describes the data structure that responds to a pagination request
- FormsSectionsList
- Describes the data structure that stores a list of forms sections
- FormsSectionsServiceBase
- FormsSectionsServiceClient
- Describes the methods applicable on each form section
- FormsSectionsServiceCountReq
- Describes the base request payload of a count search
- FormsSectionsServiceCreateRequest
- Describes the necessary data structure during creation of a form section
- FormsSectionsServiceFilterReq
- Describes the base request payload of a filter search
- FormsSectionsServicePaginationReq
- Describes a pagination request to retrieve records
- FormsSectionsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on forms sections
- FormsSectionsServiceUpdateRequest
- Describes the data structure to perform the update (draft/revision) operation on a form section
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.