FormsSectionsServiceClient class

Describes the methods applicable on each form section

Annotations
  • @GrpcServiceName.new('Scailo.FormsSectionsService')

Constructors

FormsSectionsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
count(FormsSectionsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
create(FormsSectionsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<FormSection>
Create a form section
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard the form section
downloadAsCSV(FormsSectionsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
filter(FormsSectionsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<FormsSectionsList>
View all that match the given filter criteria
importFromCSV(StandardFile request, {CallOptions? options}) → ResponseFuture<IdentifierUUIDsList>
Import records using a CSV file (duplicate codes will be skipped)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore the form section
searchAll(FormsSectionsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<FormsSectionsList>
View all forms sections that match the given search key
toString() String
A string representation of this object.
inherited
update(FormsSectionsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<FormSection>
Update a form section
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<FormsSectionsList>
View all forms sections
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<FormsSectionsList>
View all forms sections with the given entity UUID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<FormSection>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<FormSection>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<FormSection>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<FormSection>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<FormsSectionsList>
View all records with the given IDs
viewWithPagination(FormsSectionsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<FormSectionPaginationResp>
View forms sections with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.