importFromCSV method

ResponseFuture<IdentifierUUIDsList> importFromCSV(
  1. StandardFile request, {
  2. CallOptions? options,
})

Bulk imports records from a provided CSV file. Behavior:

  • Deduplication: Skips entries where the code already exists in the system.
  • Atomicity: This is an "all-or-nothing" operation; if any part of the import fails, no changes are committed.
  • Idempotency: Multiple calls with the same CSV result in the same state. Returns a list of UUIDs for all successfully processed or existing records.

Implementation

$grpc.ResponseFuture<$1.IdentifierUUIDsList> importFromCSV(
  $1.StandardFile request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$importFromCSV, request, options: options);
}