GeneralSettingsServiceCreateRequest class

Describes the necessary data structure during creation of a general settings

Available extensions

Constructors

GeneralSettingsServiceCreateRequest({String? entityUuid, String? companyName, String? phone, String? email, String? address, String? city, String? state, String? pinCode, String? country, String? cin, String? pan, String? gstin, String? domainName, String? authlessAccessDomain, String? purchaseOrderSenderEmail, String? salesEnquirySenderEmail, String? salesOrderSenderEmail, String? salesInvoiceSenderEmail, String? salesQuotationSenderEmail, String? vendorInvoiceSenderEmail, String? workOrderSenderEmail, String? expenseSenderEmail, bool? disableViCreationWithBillDateAfterPoApproval, bool? requireMfaForRecordApproval, bool? autoReqVerifyOnExitRecordEntry, Iterable<FormFieldDatumCreateRequest>? formData})
factory
GeneralSettingsServiceCreateRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
GeneralSettingsServiceCreateRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

address String
The address of the organization
getter/setter pair
authlessAccessDomain String
The name of the domain using which users can access records without logging in
getter/setter pair
autoReqVerifyOnExitRecordEntry bool
Stores if attendances should be automatically sent for verification on exit record
getter/setter pair
cin String
The Company Identification Number
getter/setter pair
city String
The city of the organization
getter/setter pair
companyName String
The name of the organization
getter/setter pair
country String
The country of the organization
getter/setter pair
disableViCreationWithBillDateAfterPoApproval bool
Stores if vendor invoices should not be created with bill date that is after the approval of a purchase order
getter/setter pair
domainName String
The name of the domain under which this application is run
getter/setter pair
email String
The email of the organization
getter/setter pair
entityUuid String
Stores a globally unique entity UUID. This will be set at the organization level
getter/setter pair
expenseSenderEmail String
The email address from which expenses will be sent
getter/setter pair
formData → PbList<FormFieldDatumCreateRequest>
The list of dynamic forms
no setter
gstin String
The GSTIN of the organization
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
Stores the base64 encoded logo of the organization
getter/setter pair
pan String
The PAN number of the organization
getter/setter pair
phone String
The phone number of the organization
getter/setter pair
pinCode String
The pin code of the organization
getter/setter pair
purchaseOrderSenderEmail String
The email address from which purchase orders will be sent
getter/setter pair
requireMfaForRecordApproval bool
Stores if MFA is required for record approval
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesEnquirySenderEmail String
The email address from which sales enquiries will be sent
getter/setter pair
salesInvoiceSenderEmail String
The email address from which sales invoices will be sent
getter/setter pair
salesOrderSenderEmail String
The email address from which sales orders will be sent
getter/setter pair
salesQuotationSenderEmail String
The email address from which sales quotations will be sent
getter/setter pair
state String
The state of the organization
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
vendorInvoiceSenderEmail String
The email address from which vendor invoices will be sent
getter/setter pair
workOrderSenderEmail String
The email address from which work orders will be sent
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAddress() → void
clearAuthlessAccessDomain() → void
clearAutoReqVerifyOnExitRecordEntry() → void
clearCin() → void
clearCity() → void
clearCompanyName() → void
clearCountry() → void
clearDisableViCreationWithBillDateAfterPoApproval() → void
clearDomainName() → void
clearEmail() → void
clearEntityUuid() → void
clearExpenseSenderEmail() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGstin() → void
clearPan() → void
clearPhone() → void
clearPinCode() → void
clearPurchaseOrderSenderEmail() → void
clearRequireMfaForRecordApproval() → void
clearSalesEnquirySenderEmail() → void
clearSalesInvoiceSenderEmail() → void
clearSalesOrderSenderEmail() → void
clearSalesQuotationSenderEmail() → void
clearState() → void
clearVendorInvoiceSenderEmail() → void
clearWorkOrderSenderEmail() → void
clone() GeneralSettingsServiceCreateRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(GeneralSettingsServiceCreateRequest)) GeneralSettingsServiceCreateRequest
Apply updates to a copy of this message.
createEmptyInstance() GeneralSettingsServiceCreateRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAddress() bool
hasAuthlessAccessDomain() bool
hasAutoReqVerifyOnExitRecordEntry() bool
hasCin() bool
hasCity() bool
hasCompanyName() bool
hasCountry() bool
hasDisableViCreationWithBillDateAfterPoApproval() bool
hasDomainName() bool
hasEmail() bool
hasEntityUuid() bool
hasExpenseSenderEmail() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasGstin() bool
hasPan() bool
hasPhone() bool
hasPinCode() bool
hasPurchaseOrderSenderEmail() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRequireMfaForRecordApproval() bool
hasSalesEnquirySenderEmail() bool
hasSalesInvoiceSenderEmail() bool
hasSalesOrderSenderEmail() bool
hasSalesQuotationSenderEmail() bool
hasState() bool
hasVendorInvoiceSenderEmail() bool
hasWorkOrderSenderEmail() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited