sdk/general_settings.scailo.pbgrpc library

Classes

GeneralSettings
Describes the data structure of general settings on the platform
GeneralSettingsServiceBase
GeneralSettingsServiceClient
Describes the methods applicable on each general settings
GeneralSettingsServiceCreateRequest
Describes the necessary data structure during creation of a general settings

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.