GeneralSettingsServiceClient class
Describes the methods applicable on each general settings
- Annotations
-
- @GrpcServiceName.new('Scailo.GeneralSettingsService')
Constructors
-
GeneralSettingsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
create(
GeneralSettingsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< GeneralSettings> - Create a general settings
-
downloadImportTemplate(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV template that could be used to upload records
-
importFromCSV(
StandardFile request, {CallOptions? options}) → ResponseFuture< IdentifierUUIDsList> - Import records using a CSV file
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateOrganizationLogo(
StandardFile request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update the logo of the organization
-
viewOrganizationLogo(
Empty request, {CallOptions? options}) → ResponseFuture< ImageResponse> - View current logo of the organization
-
viewSettings(
Empty request, {CallOptions? options}) → ResponseFuture< GeneralSettings>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.