deleteExisting property

  1. @TagNumber.new(4)
bool get deleteExisting

Stores if the existing internal subscribers in the general stream need to be deleted before adding from the source record

Implementation

@$pb.TagNumber(4)
$core.bool get deleteExisting => $_getBF(3);
  1. @TagNumber.new(4)
set deleteExisting (bool value)

Implementation

@$pb.TagNumber(4)
set deleteExisting($core.bool value) => $_setBool(3, value);