GeneralStreamsServiceClient class

Describes the common methods applicable on each general stream

Annotations
  • @GrpcServiceName.new('Scailo.GeneralStreamsService')

Constructors

GeneralStreamsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addInternalSubscriber(GeneralStreamsServiceInternalSubscriberCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an internal subscriber
addMessage(GeneralStreamsServiceMessageCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add a message to an general stream
cancel(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Cancel
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Complete
count(GeneralStreamsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
create(GeneralStreamsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Create
deleteInternalSubscriber(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an internal subscriber
deleteMessage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Delete a message in an general stream
downloadAsCSV(GeneralStreamsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request
filter(GeneralStreamsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
View all that match the given filter criteria
importInternalSubscribersFromDepartment(GeneralStreamsServiceImportInternalSubscribersRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Import users as internal subscribers from department and returns the ID of the general stream
importInternalSubscribersFromTeam(GeneralStreamsServiceImportInternalSubscribersRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Import users as internal subscribers from team and returns the ID of the general stream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Reopen
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Repeat
saveMessageForLater(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Saves a message for viewing it later
searchAll(GeneralStreamsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
View all that match the given search key
searchMessagesWithPagination(GeneralStreamMessagesSearchRequest request, {CallOptions? options}) → ResponseFuture<GeneralStreamsServicePaginatedMessagesResponse>
Search through general stream messages with pagination
toString() String
A string representation of this object.
inherited
update(GeneralStreamsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Update
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
View all with the given entity UUID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<GeneralStream>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStream>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<GeneralStream>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStream>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
View all records with the given IDs
viewInternalSubscriberByID(Identifier request, {CallOptions? options}) → ResponseFuture<GeneralStreamInternalSubscriber>
View an internal subscriber for the given ID
viewInternalSubscribers(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamInternalSubscribersList>
View all internal subscribers for given general stream UUID
viewMessageByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamMessage>
View General Stream Message by UUID
viewMessageReceipts(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamMessageReceiptsList>
View all receipts for the given message UUID
viewMessages(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamMessagesList>
View all messages for given general stream UUID
viewPaginatedMessages(GeneralStreamMessagesSearchRequest request, {CallOptions? options}) → ResponseFuture<GeneralStreamsServicePaginatedMessagesResponse>
View general stream messages for given general stream ID with pagination
viewWithPagination(GeneralStreamsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<GeneralStreamsServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.