textValues property
The possible values from which a user can choose in case the input type is text-dropdown
Implementation
@$pb.TagNumber(30)
$pb.PbList<$core.String> get textValues => $_getList(9);
The possible values from which a user can choose in case the input type is text-dropdown
@$pb.TagNumber(30)
$pb.PbList<$core.String> get textValues => $_getList(9);