startDate property
The date from which the goal comes into force
Implementation
@$pb.TagNumber(13)
$core.String get startDate => $_getSZ(5);
Implementation
@$pb.TagNumber(13)
set startDate($core.String value) => $_setString(5, value);
The date from which the goal comes into force
@$pb.TagNumber(13)
$core.String get startDate => $_getSZ(5);
@$pb.TagNumber(13)
set startDate($core.String value) => $_setString(5, value);