sdk/holidays.scailo.pb library

Classes

Holiday
Describes the parameters that are part of a standard response
HOLIDAY_SORT_KEY
Describes the available sort keys
HolidayShiftGroup
Describes the parameters that constitute a shift associated to a shift group
HolidaysList
Describes the message consisting of the list of shift groups
HolidaysServiceCountReq
Describes the base request payload of a count search
HolidaysServiceCreateRequest
Describes the parameters necessary to create a record
HolidaysServiceFilterReq
Describes the base request payload of a filter search
HolidaysServicePaginationReq
Describes a pagination request to retrieve records
HolidaysServicePaginationResponse
Describes the response to a pagination request
HolidaysServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
HolidaysServiceShiftGroupCreateRequest
Describes the parameters required to add a shift to a shift group
HolidaysServiceShiftGroupUpdateRequest
Describes the parameters required to update a shift in a shift group
HolidaysServiceUpdateRequest
Describes the parameters necessary to update a record
HolidaysServiceViewHolidaysOnTimestampRequest
Describes the request payload to query if the given timestamp is a holiday for the given shift group ID
HolidaysShiftsGroupsHistoryRequest
Describes the parameters that are required to retrieve the history of the record
HolidaysShiftsGroupsList
Describes the message consisting of the list of holiday shift groups

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.