Infrastructure class

Describes the parameters that are part of a standard response

Available extensions

Constructors

Infrastructure({String? entityUuid, EmployeeMetadata? metadata, INVENTORY_LIFECYCLE? status, Iterable<LogbookLogInventoryLC>? logs, Int64? storeIntakeAt, Int64? consumedOrRejectedAt, Int64? reworkStartAt, Int64? reworkEndAt, Int64? returnedOrScrappedAt, Int64? discardedAt, Int64? vaultFolderId, Int64? parentRefId, INFRASTRUCTURE_REF_FROM? refFrom, Int64? refId, Int64? familyId, String? code, String? internalItemCode, String? hash, Int64? quantity, Int64? quantityRemaining, Int64? secondaryUomId, Int64? secondaryQuantity, Int64? shelfLifeTimestamp, Int64? warrantyTimestamp, Int64? storeId, Int64? storageId, bool? isQcReportPublic, Int64? locationId, String? remainingDimensions, String? description, String? shortUrl, Iterable<FormFieldDatum>? formData})
factory
Infrastructure.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
Infrastructure.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

code String
The auto generated code of the infrastructure
getter/setter pair
consumedOrRejectedAt ↔ Int64
The timestamp of when the item was either consumed or rejected
getter/setter pair
description String
The description of the infrastructure
getter/setter pair
discardedAt ↔ Int64
The timestamp of when the item was discarded
getter/setter pair
entityUuid String
Stores a globally unique entity UUID. This will be set at the organization level
getter/setter pair
familyId ↔ Int64
Stores the ID of the associated family
getter/setter pair
formData → PbList<FormFieldDatum>
The list of dynamic forms
no setter
hash String
The computed hash of the infrastructure
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
internalItemCode String
Stores the internal code (as given by user)
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isQcReportPublic bool
Stores if the associated QC report should be public
getter/setter pair
locationId ↔ Int64
The location ID of where the item needs to be stored
getter/setter pair
logs → PbList<LogbookLogInventoryLC>
Stores the logs of every operation performed on this infrastructure
no setter
metadata EmployeeMetadata
Stores the metadata of this infrastructure
getter/setter pair
parentRefId ↔ Int64
The ID of the parent inventory item (if applicable)
getter/setter pair
quantity ↔ Int64
Stores the quantity (in cents)
getter/setter pair
quantityRemaining ↔ Int64
Stores the remaining quantity (in cents)
getter/setter pair
refFrom INFRASTRUCTURE_REF_FROM
Stores the reference from
getter/setter pair
refId ↔ Int64
Stores the ID of the reference
getter/setter pair
remainingDimensions String
Stores any applicable remaining dimensions as a string
getter/setter pair
returnedOrScrappedAt ↔ Int64
The timestamp of when the item was either returned or scrapped
getter/setter pair
reworkEndAt ↔ Int64
The timestamp of when the rework process ended
getter/setter pair
reworkStartAt ↔ Int64
The timestamp of when the rework process began
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryQuantity ↔ Int64
Stores an optional quantity in the secondary unit of infrastructure
getter/setter pair
secondaryUomId ↔ Int64
Stores an optional secondary unit of infrastructure
getter/setter pair
shelfLifeTimestamp ↔ Int64
Stores an optional shelf life as a timestamp
getter/setter pair
shortUrl String
The short URL of the item
getter/setter pair
status INVENTORY_LIFECYCLE
The status of this infrastructure
getter/setter pair
storageId ↔ Int64
Stores an optional ID of the associated storage that the infrastructure is stored in
getter/setter pair
storeId ↔ Int64
Stores the store to which the infrastructure is sent to
getter/setter pair
storeIntakeAt ↔ Int64
The timestamp of when the item was admitted into store
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
vaultFolderId ↔ Int64
The associated vault folder ID
getter/setter pair
warrantyTimestamp ↔ Int64
Stores an optional warranty as a timestamp
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCode() → void
clearConsumedOrRejectedAt() → void
clearDescription() → void
clearDiscardedAt() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFamilyId() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearHash() → void
clearInternalItemCode() → void
clearIsQcReportPublic() → void
clearLocationId() → void
clearMetadata() → void
clearParentRefId() → void
clearQuantity() → void
clearQuantityRemaining() → void
clearRefFrom() → void
clearRefId() → void
clearRemainingDimensions() → void
clearReturnedOrScrappedAt() → void
clearReworkEndAt() → void
clearReworkStartAt() → void
clearSecondaryQuantity() → void
clearSecondaryUomId() → void
clearShelfLifeTimestamp() → void
clearShortUrl() → void
clearStatus() → void
clearStorageId() → void
clearStoreId() → void
clearStoreIntakeAt() → void
clearVaultFolderId() → void
clearWarrantyTimestamp() → void
clone() Infrastructure
Creates a deep copy of the fields in this message.
copyWith(void updates(Infrastructure)) Infrastructure
Apply updates to a copy of this message.
createEmptyInstance() Infrastructure
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureMetadata() EmployeeMetadata
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasCode() bool
hasConsumedOrRejectedAt() bool
hasDescription() bool
hasDiscardedAt() bool
hasEntityUuid() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFamilyId() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasHash() bool
hasInternalItemCode() bool
hasIsQcReportPublic() bool
hasLocationId() bool
hasMetadata() bool
hasParentRefId() bool
hasQuantity() bool
hasQuantityRemaining() bool
hasRefFrom() bool
hasRefId() bool
hasRemainingDimensions() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasReturnedOrScrappedAt() bool
hasReworkEndAt() bool
hasReworkStartAt() bool
hasSecondaryQuantity() bool
hasSecondaryUomId() bool
hasShelfLifeTimestamp() bool
hasShortUrl() bool
hasStatus() bool
hasStorageId() bool
hasStoreId() bool
hasStoreIntakeAt() bool
hasVaultFolderId() bool
hasWarrantyTimestamp() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() Infrastructure
getDefault() Infrastructure