InfrastructuresServiceUpdateRequest class

Describes the parameters necessary to update a record

Available extensions

Constructors

InfrastructuresServiceUpdateRequest({String? userComment, Int64? id, bool? notifyUsers, Int64? vaultFolderId, String? internalItemCode, Int64? secondaryUomId, Int64? secondaryQuantity, Int64? shelfLifeTimestamp, Int64? warrantyTimestamp, Int64? storageId, bool? isQcReportPublic, String? remainingDimensions, String? description, Iterable<FormFieldDatumCreateRequest>? formData})
factory
InfrastructuresServiceUpdateRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
InfrastructuresServiceUpdateRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

description String
The description of the infrastructure
getter/setter pair
formData → PbList<FormFieldDatumCreateRequest>
The list of dynamic forms
no setter
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
id ↔ Int64
The ID of the record that needs to be updated
getter/setter pair
info_ → BuilderInfo
no setter
internalItemCode String
Stores the internal code (as given by user)
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isQcReportPublic bool
Stores if the associated QC report should be public
getter/setter pair
notifyUsers bool
Optional boolean value that stores if a notification needs to be sent to users about the update to the record. This is useful when a subsequent operation needs to be performed immediately (such as send to verification after updating the revision)
getter/setter pair
remainingDimensions String
Stores any applicable remaining dimensions as a string
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryQuantity ↔ Int64
Stores an optional quantity in the secondary unit of infrastructure
getter/setter pair
secondaryUomId ↔ Int64
Stores an optional secondary unit of infrastructure
getter/setter pair
shelfLifeTimestamp ↔ Int64
Stores an optional shelf life as a timestamp
getter/setter pair
storageId ↔ Int64
Stores an optional ID of the associated storage that the infrastructure is stored in
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
userComment String
Stores any comment that the user might add during this operation
getter/setter pair
vaultFolderId ↔ Int64
The associated vault folder ID
getter/setter pair
warrantyTimestamp ↔ Int64
Stores an optional warranty as a timestamp
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearDescription() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearId() → void
clearInternalItemCode() → void
clearIsQcReportPublic() → void
clearNotifyUsers() → void
clearRemainingDimensions() → void
clearSecondaryQuantity() → void
clearSecondaryUomId() → void
clearShelfLifeTimestamp() → void
clearStorageId() → void
clearUserComment() → void
clearVaultFolderId() → void
clearWarrantyTimestamp() → void
clone() InfrastructuresServiceUpdateRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(InfrastructuresServiceUpdateRequest)) InfrastructuresServiceUpdateRequest
Apply updates to a copy of this message.
createEmptyInstance() InfrastructuresServiceUpdateRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasDescription() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasId() bool
hasInternalItemCode() bool
hasIsQcReportPublic() bool
hasNotifyUsers() bool
hasRemainingDimensions() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSecondaryQuantity() bool
hasSecondaryUomId() bool
hasShelfLifeTimestamp() bool
hasStorageId() bool
hasUserComment() bool
hasVaultFolderId() bool
hasWarrantyTimestamp() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited