InfrastructuresServiceClient class

Describes the common methods applicable on each infrastructure

Annotations
  • @GrpcServiceName.new('Scailo.InfrastructuresService')

Constructors

InfrastructuresServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
consume(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Consume
count(InfrastructuresServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
create(InfrastructuresServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create (and Send for QC)
Create a magic link
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(InfrastructuresServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request
downloadImportTemplate(Empty request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the CSV template that could be used to upload records
downloadLabelByID(Identifier request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download Label for the given Identifier
downloadLabelByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download Label for the given IdentifierUUID (can be used to allow public downloads)
downloadQCReportByID(Identifier request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download QC Report with the given Identifier
downloadQCReportByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download QC Report with the given IdentifierUUID (can be used to allow public downloads)
filter(InfrastructuresServiceFilterReq request, {CallOptions? options}) → ResponseFuture<InfrastructuresList>
View all that match the given filter criteria
importFromCSV(StandardFile request, {CallOptions? options}) → ResponseFuture<IdentifierUUIDsList>
Import records using a CSV file. Imports records as initial stock
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
partition(InventoryPartitionRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create a partition from the parent lot (and returns the identifier of the new partition)
reject(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reject
returnMaterial(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Return
scrap(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Scrap
searchAll(InfrastructuresServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<InfrastructuresList>
View all that match the given search key
sendForQC(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for QC
sendForRework(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for Rework
sendToStore(InfrastructuresServiceSendToStoreRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send to Store
splitLot(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Split into unit quantities
toString() String
A string representation of this object.
inherited
update(InfrastructuresServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<InfrastructuresList>
View all
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<Infrastructure>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Infrastructure>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<Infrastructure>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Infrastructure>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<InfrastructuresList>
View all records with the given IDs
viewFromUUIDs(IdentifierUUIDsList request, {CallOptions? options}) → ResponseFuture<InfrastructuresList>
View all records with the given UUIDs
viewInventoryInteractions(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<InventoryInteractionsList>
View all inventory interactions for infrastructure with the given IdentifierUUID
viewWithPagination(InfrastructuresServicePaginationReq request, {CallOptions? options}) → ResponseFuture<InfrastructuresServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.