sdk/inventory.scailo.pb library

Classes

AbridgedGoodsReceiptItem
Describes the abridged version of each goods receipt item
AbridgedInventoryItem
Describes the abridged version of each inventory item
AbridgedProductionPlanItem
Describes the abridged version of each production plan item
AbridgedPurchaseIndentItem
Describes the abridged version of each purchase indent item
AbridgedPurchaseOrderItem
Describes the abridged version of each purchase order item
AbridgedPurchaseReturnItem
Describes the abridged version of each purchase return item
ConsolidatedInventoryStatistics
Describes the message consisting of all the inventory statistics for the given family ID
FilterReturnableInventoryForIdentifierUUID
Describes the message that consists of parameters that are required to filter returnable inventory for a record with the given identifier
FilterReturnableInventoryReq
Describes the message that consists of parameters that are required to filter for returnable inventory
GENERIC_INVENTORY_REF_FROM
Stores all the possible references from which a generic inventory can be added
GenericInventory
Describes the parameters that are present in a generic inventory payload, which is an abstraction over every inventory item that consists of the common parameters
GenericInventoryList
Describes the message consisting of the list of generic inventory
INVENTORY_NODE_ORIGIN_TYPE
Describes the available types of inventory node origins
InventoryCodeMap
Describes the parameters that are present in an inventory code map
InventoryDemand
Describes the message consisting of the demand
InventoryDemandMap
Describes the message consisting of the demand map
InventoryDetailedDemand
Describes the message consisting of the detailed demand statistics for the given family ID
InventoryHashSearchReq
Describes the request to search for an inventory item using the item's hash
InventoryIndentedStatistics
Describes the message consisting of the indented inventory statistics for the given family ID
InventoryOrderedStatistics
Describes the message consisting of the ordered inventory statistics for the given family ID
InventoryServiceFamilyQuantityReq
Describes the request to calculate the quantity remaining for the given family in a particular status
InventoryWorkInProgressStatistics
Describes the message consisting of the work in progress inventory statistics for the given family ID
IssuableInventorySearchReq
Describes the message that consists of parameters that are required to retrieve issuable inventory
ReturnableInventorySearchReq
Describes the message that consists of parameters that are required to retrieve returnable inventory
SearchReturnableInventoryForIdentifierUUID
Describes the message that consists of parameters that are required to search for returnable inventory for a record with the given identifier
SearchReturnableInventoryReq
Describes the message that consists of parameters that are required to search for returnable inventory

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.