InventoryServiceClient class

Describes the common methods applicable on inventory

Annotations
  • @GrpcServiceName.new('Scailo.InventoryService')

Constructors

InventoryServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
countIndented(Identifier request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
Quantity of inventory items of the family with the given Identifier that have been indented
countOrdered(Identifier request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
Quantity of inventory items of the family with the given Identifier that have been ordered
countWorkInProgress(Identifier request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
Quantity of inventory items of the family with the given Identifier that are being manufactured
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
viewAdjustedDemandQuantity(Identifier request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
View adjusted demand quantity of the family with the given Identifier
viewAdmittedFromGoodsReceipt(Identifier request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View admitted inventory from a Goods Receipt represented by the Identifier
viewAdmittedFromInwardJobFreeIssueMaterial(Identifier request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View admitted inventory from an Inward Job Free Issue Material represented by the Identifier
viewAdmittedFromProductionPlan(Identifier request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View admitted inventory from a Production Plan represented by the Identifier
viewBaseDemandQuantity(Identifier request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
View base demand quantity of the family with the given Identifier
viewByHash(InventoryHashSearchReq request, {CallOptions? options}) → ResponseFuture<GenericInventory>
View inventory item by hash
viewByShortURL(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<GenericInventory>
View inventory item by short URL
viewConsolidatedStatistics(Identifier request, {CallOptions? options}) → ResponseFuture<ConsolidatedInventoryStatistics>
View consolidated inventory statistics
viewDetailedDemand(Identifier request, {CallOptions? options}) → ResponseFuture<InventoryDetailedDemand>
View the detailed demand of the family with the given Identifier
viewIndentedStatistics(Identifier request, {CallOptions? options}) → ResponseFuture<InventoryIndentedStatistics>
View the indented statistics of the family with the given Identifier
viewInStorage(Identifier request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View inventory placed in storage represented by the Identifier
viewIssuable(IssuableInventorySearchReq request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View issuable inventory
viewIssuedForGoodsDispatch(Identifier request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View issued inventory for a Goods Dispatch represented by the Identifier
viewIssuedForOutwardJobFreeIssueMaterial(Identifier request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View issued inventory for an Outward Job Free Issue Material represented by the Identifier
viewOrderedStatistics(Identifier request, {CallOptions? options}) → ResponseFuture<InventoryOrderedStatistics>
View the ordered statistics of the fammily with the given Identifier
viewQuantityRemaining(InventoryServiceFamilyQuantityReq request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
View quantity remaining of the family in the given status
viewRequiredQuantity(Identifier request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
View required quantity of the family with the given Identifier
viewReturnableForInwardJob(ReturnableInventorySearchReq request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View inventory that is returnable from an inward job
viewReturnableForOutwardJob(ReturnableInventorySearchReq request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View inventory that is returnable from an outward job
viewReturnableForPurchaseOrder(ReturnableInventorySearchReq request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View inventory that is returnable from a purchase order
viewReturnableForSalesOrder(ReturnableInventorySearchReq request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View inventory that is returnable from a sales order
viewReturnableForStockIssuance(ReturnableInventorySearchReq request, {CallOptions? options}) → ResponseFuture<GenericInventoryList>
View inventory that is returnable from a stock issuance
viewWorkInProgressStatistics(Identifier request, {CallOptions? options}) → ResponseFuture<InventoryWorkInProgressStatistics>
View the work in progress statistics of the family with the given Identifier

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.