LABEL_SORT_KEY class

Describes the available sort keys for retrieving labels

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) LABEL_SORT_KEY?

Constants

LABEL_SORT_KEY_CODE → const LABEL_SORT_KEY
Fetch ordered results by the code
LABEL_SORT_KEY_CREATED_AT → const LABEL_SORT_KEY
Fetch ordered results by the creation timestamp
LABEL_SORT_KEY_ID_UNSPECIFIED → const LABEL_SORT_KEY
Fetch ordered results by id
LABEL_SORT_KEY_MODIFIED_AT → const LABEL_SORT_KEY
Fetch ordered results by the modified timestamp
LABEL_SORT_KEY_NAME → const LABEL_SORT_KEY
Fetch ordered results by name
values → const List<LABEL_SORT_KEY>