sdk/ledgers.scailo.pbgrpc library

Classes

Ledger
Describes the parameters that are part of a standard response
LEDGER_SORT_KEY
Describes the available sort keys
LedgersList
Describes the message consisting of the list of records
LedgersServiceBase
LedgersServiceClient
Describes the common methods applicable on each ledger
LedgersServiceCountReq
Describes the base request payload of a count search
LedgersServiceCreateRequest
Describes the parameters necessary to create a record
LedgersServiceFilterReq
Describes the base request payload of a filter search
LedgersServicePaginationReq
Describes a pagination request to retrieve records
LedgersServicePaginationResponse
Describes the response to a pagination request
LedgersServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
LedgersServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.