sdk/login.scailo.pb library

Classes

AuthTokenValidityRequest
Describes the data structure required to check if the login is still valid
ClientUserLoginResponse
Describes the response to a client user login request
LogoutRequest
Describes the data structure required to logout a user
LogoutResponse
Describes the response data structure to a logout request
UserLoginHistory
Stores the user login history
UserLoginHistoryList
Describes the message consisting of the list of user logins
UserLoginRequest
Describes the data structure for a user to login
UserLoginResponse
Describes the response to a user login request
VendorUserLoginResponse
Describes the response to a vendor user login request

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.