LoginServiceClient class

Describes the methods applicable on the login service

Annotations
  • @GrpcServiceName.new('Scailo.LoginService')

Constructors

LoginServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
isAuthTokenValid(AuthTokenValidityRequest request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Check if the auth token is still valid
loginAsClientUser(UserLoginRequest request, {CallOptions? options}) → ResponseFuture<ClientUserLoginResponse>
Login using credentials belonging to a client user
loginAsEmployeePrimary(UserLoginRequest request, {CallOptions? options}) → ResponseFuture<UserLoginResponse>
Login as employee using primary role
loginAsEmployeeSecondary(UserLoginRequest request, {CallOptions? options}) → ResponseFuture<UserLoginResponse>
Login as employee using mobile role
loginAsVendorUser(UserLoginRequest request, {CallOptions? options}) → ResponseFuture<VendorUserLoginResponse>
Login using credentials belonging to a vendor user
logout(LogoutRequest request, {CallOptions? options}) → ResponseFuture<LogoutResponse>
Logout
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
userLoginPrimary(UserLoginRequest request, {CallOptions? options}) → ResponseFuture<UserLoginResponse>
Login using credentials belonging to a user and evaluate using user's primary role (this has been deprecated. Use LoginAsEmployeePrimary instead)
viewHistory(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<UserLoginHistoryList>
View login history for the given username

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.