sdk/magic_links.scailo.pb library

Classes

Describes the available resource types magic links
Describes the available sort keys for retrieving magic links
Describes the data structure of each magic link on the platform
MagicLinkAccessLog
Describes the access log of each magic link
MagicLinkAccessLogsList
Describes the message consisting of the list of access logs
MagicLinkPaginationResp
Describes the data structure that responds to a pagination request
MagicLinkServiceSearchByCodeReq
Describes the request payload for retrieving the magic link information using the code
Describes the data structure that stores a list of magic links
MagicLinksServiceCountReq
Describes the base request payload of a count search
MagicLinksServiceCreateRequest
Describes the necessary data structure during creation of a magic link
MagicLinksServiceCreateRequestForSpecificResource
Describes the necessary data structure for creation of a magic link. This data structure is used within other services, while creating magic links for the given resource
MagicLinksServiceFilterReq
Describes the base request payload of a filter search
MagicLinksServicePaginationReq
Describes a pagination request to retrieve records
MagicLinksServiceSearchAllReq
Describes the request payload for performing a generic search operation on magic links
MagicLinksServiceUpdateRequest
Describes the data structure to perform the update (draft/revision) operation on a magic link

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.