code property

  1. @TagNumber.new(40)
String get code

Stores the code of the magic link that can be used to uniquely identify the magic link. This code will be used in the associated links, and will be used to uniquely identify the resource.

Implementation

@$pb.TagNumber(40)
$core.String get code => $_getSZ(6);
  1. @TagNumber.new(40)
set code (String value)

Implementation

@$pb.TagNumber(40)
set code($core.String value) => $_setString(6, value);