code property
The code that needs to be used to retrieve the magic link
Implementation
@$pb.TagNumber(1)
$core.String get code => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set code($core.String value) => $_setString(0, value);
The code that needs to be used to retrieve the magic link
@$pb.TagNumber(1)
$core.String get code => $_getSZ(0);
@$pb.TagNumber(1)
set code($core.String value) => $_setString(0, value);