domainPrefix property

  1. @TagNumber.new(100)
String get domainPrefix

The optional domain prefix that is used to generate the magic link. If this is empty, then the default authless access domain is used. This is useful in case the URL needs to point at a custom domain.

Implementation

@$pb.TagNumber(100)
$core.String get domainPrefix => $_getSZ(5);
  1. @TagNumber.new(100)
set domainPrefix (String value)

Implementation

@$pb.TagNumber(100)
set domainPrefix($core.String value) => $_setString(5, value);