NotesServiceFilterReq class

Describes the base request payload of a filter search

Available extensions

Constructors

NotesServiceFilterReq({BOOL_FILTER? isActive, Int64? count, Int64? offset, SORT_ORDER? sortOrder, NOTE_SORT_KEY? sortKey, String? entityUuid, NOTE_LIFECYCLE? status, Int64? completedOnStart, Int64? completedOnEnd, String? title, Int64? projectId, Int64? employeeId, Int64? activityId, Int64? activityStatusId, Int64? creationTimestampStart, Int64? creationTimestampEnd, Int64? modificationTimestampStart, Int64? modificationTimestampEnd})
factory
NotesServiceFilterReq.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
NotesServiceFilterReq.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

activityId ↔ Int64
Filter by the associated activity ID
getter/setter pair
activityStatusId ↔ Int64
Filter by the associated activity status ID
getter/setter pair
completedOnEnd ↔ Int64
The end range of completed timestamp
getter/setter pair
completedOnStart ↔ Int64
The start range of completed timestamp
getter/setter pair
count ↔ Int64
The number of records that need to be sent in the response. Returns all records if it is set to -1
getter/setter pair
creationTimestampEnd ↔ Int64
The maximum timestamp that needs to be considered to filter by creation
getter/setter pair
creationTimestampStart ↔ Int64
The minimum timestamp that needs to be considered to filter by creation
getter/setter pair
employeeId ↔ Int64
The ID of the employee
getter/setter pair
entityUuid String
The entity UUID that is to be used to filter records
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isActive BOOL_FILTER
If true, then returns only active records. If false, then returns only inactive records
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
modificationTimestampEnd ↔ Int64
The maximum timestamp that needs to be considered to filter by modification
getter/setter pair
modificationTimestampStart ↔ Int64
The minimum timestamp that needs to be considered to filter by modification
getter/setter pair
offset ↔ Int64
The number that need to be offset by before fetching the records
getter/setter pair
projectId ↔ Int64
The ID of the associated project
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortKey NOTE_SORT_KEY
The sort key that is to be used to fetch the pagination response
getter/setter pair
sortOrder SORT_ORDER
The sort order that is to be used to fetch the pagination response
getter/setter pair
status NOTE_LIFECYCLE
The status of this note
getter/setter pair
title String
The title of the note
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearActivityId() → void
clearActivityStatusId() → void
clearCompletedOnEnd() → void
clearCompletedOnStart() → void
clearCount() → void
clearCreationTimestampEnd() → void
clearCreationTimestampStart() → void
clearEmployeeId() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIsActive() → void
clearModificationTimestampEnd() → void
clearModificationTimestampStart() → void
clearOffset() → void
clearProjectId() → void
clearSortKey() → void
clearSortOrder() → void
clearStatus() → void
clearTitle() → void
clone() NotesServiceFilterReq
Creates a deep copy of the fields in this message.
copyWith(void updates(NotesServiceFilterReq)) NotesServiceFilterReq
Apply updates to a copy of this message.
createEmptyInstance() NotesServiceFilterReq
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasActivityId() bool
hasActivityStatusId() bool
hasCompletedOnEnd() bool
hasCompletedOnStart() bool
hasCount() bool
hasCreationTimestampEnd() bool
hasCreationTimestampStart() bool
hasEmployeeId() bool
hasEntityUuid() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasIsActive() bool
hasModificationTimestampEnd() bool
hasModificationTimestampStart() bool
hasOffset() bool
hasProjectId() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSortKey() bool
hasSortOrder() bool
hasStatus() bool
hasTitle() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited