count property

  1. @TagNumber.new(2)
Int64 get count

The number of records that need to be sent in the response. Returns all records if it is set to -1

Implementation

@$pb.TagNumber(2)
$fixnum.Int64 get count => $_getI64(1);
  1. @TagNumber.new(2)
set count (Int64 value)

Implementation

@$pb.TagNumber(2)
set count($fixnum.Int64 value) => $_setInt64(1, value);