sortKey property
The sort key that is to be used to fetch the pagination response
Implementation
@$pb.TagNumber(5)
NOTE_SORT_KEY get sortKey => $_getN(4);
Implementation
@$pb.TagNumber(5)
set sortKey(NOTE_SORT_KEY value) => $_setField(5, value);
The sort key that is to be used to fetch the pagination response
@$pb.TagNumber(5)
NOTE_SORT_KEY get sortKey => $_getN(4);
@$pb.TagNumber(5)
set sortKey(NOTE_SORT_KEY value) => $_setField(5, value);