NotesServiceBase class abstract

Annotations
  • @GrpcServiceName.new('Scailo.NotesService')

Constructors

NotesServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
cancel(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierUUID>
cancel_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierUUID>
commentAdd(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierUUID>
commentAdd_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierUUID>
complete(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierUUID>
complete_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierUUID>
count(ServiceCall call, NotesServiceCountReq request) Future<CountResponse>
count_Pre(ServiceCall $call, Future<NotesServiceCountReq> $request) Future<CountResponse>
create(ServiceCall call, NotesServiceCreateRequest request) Future<IdentifierUUID>
create_Pre(ServiceCall $call, Future<NotesServiceCreateRequest> $request) Future<IdentifierUUID>
filter(ServiceCall call, NotesServiceFilterReq request) Future<NotesList>
filter_Pre(ServiceCall $call, Future<NotesServiceFilterReq> $request) Future<NotesList>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierUUID>
reopen_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierUUID>
repeat(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierUUID>
repeat_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierUUID>
searchAll(ServiceCall call, NotesServiceSearchAllReq request) Future<NotesList>
searchAll_Pre(ServiceCall $call, Future<NotesServiceSearchAllReq> $request) Future<NotesList>
sendEmail(ServiceCall call, IdentifierWithEmailAttributes request) Future<IdentifierUUID>
sendEmail_Pre(ServiceCall $call, Future<IdentifierWithEmailAttributes> $request) Future<IdentifierUUID>
toString() String
A string representation of this object.
inherited
update(ServiceCall call, NotesServiceUpdateRequest request) Future<IdentifierUUID>
update_Pre(ServiceCall $call, Future<NotesServiceUpdateRequest> $request) Future<IdentifierUUID>
viewAll(ServiceCall call, ActiveStatus request) Future<NotesList>
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request) Future<NotesList>
viewAllForEntityUUID(ServiceCall call, IdentifierUUID request) Future<NotesList>
viewAllForEntityUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<NotesList>
viewByID(ServiceCall call, Identifier request) Future<Note>
viewByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<Note>
viewByUUID(ServiceCall call, IdentifierUUID request) Future<Note>
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<Note>
viewEssentialByID(ServiceCall call, Identifier request) Future<Note>
viewEssentialByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<Note>
viewEssentialByUUID(ServiceCall call, IdentifierUUID request) Future<Note>
viewEssentialByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<Note>
viewFromIDs(ServiceCall call, IdentifiersList request) Future<NotesList>
viewFromIDs_Pre(ServiceCall $call, Future<IdentifiersList> $request) Future<NotesList>
viewWithPagination(ServiceCall call, NotesServicePaginationReq request) Future<NotesServicePaginationResponse>
viewWithPagination_Pre(ServiceCall $call, Future<NotesServicePaginationReq> $request) Future<NotesServicePaginationResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited