sdk/payroll_groups.scailo.pbgrpc library
Classes
- PAYROLL_GROUP_ITEM_VALUE_TYPE
- Describes the available input types for a payroll group item (with possible vbalues being percentage or fixed)
- PAYROLL_GROUP_SORT_KEY
- Describes the available sort keys
- PayrollGroup
- Describes the parameters that are part of a standard response
- PayrollGroupItem
- Describes the parameters that constitute a param associated to a payroll group
- PayrollGroupItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the record
- PayrollGroupsItemsList
- Describes the message consisting of the list of payroll group params
- PayrollGroupsList
- Describes the message consisting of the list of payroll groups
- PayrollGroupsServiceBase
- PayrollGroupsServiceClient
- Describes the common methods applicable on each payroll group
- PayrollGroupsServiceCountReq
- Describes the base request payload of a count search
- PayrollGroupsServiceCreateRequest
- Describes the parameters necessary to create a record
- PayrollGroupsServiceFilterReq
- Describes the base request payload of a filter search
- PayrollGroupsServiceItemCreateRequest
- Describes the parameters required to add a param to a payroll group
- PayrollGroupsServiceItemUpdateRequest
- Describes the parameters required to update a param in a payroll group
- PayrollGroupsServicePaginationReq
- Describes a pagination request to retrieve records
- PayrollGroupsServicePaginationResponse
- Describes the response to a pagination request
- PayrollGroupsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- PayrollGroupsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.