PayrollGroupsServiceClient class
Describes the common methods applicable on each payroll group
- Annotations
-
- @GrpcServiceName.new('Scailo.PayrollGroupsService')
Constructors
-
PayrollGroupsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addPayrollGroupItem(
PayrollGroupsServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add a param to a payroll group
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approvePayrollGroupItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve a param in a payroll group
-
clone(
CloneRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Clone payroll group from an existing payroll group (denoted by the identifier)
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
PayrollGroupsServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
PayrollGroupsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
deletePayrollGroupItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete a param in a payroll group
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
PayrollGroupsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadItemsAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
-
downloadItemsTemplateAsCSV(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload items
-
draft(
PayrollGroupsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
PayrollGroupsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
PayrollGroupsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< PayrollGroupsList> - View all that match the given filter criteria
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
importFromCSV(
StandardFile request, {CallOptions? options}) → ResponseFuture< IdentifierUUIDsList> - Import records using a CSV file (duplicate codes will be skipped)
-
modifyPayrollGroupItem(
PayrollGroupsServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify a param in a payroll group
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderPayrollGroupItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder params in a payroll group
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
PayrollGroupsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
PayrollGroupsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< PayrollGroupsList> - View all that match the given search key
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadPayrollGroupItems(
IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture< IdentifiersList> - Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< PayrollGroupsList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< PayrollGroupsList> - View all with the given entity UUID
-
viewApprovedPayrollGroupItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< PayrollGroupsItemsList> - View approved payroll group params for given payroll group ID
-
viewByCode(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< PayrollGroup> - View by Code (returns the latest record in case of duplicates)
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< PayrollGroup> - View by ID
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< PayrollGroup> - View by UUID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< PayrollGroup> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< PayrollGroup> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< PayrollGroupsList> - View all records with the given IDs
-
viewPayrollGroupItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< PayrollGroupItem> - View Payroll Group Item by ID
-
viewPayrollGroupItemHistory(
PayrollGroupItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< PayrollGroupsItemsList> - View the history of the payroll group item
-
viewUnapprovedPayrollGroupItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< PayrollGroupsItemsList> - View unapproved payroll group params for given payroll group ID
-
viewWithPagination(
PayrollGroupsServicePaginationReq request, {CallOptions? options}) → ResponseFuture< PayrollGroupsServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.