sdk/production_indents.scailo.pb library

Classes

PRODUCTION_INDENT_INDENT_REF_FOR
Stores all the possible indent references from which a production indent can be added
PRODUCTION_INDENT_ITEM_SORT_KEY
Describes the available sort keys
PRODUCTION_INDENT_ITEM_STATUS
Describes the applicable statuses of production indent items
PRODUCTION_INDENT_PRODUCTION_REF_FOR
Stores all the possible production references from which a production indent can be added
PRODUCTION_INDENT_SORT_KEY
Describes the available sort keys
ProductionIndent
Describes the parameters that are part of a standard response
ProductionIndentIssuedStatistics
Describes the issued statistics of the production indent
ProductionIndentIssuedStatisticsList
Describes the list of issued statistics of the production indent
ProductionIndentItem
Describes the parameters that constitute an item associated to a production indent
ProductionIndentItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
ProductionIndentItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective production indent item
ProductionIndentItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
ProductionIndentsItemsList
Describes the message consisting of the list of production indent items
ProductionIndentsList
Describes the message consisting of the list of production indents
ProductionIndentsServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
ProductionIndentsServiceCountReq
Describes the base request payload of a count search
ProductionIndentsServiceCreateRequest
Describes the parameters necessary to create a record
ProductionIndentsServiceFilterReq
Describes the base request payload of a filter search
ProductionIndentsServiceItemCreateRequest
Describes the parameters required to add an item to a production indent
ProductionIndentsServiceItemUpdateRequest
Describes the parameters required to update an item in a production indent
ProductionIndentsServicePaginatedItemsResponse
Describes the response to a pagination items request
ProductionIndentsServicePaginationReq
Describes a pagination request to retrieve records
ProductionIndentsServicePaginationResponse
Describes the response to a pagination request
ProductionIndentsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ProductionIndentsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.