sdk/production_plans.scailo.pb library

Classes

PRODUCTION_PLAN_ITEM_SORT_KEY
Describes the available sort keys
PRODUCTION_PLAN_ITEM_STATUS
Describes the applicable statuses of production plan items
PRODUCTION_PLAN_REF_FROM
Stores all the possible references from which a production plan can be added
PRODUCTION_PLAN_SORT_KEY
Describes the available sort keys
ProductionPlan
Describes the parameters that are part of a standard response
ProductionPlanAncillaryParameters
Stores the UUID references of the record
ProductionPlanItem
Describes the parameters that constitute an item associated to a production plan
ProductionPlanItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
ProductionPlanItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective production plan item
ProductionPlanItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
ProductionPlanProductionStatistics
Describes the production statistics of the production plan
ProductionPlanProductionStatisticsList
Describes the list of production statistics of the production plan
ProductionPlansItemsList
Describes the message consisting of the list of production plan items
ProductionPlansList
Describes the message consisting of the list of production plans
ProductionPlansServiceAlreadyAddedQuantityForSourceRequest
Describes the request payload to retrieve the quantity that has already been added for the specific ref_from, ref_id and family_id
ProductionPlansServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
ProductionPlansServiceCountReq
Describes the base request payload of a count search
ProductionPlansServiceCreateRequest
Describes the parameters necessary to create a record
ProductionPlansServiceFilterReq
Describes the base request payload of a filter search
ProductionPlansServiceItemCreateRequest
Describes the parameters required to add an item to a production plan
ProductionPlansServiceItemUpdateRequest
Describes the parameters required to update an item in a production plan
ProductionPlansServicePaginatedItemsResponse
Describes the response to a pagination items request
ProductionPlansServicePaginationReq
Describes a pagination request to retrieve records
ProductionPlansServicePaginationResponse
Describes the response to a pagination request
ProductionPlansServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ProductionPlansServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.