ProductionPlansServiceClient class

Describes the common methods applicable on each production plan

Annotations
  • @GrpcServiceName.new('Scailo.ProductionPlansService')

Constructors

ProductionPlansServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addProductionPlanItem(ProductionPlansServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an item to a production plan
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
approveProductionPlanItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve an item in a production plan
autofill(ProductionPlansServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Autofill the production plan
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Complete
count(ProductionPlansServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(ProductionPlansServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Create a magic link
deleteProductionPlanItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an item in a production plan
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(ProductionPlansServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
downloadByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download production plan with the given IdentifierUUID (can be used to allow public downloads)
downloadItemsAsCSV(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
downloadItemsTemplateAsCSV(Empty request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the CSV template that could be used to upload items
draft(ProductionPlansServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(ProductionPlansServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
filter(ProductionPlansServiceFilterReq request, {CallOptions? options}) → ResponseFuture<ProductionPlansList>
View all that match the given filter criteria
filterFamiliesInProductionPlan(FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture<FamiliesList>
Filter families (of all family types) for the given production plan
filterProspectiveFamilies(FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture<FamiliesList>
Filter prospective families for the record represented by the given UUID identifier
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
isCompletable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the Production Plan can be marked as completed
isDownloadable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the record is downloadable (checks if the custom download function has been implemented)
modifyProductionPlanItem(ProductionPlansServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Modify an item in a production plan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reopen
reorderProductionPlanItems(ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reorder items in a production plan
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Repeat
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(ProductionPlansServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(ProductionPlansServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<ProductionPlansList>
View all that match the given search key
searchItemsWithPagination(ProductionPlanItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<ProductionPlansServicePaginatedItemsResponse>
Search through production plan items with pagination
sendEmail(IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send Email
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
uploadProductionPlanItems(IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture<IdentifiersList>
Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAddedFamilyQuantityForSource(ProductionPlansServiceAlreadyAddedQuantityForSourceRequest request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
View already added quantities
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<ProductionPlansList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ProductionPlansList>
View all with the given entity UUID
viewAncillaryParametersByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ProductionPlanAncillaryParameters>
View the ancillary parameters (UUIDs of the internal references) by UUID
viewApprovedProductionPlanItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<ProductionPlansItemsList>
View approved production plan items for given production plan ID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<ProductionPlan>
View by ID
viewByReferenceID(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<ProductionPlan>
View by Reference ID (returns the latest record in case of duplicates)
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ProductionPlan>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<ProductionPlan>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ProductionPlan>
View only essential components (without logs) that matches the given UUID
viewFamiliesInProductionPlan(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<FamiliesList>
View families (of all family types) for the given production plan
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<ProductionPlansList>
View all records with the given IDs
viewPaginatedApprovedProductionPlanItems(ProductionPlanItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<ProductionPlansServicePaginatedItemsResponse>
View approved production plan items for given production plan ID with pagination
viewPaginatedUnapprovedProductionPlanItems(ProductionPlanItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<ProductionPlansServicePaginatedItemsResponse>
View unapproved production plan items for given production plan ID with pagination
viewProductionPlanItemByID(Identifier request, {CallOptions? options}) → ResponseFuture<ProductionPlanItem>
View Production Plan Item by ID
viewProductionPlanItemHistory(ProductionPlanItemHistoryRequest request, {CallOptions? options}) → ResponseFuture<ProductionPlansItemsList>
View the history of the production plan item
viewProductionStatistics(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ProductionPlanProductionStatisticsList>
View production statistics of the production plan (match with all the produced items)
viewProspectiveFamilies(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<FamiliesList>
View prospective families for the given production plan
viewProspectiveProductionPlanItem(ProductionPlanItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture<ProductionPlansServiceItemCreateRequest>
View prospective production plan item info for the given family ID and production plan ID
viewRemainingProductionQuantity(ProductionPlanItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture<QuantityResponse>
View the net quantity to be produced for the given family in the given production plan
viewUnapprovedProductionPlanItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<ProductionPlansItemsList>
View unapproved production plan items for given production plan ID
viewWithPagination(ProductionPlansServicePaginationReq request, {CallOptions? options}) → ResponseFuture<ProductionPlansServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.