sdk/projects.scailo.pb library
Classes
- Project
- Describes the parameters that are part of a standard response
- PROJECT_SORT_KEY
- Describes the available sort keys
- ProjectContact
- Describes the parameters that constitute a project contact
- ProjectContactsList
- Describes the message consisting of the list of project contacts
- ProjectsList
- Describes the message consisting of the list of records
- ProjectsServiceContactCreateRequest
- Describes the parameters necessary to create a project contact
- ProjectsServiceCountReq
- Describes the base request payload of a count search
- ProjectsServiceCreateRequest
- Describes the parameters necessary to create a record
- ProjectsServiceFilterReq
- Describes the base request payload of a filter search
- ProjectsServicePaginationReq
- Describes a pagination request to retrieve records
- ProjectsServicePaginationResponse
- Describes the response to a pagination request
- ProjectsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- ProjectsServiceUpdateRequest
- Describes the parameters necessary to update a record
- ProjectStatistics
- Describes the parameters that are part of a project's statistics payload
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.