totalCompletionPercentage property

  1. @TagNumber.new(2)
Int64 get totalCompletionPercentage

@description The cumulative progress of the project expressed as a percentage. Can have a range between 0 and 10000. A fully completed project would have a value of 10000.

@example 10000

Implementation

@$pb.TagNumber(2)
$fixnum.Int64 get totalCompletionPercentage => $_getI64(1);
  1. @TagNumber.new(2)
set totalCompletionPercentage (Int64 value)

Implementation

@$pb.TagNumber(2)
set totalCompletionPercentage($fixnum.Int64 value) => $_setInt64(1, value);