clientId property
- @TagNumber.new(22)
@optional
@description Filter projects assigned to a specific client. Explicitly set to -1 to bypass this filter and return all client records. 0 acts as a valid, concrete filter ID.
@example 455
@regex ^0-9*$
@format 64-bit integer that with a minimum value of -1.
Implementation
@$pb.TagNumber(22)
$fixnum.Int64 get clientId => $_getI64(15);
- @TagNumber.new(22)
Implementation
@$pb.TagNumber(22)
set clientId($fixnum.Int64 value) => $_setInt64(15, value);