notifyUsers property

  1. @TagNumber.new(3)
bool get notifyUsers

Optional boolean value that stores if a notification needs to be sent to users about the update to the record. This is useful when a subsequent operation needs to be performed immediately (such as send to verification after updating the revision)

Implementation

@$pb.TagNumber(3)
$core.bool get notifyUsers => $_getBF(2);
  1. @TagNumber.new(3)
set notifyUsers (bool value)

Implementation

@$pb.TagNumber(3)
set notifyUsers($core.bool value) => $_setBool(2, value);