ProjectsServiceBase class abstract

Annotations
  • @GrpcServiceName.new('Scailo.ProjectsService')

Constructors

ProjectsServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
addProjectContact(ServiceCall call, ProjectsServiceContactCreateRequest request) Future<IdentifierResponse>
addProjectContact_Pre(ServiceCall $call, Future<ProjectsServiceContactCreateRequest> $request) Future<IdentifierResponse>
approve(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
approve_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
approveProjectContact(ServiceCall call, IdentifierWithUserComment request) Future<IdentifierResponse>
approveProjectContact_Pre(ServiceCall $call, Future<IdentifierWithUserComment> $request) Future<IdentifierResponse>
commentAdd(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
commentAdd_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
complete(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
complete_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
count(ServiceCall call, ProjectsServiceCountReq request) Future<CountResponse>
count_Pre(ServiceCall $call, Future<ProjectsServiceCountReq> $request) Future<CountResponse>
countInStatus(ServiceCall call, CountInSLCStatusRequest request) Future<CountResponse>
countInStatus_Pre(ServiceCall $call, Future<CountInSLCStatusRequest> $request) Future<CountResponse>
create(ServiceCall call, ProjectsServiceCreateRequest request) Future<IdentifierResponse>
create_Pre(ServiceCall $call, Future<ProjectsServiceCreateRequest> $request) Future<IdentifierResponse>
deleteProjectContact(ServiceCall call, IdentifierWithUserComment request) Future<IdentifierResponse>
deleteProjectContact_Pre(ServiceCall $call, Future<IdentifierWithUserComment> $request) Future<IdentifierResponse>
discard(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
discard_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
downloadAsCSV(ServiceCall call, ProjectsServiceFilterReq request) Future<StandardFile>
downloadAsCSV_Pre(ServiceCall $call, Future<ProjectsServiceFilterReq> $request) Future<StandardFile>
draft(ServiceCall call, ProjectsServiceCreateRequest request) Future<IdentifierResponse>
draft_Pre(ServiceCall $call, Future<ProjectsServiceCreateRequest> $request) Future<IdentifierResponse>
draftUpdate(ServiceCall call, ProjectsServiceUpdateRequest request) Future<IdentifierResponse>
draftUpdate_Pre(ServiceCall $call, Future<ProjectsServiceUpdateRequest> $request) Future<IdentifierResponse>
filter(ServiceCall call, ProjectsServiceFilterReq request) Future<ProjectsList>
filter_Pre(ServiceCall $call, Future<ProjectsServiceFilterReq> $request) Future<ProjectsList>
halt(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
halt_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
reopen_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
repeat(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
repeat_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
restore(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
restore_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
revisionUpdate(ServiceCall call, ProjectsServiceUpdateRequest request) Future<IdentifierResponse>
revisionUpdate_Pre(ServiceCall $call, Future<ProjectsServiceUpdateRequest> $request) Future<IdentifierResponse>
searchAll(ServiceCall call, ProjectsServiceSearchAllReq request) Future<ProjectsList>
searchAll_Pre(ServiceCall $call, Future<ProjectsServiceSearchAllReq> $request) Future<ProjectsList>
sendEmail(ServiceCall call, IdentifierWithEmailAttributes request) Future<IdentifierResponse>
sendEmail_Pre(ServiceCall $call, Future<IdentifierWithEmailAttributes> $request) Future<IdentifierResponse>
sendForRevision(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForRevision_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
sendForVerification(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForVerification_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
toString() String
A string representation of this object.
inherited
verify(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
verify_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
viewAll(ServiceCall call, ActiveStatus request) Future<ProjectsList>
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request) Future<ProjectsList>
viewAllForEntityUUID(ServiceCall call, IdentifierUUID request) Future<ProjectsList>
viewAllForEntityUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ProjectsList>
viewByID(ServiceCall call, Identifier request) Future<Project>
viewByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<Project>
viewByUUID(ServiceCall call, IdentifierUUID request) Future<Project>
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<Project>
viewEssentialByID(ServiceCall call, Identifier request) Future<Project>
viewEssentialByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<Project>
viewEssentialByUUID(ServiceCall call, IdentifierUUID request) Future<Project>
viewEssentialByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<Project>
viewFromIDs(ServiceCall call, IdentifiersList request) Future<ProjectsList>
viewFromIDs_Pre(ServiceCall $call, Future<IdentifiersList> $request) Future<ProjectsList>
viewProjectContactByID(ServiceCall call, Identifier request) Future<ProjectContact>
viewProjectContactByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<ProjectContact>
viewProjectContacts(ServiceCall call, IdentifierUUID request) Future<ProjectContactsList>
viewProjectContacts_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ProjectContactsList>
viewStatistics(ServiceCall call, IdentifierUUID request) Future<ProjectStatistics>
viewStatistics_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ProjectStatistics>
viewWithPagination(ServiceCall call, ProjectsServicePaginationReq request) Future<ProjectsServicePaginationResponse>
viewWithPagination_Pre(ServiceCall $call, Future<ProjectsServicePaginationReq> $request) Future<ProjectsServicePaginationResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited