addProjectContact method

ResponseFuture<IdentifierResponse> addProjectContact(
  1. ProjectsServiceContactCreateRequest request, {
  2. CallOptions? options,
})

Associates a new personnel contact with an existing project.

Side Effects:

  • Validates the relationship between the project and employee.
  • Depending on system configurations, may place the new contact association into a pending approval state.

Implementation

$grpc.ResponseFuture<$1.IdentifierResponse> addProjectContact(
  $0.ProjectsServiceContactCreateRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$addProjectContact, request, options: options);
}