approveProjectContact method

ResponseFuture<IdentifierResponse> approveProjectContact(
  1. IdentifierWithUserComment request, {
  2. CallOptions? options,
})

Approves a pending project contact record, finalizing its integration into the project roster.

Side Effects:

  • Activates the contact mapping within the system.
  • Appends the required approval metadata and audit comment to the record history.

Implementation

$grpc.ResponseFuture<$1.IdentifierResponse> approveProjectContact(
  $1.IdentifierWithUserComment request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$approveProjectContact, request, options: options);
}