deleteProjectContact method
ResponseFuture<IdentifierResponse>
deleteProjectContact(
- IdentifierWithUserComment request, {
- CallOptions? options,
Permanently removes or deactivates a contact association from a project.
Side Effects:
- Revokes project-specific context and access linked to this contact association.
- Logs the deletion justification comment into the system compliance log.
Implementation
$grpc.ResponseFuture<$1.IdentifierResponse> deleteProjectContact(
$1.IdentifierWithUserComment request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$deleteProjectContact, request, options: options);
}