reopen method
ResponseFuture<IdentifierResponse>
reopen(
- IdentifierUUIDWithUserComment request, {
- CallOptions? options,
Reopens a finalized or closed record for further modifications.
Status Transition: -> REVISION
Side Effects:
- Unlocks the record to allow edits.
- Logs the required user comment into the audit trail for compliance tracking.
Implementation
$grpc.ResponseFuture<$1.IdentifierResponse> reopen(
$1.IdentifierUUIDWithUserComment request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$reopen, request, options: options);
}