sdk/purchases_indents.scailo.pb library

Classes

PURCHASE_INDENT_ITEM_SORT_KEY
Describes the available sort keys
PURCHASE_INDENT_ITEM_STATUS
Describes the applicable statuses of purchase indent items
PURCHASE_INDENT_SORT_KEY
Describes the available sort keys
PurchaseIndent
Describes the parameters that are part of a standard response
PurchaseIndentItem
Describes the parameters that constitute an item associated to a purchase indent
PurchaseIndentItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
PurchaseIndentItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective purchase indent item
PurchaseIndentItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
PurchaseIndentOrderedStatistics
Describes the ordered statistics of the purchase indent
PurchaseIndentOrderedStatisticsList
Describes the list of ordered statistics of the purchase indent
PurchasesIndentsItemsList
Describes the message consisting of the list of purchase indent items
PurchasesIndentsList
Describes the message consisting of the list of purchases indents
PurchasesIndentsServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
PurchasesIndentsServiceCountReq
Describes the base request payload of a count search
PurchasesIndentsServiceCreateRequest
Describes the parameters necessary to create a record
PurchasesIndentsServiceFilterReq
Describes the base request payload of a filter search
PurchasesIndentsServiceItemCreateRequest
Describes the parameters required to add an item to a purchase indent
PurchasesIndentsServiceItemSpecificationsUpdateRequest
Describes the parameters required to update the specifications of an item in a purchase indent
PurchasesIndentsServiceItemUpdateRequest
Describes the parameters required to update an item in a purchase indent
PurchasesIndentsServiceMultipleItemsCreateRequest
Describes the parameters required to add multiple items to a purchase indent
PurchasesIndentsServiceMultipleItemsSingleton
Describes the parameters required to add an individual item as part of multiple item addition to a purchase indent
PurchasesIndentsServicePaginatedItemsResponse
Describes the response to a pagination items request
PurchasesIndentsServicePaginationReq
Describes a pagination request to retrieve records
PurchasesIndentsServicePaginationResponse
Describes the response to a pagination request
PurchasesIndentsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
PurchasesIndentsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.