PurchasesOrdersServiceClient class

Describes the common methods applicable on each purchase order

Annotations
  • @GrpcServiceName.new('Scailo.PurchasesOrdersService')

Constructors

PurchasesOrdersServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
accruedValue(PurchasesOrdersServiceCountReq request, {CallOptions? options}) → ResponseFuture<SumResponse>
Returns the sum of the total value of all the records that match the given criteria
addMultiplePurchaseOrderItems(PurchasesOrdersServiceMultipleItemsCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add multiple items to a purchase order
addPurchaseOrderContact(PurchasesOrdersServiceContactCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add a contact
addPurchaseOrderItem(PurchasesOrdersServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an item to a purchase order
addPurchaseOrderReference(PurchasesOrdersServiceReferenceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add a reference
amend(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Amend the purchase order and send for revision
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
approvePurchaseOrderContact(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve a contact
approvePurchaseOrderItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve an item in a purchase order
approvePurchaseOrderReference(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve a reference
autofill(PurchasesOrdersServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Autofill the purchase order
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Complete
count(PurchasesOrdersServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(PurchasesOrdersServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Create a magic link
deletePurchaseOrderContact(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete a contact
deletePurchaseOrderItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an item in a purchase order
deletePurchaseOrderReference(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete a reference
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(PurchasesOrdersServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
downloadByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download purchase order with the given IdentifierUUID (can be used to allow public downloads)
downloadItemsAsCSV(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
downloadItemsTemplateAsCSV(Empty request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the CSV template that could be used to upload items
draft(PurchasesOrdersServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(PurchasesOrdersServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
filter(PurchasesOrdersServiceFilterReq request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersList>
View all that match the given filter criteria
filterProspectiveFamilies(FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture<FamiliesList>
Filter prospective families for the record represented by the given UUID identifier
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
isDownloadable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the record is downloadable (checks if the custom download function has been implemented)
modifyPurchaseOrderItem(PurchasesOrdersServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Modify an item in a purchase order
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reopen
reorderPurchaseOrderItems(ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reorder items in a purchase order
repeat(RepeatWithDeliveryDate request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Repeat
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(PurchasesOrdersServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(PurchasesOrdersServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersList>
View all that match the given search key
searchItemsWithPagination(PurchaseOrderItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersServicePaginatedItemsResponse>
Search through purchase order items with pagination
sendEmail(IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send Email
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
updatePurchaseOrderItemSpecifications(PurchasesOrdersServiceItemSpecificationsUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update specifications of an item in a purchase order
uploadPurchaseOrderItems(IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture<IdentifiersList>
Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersList>
View all with the given entity UUID
viewAmendments(Identifier request, {CallOptions? options}) → ResponseFuture<AmendmentLogsList>
View all the amendments made
viewAncillaryParametersByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchaseOrderAncillaryParameters>
View the ancillary parameters (UUIDs of the internal references) by UUID
viewApprovedPurchaseOrderItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<PurchaseOrderItemsList>
View approved purchase order items for given purchase order ID
viewBillingStatistics(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchaseOrderBillingStatistics>
View Billing Statistics of Purchase Order
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<PurchaseOrder>
View by ID
viewByReferenceID(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<PurchaseOrder>
View by Reference ID (returns the latest record in case of duplicates)
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchaseOrder>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<PurchaseOrder>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchaseOrder>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersList>
View all records with the given IDs
viewInventoryMatch(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchaseOrderInventoryMatchList>
View Inventory Match of all the families within a Purchase Order
viewInventoryStatistics(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchaseOrderInventoryStatistics>
View Inventory Statistics of Purchase Order
viewPaginatedApprovedPurchaseOrderItems(PurchaseOrderItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersServicePaginatedItemsResponse>
View approved purchase order items for given purchase order ID with pagination
viewPaginatedUnapprovedPurchaseOrderItems(PurchaseOrderItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersServicePaginatedItemsResponse>
View unapproved purchase order items for given purchase order ID with pagination
viewPriceMatch(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchaseOrderPriceMatchList>
View Price Match of all the families within a Purchase Order (between the purchase order, and the corresponding vendor invoices, and any corresponding debit notes)
viewProspectiveFamilies(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<FamiliesList>
View prospective families for the given purchase order
viewProspectivePurchaseOrderItem(PurchaseOrderItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersServiceItemCreateRequest>
View prospective purchase order item info for the given family ID and purchase order ID
viewPurchaseOrderContactByID(Identifier request, {CallOptions? options}) → ResponseFuture<PurchaseOrderContact>
View a contact for the given ID
viewPurchaseOrderContacts(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<PurchaseOrderContactsList>
View all contacts for given purchase order UUID
viewPurchaseOrderItemByID(Identifier request, {CallOptions? options}) → ResponseFuture<PurchaseOrderItem>
View Purchase Order Item by ID
viewPurchaseOrderItemHistory(PurchaseOrderItemHistoryRequest request, {CallOptions? options}) → ResponseFuture<PurchaseOrderItemsList>
View the history of the purchase order item
viewPurchaseOrderItemPrice(PurchaseOrderItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture<PriceResponse>
View Purchase Order Item's price after factoring in the discount
viewPurchaseOrderReferenceByID(Identifier request, {CallOptions? options}) → ResponseFuture<PurchaseOrderReference>
View a reference for the given ID
viewPurchaseOrderReferences(Identifier request, {CallOptions? options}) → ResponseFuture<PurchaseOrderReferencesList>
View all references for given purchase order ID
viewUnapprovedPurchaseOrderItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<PurchaseOrderItemsList>
View unapproved purchase order items for given purchase order ID
viewWithPagination(PurchasesOrdersServicePaginationReq request, {CallOptions? options}) → ResponseFuture<PurchasesOrdersServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.