sdk/purchases_payments.scailo.pb library

Classes

PURCHASE_PAYMENT_SORT_KEY
Describes the available sort keys
PurchasePayment
Describes the parameters that are part of a standard response
PurchasePaymentAncillaryParameters
Stores the UUID references of the record
PurchasesPaymentsList
Describes the message consisting of the list of records
PurchasesPaymentsServiceCountReq
Describes the base request payload of a count search
PurchasesPaymentsServiceCreateRequest
Describes the parameters necessary to create a record
PurchasesPaymentsServiceFilterReq
Describes the base request payload of a filter search
PurchasesPaymentsServicePaginationReq
Describes a pagination request to retrieve records
PurchasesPaymentsServicePaginationResponse
Describes the response to a pagination request
PurchasesPaymentsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
PurchasesPaymentsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.