sdk/purchases_returns.scailo.pb library

Classes

PURCHASE_RETURN_BILLING_STATUS
Describes the available billing statuses
PURCHASE_RETURN_ITEM_SORT_KEY
Describes the available sort keys
PURCHASE_RETURN_ITEM_STATUS
Describes the applicable statuses of purchase return items
PURCHASE_RETURN_REF_FROM
Stores all the possible references from which a purchase return can be added
PURCHASE_RETURN_SORT_KEY
Describes the available sort keys
PurchaseReturn
Describes the parameters that are part of a standard response
PurchaseReturnAncillaryParameters
Stores the UUID references of the record
PurchaseReturnItem
Describes the parameters that constitute an item associated to a purchase return
PurchaseReturnItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
PurchaseReturnItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective purchase return item
PurchaseReturnItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
PurchasesReturnsItemsList
Describes the message consisting of the list of purchase return items
PurchasesReturnsList
Describes the message consisting of the list of purchases returns
PurchasesReturnsServiceAlreadyAddedQuantityForSourceRequest
Describes the request payload to retrieve the quantity that has already been added for the specific ref_from, ref_id and family_id
PurchasesReturnsServiceCountReq
Describes the base request payload of a count search
PurchasesReturnsServiceCreateRequest
Describes the parameters necessary to create a record
PurchasesReturnsServiceFilterReq
Describes the base request payload of a filter search
PurchasesReturnsServiceItemCreateRequest
Describes the parameters required to add an item to a purchase return
PurchasesReturnsServiceItemUpdateRequest
Describes the parameters required to update an item in a purchase return
PurchasesReturnsServicePaginatedItemsResponse
Describes the response to a pagination items request
PurchasesReturnsServicePaginationReq
Describes a pagination request to retrieve records
PurchasesReturnsServicePaginationResponse
Describes the response to a pagination request
PurchasesReturnsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
PurchasesReturnsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.