sdk/qc_groups.scailo.pb library

Classes

QC_GROUP_ITEM_ACCEPTABLE_VALUE_TYPE
Describes the available input types for a qc group item (with possible vbalues being number-absolute, number-percentage, text-input, text-dropdown)
QC_GROUP_ITEM_SORT_KEY
Describes the available sort keys
QC_GROUP_ITEM_STATUS
Describes the applicable statuses of qc group items
QC_GROUP_SORT_KEY
Describes the available sort keys
QCGroup
Describes the parameters that are part of a standard response
QCGroupItem
Describes the parameters that constitute a param associated to a qc group
QCGroupItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
QCGroupItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
QCGroupsItemsList
Describes the message consisting of the list of qc group params
QCGroupsList
Describes the message consisting of the list of qc groups
QCGroupsServiceCountReq
Describes the base request payload of a count search
QCGroupsServiceCreateRequest
Describes the parameters necessary to create a record
QCGroupsServiceFilterReq
Describes the base request payload of a filter search
QCGroupsServiceItemCreateRequest
Describes the parameters required to add a param to a qc group
QCGroupsServiceItemUpdateRequest
Describes the parameters required to update a param in a qc group
QCGroupsServicePaginatedItemsResponse
Describes the response to a pagination items request
QCGroupsServicePaginationReq
Describes a pagination request to retrieve records
QCGroupsServicePaginationResponse
Describes the response to a pagination request
QCGroupsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
QCGroupsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.