textAcceptableValues property
The list of values that are acceptable in case the acceptable value type is text-input or text-dropdown
Implementation
@$pb.TagNumber(30)
$pb.PbList<$core.String> get textAcceptableValues => $_getList(9);
The list of values that are acceptable in case the acceptable value type is text-input or text-dropdown
@$pb.TagNumber(30)
$pb.PbList<$core.String> get textAcceptableValues => $_getList(9);