textUnacceptableValues property
The list of unacceptable values in case the acceptable value type is text-input or text-dropdown
Implementation
@$pb.TagNumber(32)
$pb.PbList<$core.String> get textUnacceptableValues => $_getList(11);
The list of unacceptable values in case the acceptable value type is text-input or text-dropdown
@$pb.TagNumber(32)
$pb.PbList<$core.String> get textUnacceptableValues => $_getList(11);