QCSample class

Describes the parameters that are part of a standard response

Available extensions

Constructors

QCSample({String? entityUuid, EmployeeMetadata? metadata, ApprovalMetadata? approvalMetadata, QC_SAMPLE_LIFECYCLE? status, Iterable<LogbookLogQCSampleLC>? logs, Int64? finishedOn, Int64? vaultFolderId, FAMILY_TYPE? familyType, Int64? familyId, String? inventoryItemUuid, Int64? qcGroupId, Int64? locationId, String? name, String? description})
factory
QCSample.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
QCSample.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

approvalMetadata ApprovalMetadata
Stores the approval metadata
getter/setter pair
description String
The description of the qc sample
getter/setter pair
entityUuid String
Stores a globally unique entity UUID. This will be set at the organization level
getter/setter pair
familyId ↔ Int64
The associated family ID
getter/setter pair
familyType FAMILY_TYPE
The associated family type
getter/setter pair
finishedOn ↔ Int64
The timestamp of when this qc sample was marked as finished
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
inventoryItemUuid String
The UUID of the inventory item
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
locationId ↔ Int64
The location ID of where the record is created
getter/setter pair
logs → PbList<LogbookLogQCSampleLC>
Stores the logs of every operation performed on this qc sample
no setter
metadata EmployeeMetadata
Stores the metadata of this qc sample
getter/setter pair
name String
The name of the qc sample (will be autogenerated if not provided)
getter/setter pair
qcGroupId ↔ Int64
The ID of the qc group
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status QC_SAMPLE_LIFECYCLE
The status of this qc sample
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
vaultFolderId ↔ Int64
The associated vault folder ID
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearApprovalMetadata() → void
clearDescription() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFamilyId() → void
clearFamilyType() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFinishedOn() → void
clearInventoryItemUuid() → void
clearLocationId() → void
clearMetadata() → void
clearName() → void
clearQcGroupId() → void
clearStatus() → void
clearVaultFolderId() → void
clone() QCSample
Creates a deep copy of the fields in this message.
copyWith(void updates(QCSample)) QCSample
Apply updates to a copy of this message.
createEmptyInstance() QCSample
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureApprovalMetadata() ApprovalMetadata
ensureMetadata() EmployeeMetadata
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasApprovalMetadata() bool
hasDescription() bool
hasEntityUuid() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFamilyId() bool
hasFamilyType() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFinishedOn() bool
hasInventoryItemUuid() bool
hasLocationId() bool
hasMetadata() bool
hasName() bool
hasQcGroupId() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasStatus() bool
hasVaultFolderId() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() QCSample
getDefault() QCSample