logs property
Stores the logs of every operation performed on this qc sample
Implementation
@$pb.TagNumber(5)
$pb.PbList<LogbookLogQCSampleLC> get logs => $_getList(4);
Stores the logs of every operation performed on this qc sample
@$pb.TagNumber(5)
$pb.PbList<LogbookLogQCSampleLC> get logs => $_getList(4);