isInternal property
Denotes if this parameter is internal or not (if set to true, then this value will be hidden. If set to false, then this value will be printed)
Implementation
@$pb.TagNumber(19)
$core.bool get isInternal => $_getBF(10);
Implementation
@$pb.TagNumber(19)
set isInternal($core.bool value) => $_setBool(10, value);