QCSamplesServiceFilterReq class

Describes the base request payload of a filter search

Available extensions

Constructors

QCSamplesServiceFilterReq({BOOL_FILTER? isActive, Int64? count, Int64? offset, SORT_ORDER? sortOrder, QC_SAMPLE_SORT_KEY? sortKey, String? entityUuid, QC_SAMPLE_LIFECYCLE? status, Int64? finishedOnStart, Int64? finishedOnEnd, FAMILY_TYPE? familyType, Int64? familyId, Int64? qcGroupId, String? inventoryItemUuid, Int64? locationId, Int64? productionPlanId, Int64? goodsReceiptId, Int64? inwardJobFreeIssueMaterialId, Int64? vendorId, Int64? buyerClientId, Int64? creationTimestampStart, Int64? creationTimestampEnd, Int64? modificationTimestampStart, Int64? modificationTimestampEnd})
factory
QCSamplesServiceFilterReq.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
QCSamplesServiceFilterReq.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

buyerClientId ↔ Int64
The associated buyer client ID of the linked sales order
getter/setter pair
count ↔ Int64
The number of records that need to be sent in the response. Returns all records if it is set to -1
getter/setter pair
creationTimestampEnd ↔ Int64
The maximum timestamp that needs to be considered to filter by creation
getter/setter pair
creationTimestampStart ↔ Int64
The minimum timestamp that needs to be considered to filter by creation
getter/setter pair
entityUuid String
The entity UUID that is to be used to filter records
getter/setter pair
familyId ↔ Int64
The associated family ID
getter/setter pair
familyType FAMILY_TYPE
The associated family type
getter/setter pair
finishedOnEnd ↔ Int64
The end range of finished timestamp
getter/setter pair
finishedOnStart ↔ Int64
The start range of finished timestamp
getter/setter pair
goodsReceiptId ↔ Int64
The associated goods receipt ID
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
inventoryItemUuid String
The UUID of the inventory item
getter/setter pair
inwardJobFreeIssueMaterialId ↔ Int64
The associated inward job free issue material ID
getter/setter pair
isActive BOOL_FILTER
If true, then returns only active records. If false, then returns only inactive records
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
locationId ↔ Int64
The location ID of where the record is created
getter/setter pair
modificationTimestampEnd ↔ Int64
The maximum timestamp that needs to be considered to filter by modification
getter/setter pair
modificationTimestampStart ↔ Int64
The minimum timestamp that needs to be considered to filter by modification
getter/setter pair
offset ↔ Int64
The number that need to be offset by before fetching the records
getter/setter pair
productionPlanId ↔ Int64
getter/setter pair
qcGroupId ↔ Int64
The ID of the qc group
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortKey QC_SAMPLE_SORT_KEY
The sort key that is to be used to fetch the pagination response
getter/setter pair
sortOrder SORT_ORDER
The sort order that is to be used to fetch the pagination response
getter/setter pair
status QC_SAMPLE_LIFECYCLE
The status of this qc sample
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
vendorId ↔ Int64
The associated vendor ID
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBuyerClientId() → void
clearCount() → void
clearCreationTimestampEnd() → void
clearCreationTimestampStart() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFamilyId() → void
clearFamilyType() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFinishedOnEnd() → void
clearFinishedOnStart() → void
clearGoodsReceiptId() → void
clearInventoryItemUuid() → void
clearInwardJobFreeIssueMaterialId() → void
clearIsActive() → void
clearLocationId() → void
clearModificationTimestampEnd() → void
clearModificationTimestampStart() → void
clearOffset() → void
clearProductionPlanId() → void
clearQcGroupId() → void
clearSortKey() → void
clearSortOrder() → void
clearStatus() → void
clearVendorId() → void
clone() QCSamplesServiceFilterReq
Creates a deep copy of the fields in this message.
copyWith(void updates(QCSamplesServiceFilterReq)) QCSamplesServiceFilterReq
Apply updates to a copy of this message.
createEmptyInstance() QCSamplesServiceFilterReq
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasBuyerClientId() bool
hasCount() bool
hasCreationTimestampEnd() bool
hasCreationTimestampStart() bool
hasEntityUuid() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFamilyId() bool
hasFamilyType() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFinishedOnEnd() bool
hasFinishedOnStart() bool
hasGoodsReceiptId() bool
hasInventoryItemUuid() bool
hasInwardJobFreeIssueMaterialId() bool
hasIsActive() bool
hasLocationId() bool
hasModificationTimestampEnd() bool
hasModificationTimestampStart() bool
hasOffset() bool
hasProductionPlanId() bool
hasQcGroupId() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSortKey() bool
hasSortOrder() bool
hasStatus() bool
hasVendorId() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited