QCSamplesServiceClient class

Describes the common methods applicable on each qc sample

Annotations
  • @GrpcServiceName.new('Scailo.QCSamplesService')

Constructors

QCSamplesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
accept(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Accept
acceptWithDeviation(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Accept With Deviation
cancel(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Cancel
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
count(QCSamplesServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
countsForInventoryItem(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QCSamplesCountStatistics>
Count all the qc samples in various statuses for the inventory item with the given UUID
create(QCSamplesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUIDsList>
Create
Create a magic link
downloadAsCSV(QCSamplesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
downloadByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download qc sample with the given IdentifierUUID (can be used to allow public downloads)
downloadParametersAsCSV(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of parameters in each qc sample represented by the given identifier UUID
filter(QCSamplesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<QCSamplesList>
View all that match the given filter criteria
finish(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Finish
isDownloadable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the record is downloadable (checks if the custom download function has been implemented)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reject(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reject
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reopen
searchAll(QCSamplesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<QCSamplesWithMetadataList>
View all that match the given search key
searchParametersWithPagination(QCSampleParametersSearchRequest request, {CallOptions? options}) → ResponseFuture<QCSamplesServicePaginatedParametersResponse>
Search through qc sample parameters with pagination
sendEmail(IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send Email
toString() String
A string representation of this object.
inherited
update(QCSamplesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update
updateParameter(QCSamplesServiceParameterUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Modify an parameter in a qc sample
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<QCSamplesList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QCSamplesList>
View all with the given entity UUID
viewAncillaryParametersByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QCSampleAncillaryParameters>
View the ancillary parameters (UUIDs of the internal references) by UUID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<QCSample>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QCSample>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<QCSample>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QCSample>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<QCSamplesList>
View all records with the given IDs
viewPaginatedParameters(QCSampleParametersSearchRequest request, {CallOptions? options}) → ResponseFuture<QCSamplesServicePaginatedParametersResponse>
View qc sample parameters for given qc sample ID with pagination
viewParameterByID(Identifier request, {CallOptions? options}) → ResponseFuture<QCSampleParameter>
View QCSample Parameter by ID
viewParameterHistory(QCSampleParameterHistoryRequest request, {CallOptions? options}) → ResponseFuture<QCSampleParameterHistoryList>
View the history of the qc sample parameter
viewParameters(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QCSampleParametersList>
View all parameters for given qc sample UUID
viewWithPagination(QCSamplesServicePaginationReq request, {CallOptions? options}) → ResponseFuture<QCSamplesServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.