description property

  1. @TagNumber.new(20)
String get description

@optional

@description A detailed text description outlining the purpose, context, or instructions specific to this section of the questionnaire.

@example "Section 1: Facility Safety and Compliance Guidelines"

@regex .*

@format Must be a non-empty string.

Implementation

@$pb.TagNumber(20)
$core.String get description => $_getSZ(7);
  1. @TagNumber.new(20)
set description (String value)

Implementation

@$pb.TagNumber(20)
set description($core.String value) => $_setString(7, value);