sdk/quotations_requests.scailo.pbgrpc library

Classes

QUOTATION_REQUEST_ITEM_SORT_KEY
Describes the available sort keys
QUOTATION_REQUEST_ITEM_STATUS
Describes the applicable statuses of quotation request items
QUOTATION_REQUEST_SORT_KEY
Describes the available sort keys
QuotationRequest
Describes the parameters that are part of a standard response
QuotationRequestAncillaryParameters
Stores the UUID references of the record
QuotationRequestItem
Describes the parameters that constitute an item associated to a quotation request
QuotationRequestItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
QuotationRequestItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
QuotationsRequestsItemsList
Describes the message consisting of the list of quotation request items
QuotationsRequestsList
Describes the message consisting of the list of quotations requests
QuotationsRequestsServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
QuotationsRequestsServiceBase
QuotationsRequestsServiceClient
Describes the common methods applicable on each quotation request
QuotationsRequestsServiceCountReq
Describes the base request payload of a count search
QuotationsRequestsServiceCreateRequest
Describes the parameters necessary to create a record
QuotationsRequestsServiceFilterReq
Describes the base request payload of a filter search
QuotationsRequestsServiceItemCreateRequest
Describes the parameters required to add an item to a quotation request
QuotationsRequestsServiceItemUpdateRequest
Describes the parameters required to update an item in a quotation request
QuotationsRequestsServicePaginatedItemsResponse
Describes the response to a pagination items request
QuotationsRequestsServicePaginationReq
Describes a pagination request to retrieve records
QuotationsRequestsServicePaginationResponse
Describes the response to a pagination request
QuotationsRequestsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
QuotationsRequestsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.