QuotationsRequestsServiceClient class

Describes the common methods applicable on each quotation request

Annotations
  • @GrpcServiceName.new('Scailo.QuotationsRequestsService')

Constructors

QuotationsRequestsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addQuotationRequestItem(QuotationsRequestsServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an item to a quotation request
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
approveQuotationRequestItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve an item in a quotation request
autofill(QuotationsRequestsServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Autofill the quotation request (from the associated purchase enquiry)
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Complete
count(QuotationsRequestsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(QuotationsRequestsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Create a magic link
deleteQuotationRequestItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an item in a quotation request
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(QuotationsRequestsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
downloadByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download quotation request with the given IdentifierUUID (can be used to allow public downloads)
downloadItemsAsCSV(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
downloadItemsTemplateAsCSV(Empty request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the CSV template that could be used to upload items
draft(QuotationsRequestsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(QuotationsRequestsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
filter(QuotationsRequestsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsList>
View all that match the given filter criteria
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
isDownloadable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the record is downloadable (checks if the custom download function has been implemented)
modifyQuotationRequestItem(QuotationsRequestsServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Modify an item in a quotation request
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reopen
reorderQuotationRequestItems(ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reorder items in a quotation request
repeat(RepeatWithDeliveryDate request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Repeat
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(QuotationsRequestsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(QuotationsRequestsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsList>
View all that match the given search key
searchItemsWithPagination(QuotationRequestItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsServicePaginatedItemsResponse>
Search through quotation request items with pagination
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
uploadQuotationRequestItems(IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture<IdentifiersList>
Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsList>
View all with the given entity UUID
viewAncillaryParametersByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QuotationRequestAncillaryParameters>
View the ancillary parameters (UUIDs of the internal references) by UUID
viewApprovedQuotationRequestItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsItemsList>
View approved quotation request items for given quotation request ID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<QuotationRequest>
View by ID
viewByReferenceID(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<QuotationRequest>
View by Reference ID (returns the latest record in case of duplicates)
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QuotationRequest>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<QuotationRequest>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<QuotationRequest>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsList>
View all records with the given IDs
viewPaginatedApprovedQuotationRequestItems(QuotationRequestItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsServicePaginatedItemsResponse>
View approved quotation request items for given quotation request ID with pagination
viewPaginatedUnapprovedQuotationRequestItems(QuotationRequestItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsServicePaginatedItemsResponse>
View unapproved quotation request items for given quotation request ID with pagination
viewQuotationRequestItemByID(Identifier request, {CallOptions? options}) → ResponseFuture<QuotationRequestItem>
View quotation request Item by ID
viewQuotationRequestItemHistory(QuotationRequestItemHistoryRequest request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsItemsList>
View the history of the quotation request item
viewUnapprovedQuotationRequestItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsItemsList>
View unapproved quotation request items for given quotation request ID
viewWithPagination(QuotationsRequestsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<QuotationsRequestsServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.