sdk/replaceable_indents.scailo.pb library

Classes

REPLACEABLE_INDENT_ITEM_SORT_KEY
Describes the available sort keys
REPLACEABLE_INDENT_ITEM_STATUS
Describes the applicable statuses of replaceable indent items
REPLACEABLE_INDENT_SORT_KEY
Describes the available sort keys
ReplaceableIndent
Describes the parameters that are part of a standard response
ReplaceableIndentIssuedStatistics
Describes the issued statistics of the replaceable indent
ReplaceableIndentIssuedStatisticsList
Describes the list of issued statistics of the replaceable indent
ReplaceableIndentItem
Describes the parameters that constitute an item associated to a replaceable indent
ReplaceableIndentItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
ReplaceableIndentItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective replaceable indent item
ReplaceableIndentItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
ReplaceableIndentsItemsList
Describes the message consisting of the list of replaceable indent items
ReplaceableIndentsList
Describes the message consisting of the list of replaceable indents
ReplaceableIndentsServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
ReplaceableIndentsServiceCountReq
Describes the base request payload of a count search
ReplaceableIndentsServiceCreateRequest
Describes the parameters necessary to create a record
ReplaceableIndentsServiceFilterReq
Describes the base request payload of a filter search
ReplaceableIndentsServiceItemCreateRequest
Describes the parameters required to add an item to a replaceable indent
ReplaceableIndentsServiceItemUpdateRequest
Describes the parameters required to update an item in a replaceable indent
ReplaceableIndentsServicePaginatedItemsResponse
Describes the response to a pagination items request
ReplaceableIndentsServicePaginationReq
Describes a pagination request to retrieve records
ReplaceableIndentsServicePaginationResponse
Describes the response to a pagination request
ReplaceableIndentsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ReplaceableIndentsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.