sdk/roles.scailo.pb library

Classes

Role
Describes the parameters that are part of a standard response
ROLE_SORT_KEY
Describes the available sort keys
RoleAccess
Describes the data structure of each role access on the platform
RolesList
Describes the message consisting of the list of roles
RolesServiceAccessCreateAndUpdateRequest
Describes the necessary data structure during creation/updation of a role access
RolesServiceAccessDefinition
Describes the parameters for a role definition
RolesServiceCountReq
Describes the base request payload of a count search
RolesServiceCreateRequest
Describes the parameters necessary to create a record
RolesServiceFilterReq
Describes the base request payload of a filter search
RolesServicePaginationReq
Describes a pagination request to retrieve records
RolesServicePaginationResponse
Describes the response to a pagination request
RolesServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
RolesServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.