sdk/sales_orders.scailo.pb library

Classes

SALES_ORDER_ITEM_SORT_KEY
Describes the available sort keys
SALES_ORDER_ITEM_STATUS
Describes the applicable statuses of sales order items
SALES_ORDER_REFERENCE_CONTEXT
Describes the sales order reference context
SALES_ORDER_REFERENCE_REF_FROM
Describes the possible options for ref_from field for a sales order reference
SALES_ORDER_SORT_KEY
Describes the available sort keys
SalesOrder
Describes the parameters that are part of a standard response
SalesOrderAncillaryParameters
Stores the UUID references of the record
SalesOrderBillingStatistics
Describes the parameters that are part of a sales order's billing statistics payload
SalesOrderContact
Describes the parameters that constitute a sales order contact
SalesOrderContactsList
Describes the message consisting of the list of sales order contacts
SalesOrderInventoryMatch
Describes the parameters that are part of a sales order's inventory match
SalesOrderInventoryMatchList
Describes the list of inventory match families
SalesOrderInventoryStatistics
Describes the parameters that are part of a sales order's inventory statistics payload
SalesOrderItem
Describes the parameters that constitute an item associated to a sales order
SalesOrderItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
SalesOrderItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective sales order item
SalesOrderItemsList
Describes the message consisting of the list of sales order items
SalesOrderItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
SalesOrderPriceMatch
Describes the parameters that are part of a sales order's price match
SalesOrderPriceMatchList
Describes the list of inventory match families
SalesOrderReference
Describes the parameters that constitute a sales order reference
SalesOrderReferencesList
Describes the message consisting of the list of sales order references
SalesOrdersList
Describes the message consisting of the list of sales orders
SalesOrdersServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
SalesOrdersServiceContactCreateRequest
Describes the parameters necessary to create a sales order contact
SalesOrdersServiceCountReq
Describes the base request payload of a count search
SalesOrdersServiceCreateRequest
Describes the parameters necessary to create a record
SalesOrdersServiceFilterReq
Describes the base request payload of a filter search
SalesOrdersServiceItemCreateRequest
Describes the parameters required to add an item to a sales order
SalesOrdersServiceItemSpecificationsUpdateRequest
Describes the parameters required to update the specifications of an item in a sales order
SalesOrdersServiceItemUpdateRequest
Describes the parameters required to update an item in a sales order
SalesOrdersServiceMultipleItemsCreateRequest
Describes the parameters required to add multiple items to a sales order
SalesOrdersServiceMultipleItemsSingleton
Describes the parameters required to add an individual item as part of multiple item addition to a sales order
SalesOrdersServicePaginatedItemsResponse
Describes the response to a pagination items request
SalesOrdersServicePaginationReq
Describes a pagination request to retrieve records
SalesOrdersServicePaginationResponse
Describes the response to a pagination request
SalesOrdersServiceReferenceCreateRequest
Describes the parameters necessary to create a sales order reference
SalesOrdersServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
SalesOrdersServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.