sdk/shifts.scailo.pbgrpc library

Classes

Shift
Describes the parameters that are part of a standard response
SHIFT_SORT_KEY
Describes the available sort keys
ShiftsList
Describes the message consisting of the list of records
ShiftsServiceBase
ShiftsServiceClient
Describes the common methods applicable on each shift
ShiftsServiceCountReq
Describes the base request payload of a count search
ShiftsServiceCreateRequest
Describes the parameters necessary to create a record
ShiftsServiceFilterReq
Describes the base request payload of a filter search
ShiftsServicePaginationReq
Describes a pagination request to retrieve records
ShiftsServicePaginationResponse
Describes the response to a pagination request
ShiftsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ShiftsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.