sdk/shifts_groups.scailo.pb library

Classes

SHIFT_GROUP_SORT_KEY
Describes the available sort keys
ShiftGroup
Describes the parameters that are part of a standard response
ShiftGroupShift
Describes the parameters that constitute a shift associated to a shift group
ShiftsGroupsList
Describes the message consisting of the list of shift groups
ShiftsGroupsServiceCountReq
Describes the base request payload of a count search
ShiftsGroupsServiceCreateRequest
Describes the parameters necessary to create a record
ShiftsGroupsServiceFilterReq
Describes the base request payload of a filter search
ShiftsGroupsServicePaginationReq
Describes a pagination request to retrieve records
ShiftsGroupsServicePaginationResponse
Describes the response to a pagination request
ShiftsGroupsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ShiftsGroupsServiceShiftGroupCreateRequest
Describes the parameters required to add a shift to a shift group
ShiftsGroupsServiceShiftGroupUpdateRequest
Describes the parameters required to update a shift in a shift group
ShiftsGroupsServiceUpdateRequest
Describes the parameters necessary to update a record
ShiftsGroupsShiftsHistoryRequest
Describes the parameters that are required to retrieve the history of the record
ShiftsGroupsShiftsList
Describes the message consisting of the list of shift group shifts

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.