sdk/stock_audits.scailo.pb library

Classes

STOCK_AUDIT_ITEM_SORT_KEY
Describes the available sort keys
STOCK_AUDIT_ITEM_STATUS
Describes the applicable statuses of stock audit items
STOCK_AUDIT_SORT_KEY
Describes the available sort keys
StockAudit
Describes the parameters that are part of a standard response
StockAuditItem
Describes the parameters that constitute an item associated to a stock audit
StockAuditItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
StockAuditItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective stock audit item
StockAuditItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
StockAuditsItemsList
Describes the message consisting of the list of stock audit items
StockAuditsList
Describes the message consisting of the list of stock audits
StockAuditsServiceCountReq
Describes the base request payload of a count search
StockAuditsServiceCreateRequest
Describes the parameters necessary to create a record
StockAuditsServiceFilterReq
Describes the base request payload of a filter search
StockAuditsServiceItemCreateRequest
Describes the parameters required to add an item to a stock audit
StockAuditsServiceItemUpdateRequest
Describes the parameters required to update an item in a stock audit
StockAuditsServicePaginatedItemsResponse
Describes the response to a pagination items request
StockAuditsServicePaginationReq
Describes a pagination request to retrieve records
StockAuditsServicePaginationResponse
Describes the response to a pagination request
StockAuditsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
StockAuditsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.