StockAuditsServiceClient class

Describes the common methods applicable on each stock audit

Annotations
  • @GrpcServiceName.new('Scailo.StockAuditsService')

Constructors

StockAuditsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addStockAuditItem(StockAuditsServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an item to a stock audit
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
approveStockAuditItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve an item in a stock audit
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Complete
count(StockAuditsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(StockAuditsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Create a magic link
deleteStockAuditItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an item in a stock audit
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(StockAuditsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
downloadByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download stock audit with the given IdentifierUUID (can be used to allow public downloads)
downloadItemsAsCSV(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
downloadItemsTemplateAsCSV(Empty request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the CSV template that could be used to upload items
downloadLabelByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the label for the stock audit with the given IdentifierUUID
draft(StockAuditsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(StockAuditsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
filter(StockAuditsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StockAuditsList>
View all that match the given filter criteria
filterProspectiveFamilies(FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture<FamiliesList>
Filter prospective families for the record represented by the given UUID identifier
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
isCompletable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the Stock Audit can be marked as completed
isDownloadable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the record is downloadable (checks if the custom download function has been implemented)
modifyStockAuditItem(StockAuditsServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Modify an item in a stock audit
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reopen
reorderStockAuditItems(ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reorder items in a stock audit
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Repeat
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(StockAuditsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(StockAuditsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<StockAuditsList>
View all that match the given search key
searchItemsWithPagination(StockAuditItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<StockAuditsServicePaginatedItemsResponse>
Search through stock audit items with pagination
sendEmail(IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send Email
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
uploadStockAuditItems(IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture<IdentifiersList>
Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<StockAuditsList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StockAuditsList>
View all with the given entity UUID
viewApprovedStockAuditItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<StockAuditsItemsList>
View approved stock audit items for given stock audit ID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<StockAudit>
View by ID
viewByReferenceID(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<StockAudit>
View by Reference ID (returns the latest record in case of duplicates)
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StockAudit>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<StockAudit>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StockAudit>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<StockAuditsList>
View all records with the given IDs
viewPaginatedApprovedStockAuditItems(StockAuditItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<StockAuditsServicePaginatedItemsResponse>
View approved stock audit items for given stock audit ID with pagination
viewPaginatedUnapprovedStockAuditItems(StockAuditItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<StockAuditsServicePaginatedItemsResponse>
View unapproved stock audit items for given stock audit ID with pagination
viewProspectiveFamilies(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<FamiliesList>
View prospective families for the given stock audit
viewProspectiveStockAuditItem(StockAuditItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture<StockAuditsServiceItemCreateRequest>
View prospective stock audit item info for the given family ID and stock audit ID
viewStockAuditItemByID(Identifier request, {CallOptions? options}) → ResponseFuture<StockAuditItem>
View Stock Audit Item by ID
viewStockAuditItemByInventoryHash(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<StockAuditItem>
View Stock Audit Item by Inventory Hash
viewStockAuditItemHistory(StockAuditItemHistoryRequest request, {CallOptions? options}) → ResponseFuture<StockAuditsItemsList>
View the history of the stock audit item
viewUnapprovedStockAuditItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<StockAuditsItemsList>
View unapproved stock audit items for given stock audit ID
viewWithPagination(StockAuditsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<StockAuditsServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.