sdk/supply_offers.scailo.pb library

Classes

SUPPLY_OFFER_ITEM_SORT_KEY
Describes the available sort keys
SUPPLY_OFFER_ITEM_STATUS
Describes the applicable statuses of supply offer items
SUPPLY_OFFER_SORT_KEY
Describes the available sort keys
SupplyOffer
Describes the parameters that are part of a standard response
SupplyOfferAncillaryParameters
Stores the UUID references of the record
SupplyOfferItem
Describes the parameters that constitute an item associated to a supply offer
SupplyOfferItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
SupplyOfferItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective supply offer item
SupplyOfferItemsList
Describes the message consisting of the list of supply offer items
SupplyOfferItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
SupplyOffersList
Describes the message consisting of the list of supply offers
SupplyOffersServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
SupplyOffersServiceCountReq
Describes the base request payload of a count search
SupplyOffersServiceCreateRequest
Describes the parameters necessary to create a record
SupplyOffersServiceFilterReq
Describes the base request payload of a filter search
SupplyOffersServiceItemCreateRequest
Describes the parameters required to add an item to a supply offer
SupplyOffersServiceItemUpdateRequest
Describes the parameters required to update an item in a supply offer
SupplyOffersServicePaginatedItemsResponse
Describes the response to a pagination items request
SupplyOffersServicePaginationReq
Describes a pagination request to retrieve records
SupplyOffersServicePaginationResponse
Describes the response to a pagination request
SupplyOffersServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
SupplyOffersServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.