TaxGroupsServiceClient class

Describes the common methods applicable on each tax group

Annotations
  • @GrpcServiceName.new('Scailo.TaxGroupsService')

Constructors

TaxGroupsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addTaxGroupItem(TaxGroupsServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add a param to a tax group
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
approveTaxGroupItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve a param in a tax group
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
count(TaxGroupsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(TaxGroupsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
deleteTaxGroupItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete a param in a tax group
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(TaxGroupsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
draft(TaxGroupsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(TaxGroupsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
filter(TaxGroupsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<TaxGroupsList>
View all that match the given filter criteria
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
importFromCSV(StandardFile request, {CallOptions? options}) → ResponseFuture<IdentifierUUIDsList>
Import records using a CSV file (duplicate codes will be skipped)
modifyTaxGroupItem(TaxGroupsServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Modify a param in a tax group
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reorderTaxGroupItems(ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reorder params in a tax group
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(TaxGroupsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(TaxGroupsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<TaxGroupsList>
View all that match the given search key
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<TaxGroupsList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<TaxGroupsList>
View all with the given entity UUID
viewApprovedTaxGroupItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<TaxGroupsItemsList>
View approved tax group params for given tax group ID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<TaxGroup>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<TaxGroup>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<TaxGroup>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<TaxGroup>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<TaxGroupsList>
View all records with the given IDs
viewTaxGroupItemByID(Identifier request, {CallOptions? options}) → ResponseFuture<TaxGroupItem>
View Tax Group Item by ID
viewTaxGroupItemHistory(TaxGroupItemHistoryRequest request, {CallOptions? options}) → ResponseFuture<TaxGroupsItemsList>
View the history of the tax group item
viewUnapprovedTaxGroupItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<TaxGroupsItemsList>
View unapproved tax group params for given tax group ID
viewWithPagination(TaxGroupsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<TaxGroupsServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.