sdk/tax_params.scailo.pb library

Classes

TAX_PARAM_CATEGORY
Describes the available categories for a tax param
TAX_PARAM_SORT_KEY
Describes the available sort keys
TAX_PARAM_VALUE_TYPE
Describes the available value types for a tax param
TaxParam
Describes the parameters that are part of a standard response
TaxParamsList
Describes the message consisting of the list of records
TaxParamsServiceCountReq
Describes the base request payload of a count search
TaxParamsServiceCreateRequest
Describes the parameters necessary to create a record
TaxParamsServiceFilterReq
Describes the base request payload of a filter search
TaxParamsServicePaginationReq
Describes a pagination request to retrieve records
TaxParamsServicePaginationResponse
Describes the response to a pagination request
TaxParamsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
TaxParamsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.