sdk/teams.scailo.pb library

Classes

Team
Describes the parameters that are part of a standard response
TEAM_MEMBER_SORT_KEY
Describes the available sort keys
TEAM_MEMBER_STATUS
Describes the applicable statuses of team members
TEAM_SORT_KEY
Describes the available sort keys
TeamMember
Describes the parameters that constitute a member associated to a team
TeamMemberHistoryRequest
Describes the parameters that are required to retrieve the history of the record
TeamMembersSearchRequest
Describes the request payload to retrieve approved or unapproved members.
TeamsList
Describes the message consisting of the list of teams
TeamsMembersList
Describes the message consisting of the list of team members
TeamsServiceCountReq
Describes the base request payload of a count search
TeamsServiceCreateRequest
Describes the parameters necessary to create a record
TeamsServiceFilterReq
Describes the base request payload of a filter search
TeamsServiceMemberCreateRequest
Describes the parameters required to add a member to a team
TeamsServiceMemberUpdateRequest
Describes the parameters required to update a member in a team
TeamsServicePaginatedMembersResponse
Describes the response to a pagination members request
TeamsServicePaginationReq
Describes a pagination request to retrieve records
TeamsServicePaginationResponse
Describes the response to a pagination request
TeamsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
TeamsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.