sdk/units_of_materials.scailo.pb library

Classes

UNIT_OF_MATERIAL_SORT_KEY
Describes the available sort keys
UnitOfMaterial
Describes the parameters that are part of a standard response
UnitsOfMaterialsList
Describes the message consisting of the list of records
UnitsOfMaterialsServiceCountReq
Describes the base request payload of a count search
UnitsOfMaterialsServiceCreateRequest
Describes the parameters necessary to create a record
UnitsOfMaterialsServiceFilterReq
Describes the base request payload of a filter search
UnitsOfMaterialsServicePaginationReq
Describes a pagination request to retrieve records
UnitsOfMaterialsServicePaginationResponse
Describes the response to a pagination request
UnitsOfMaterialsServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
UnitsOfMaterialsServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.