basicPayAmount property

  1. @TagNumber.new(56)
Int64 get basicPayAmount

@description The raw volume integer representing basic salary compensation. Critical: Value must be defined in the minor unit of the currency.

@example 500000

Implementation

@$pb.TagNumber(56)
$fixnum.Int64 get basicPayAmount => $_getI64(29);
  1. @TagNumber.new(56)
set basicPayAmount (Int64 value)

Implementation

@$pb.TagNumber(56)
set basicPayAmount($fixnum.Int64 value) => $_setInt64(29, value);