shiftGroupId property

  1. @TagNumber.new(50)
Int64 get shiftGroupId

@description The unique internal identifier of the operational work shift group mapped to this account profile for scheduling and timecard verification.

@example 45

Implementation

@$pb.TagNumber(50)
$fixnum.Int64 get shiftGroupId => $_getI64(23);
  1. @TagNumber.new(50)
set shiftGroupId (Int64 value)

Implementation

@$pb.TagNumber(50)
set shiftGroupId($fixnum.Int64 value) => $_setInt64(23, value);