shiftGroupId property

  1. @TagNumber.new(26)
Int64 get shiftGroupId

@optional

@description The unique internal identifier of the operational work shift group mapped to this account profile for scheduling and timecard verification.

@example 45

@regex ^0-9+$

@format Non-negative 64-bit integer. Defaults to 0 if unallocated.

Implementation

@$pb.TagNumber(26)
$fixnum.Int64 get shiftGroupId => $_getI64(14);
  1. @TagNumber.new(26)
set shiftGroupId (Int64 value)

Implementation

@$pb.TagNumber(26)
set shiftGroupId($fixnum.Int64 value) => $_setInt64(14, value);