basicPayAmount property

  1. @TagNumber.new(56)
Int64 get basicPayAmount

@optional

@description The raw volume integer representing basic salary compensation. Critical: Value must be defined in the minor unit of the currency.

@example 500000

@regex ^0-9+$

@format Non-negative 64-bit integer. For example, a value of 500000 in USD represents $5,000.00.

Implementation

@$pb.TagNumber(56)
$fixnum.Int64 get basicPayAmount => $_getI64(27);
  1. @TagNumber.new(56)
set basicPayAmount (Int64 value)

Implementation

@$pb.TagNumber(56)
set basicPayAmount($fixnum.Int64 value) => $_setInt64(27, value);