bloodGroup property
@optional
@description Medical identifier indicating the user's legal ABO blood group for emergency or corporate wellness logs.
@example "O+"
@regex ^(A|B|AB|O)+-$
@format Alphanumeric value containing classification type followed by rh factor sign.
Implementation
@$pb.TagNumber(37)
$core.String get bloodGroup => $_getSZ(20);
Implementation
@$pb.TagNumber(37)
set bloodGroup($core.String value) => $_setString(20, value);