code property
The unique employee code by which the user is classified
Implementation
@$pb.TagNumber(11)
$core.String get code => $_getSZ(5);
Implementation
@$pb.TagNumber(11)
set code($core.String value) => $_setString(5, value);
The unique employee code by which the user is classified
@$pb.TagNumber(11)
$core.String get code => $_getSZ(5);
@$pb.TagNumber(11)
set code($core.String value) => $_setString(5, value);