departmentId property
- @TagNumber.new(52)
@optional
@description The unique internal sequence identifier of the corporate Department or business unit to which the user is structurally assigned.
@example 304
@regex ^0-9+$
@format Non-negative 64-bit integer. Defaults to 0 for general or unassigned staff vectors.
Implementation
@$pb.TagNumber(52)
$fixnum.Int64 get departmentId => $_getI64(23);
- @TagNumber.new(52)
Implementation
@$pb.TagNumber(52)
set departmentId($fixnum.Int64 value) => $_setInt64(23, value);