payrollGroupId property

  1. @TagNumber.new(53)
Int64 get payrollGroupId

@optional

@description The unique internal identifier of the designated payroll distribution group used for localized batch processing and compensation disbursement.

@example 88

@regex ^0-9+$

@format Non-negative 64-bit integer. Defaults to 0 if unassigned.

Implementation

@$pb.TagNumber(53)
$fixnum.Int64 get payrollGroupId => $_getI64(24);
  1. @TagNumber.new(53)
set payrollGroupId (Int64 value)

Implementation

@$pb.TagNumber(53)
set payrollGroupId($fixnum.Int64 value) => $_setInt64(24, value);