shiftGroupId property
- @TagNumber.new(50)
@optional
@description The unique internal identifier of the operational work shift group mapped to this account profile for scheduling and timecard verification.
@example 45
@regex ^0-9+$
@format Non-negative 64-bit integer. Defaults to 0 if unallocated.
Implementation
@$pb.TagNumber(50)
$fixnum.Int64 get shiftGroupId => $_getI64(21);
- @TagNumber.new(50)
Implementation
@$pb.TagNumber(50)
set shiftGroupId($fixnum.Int64 value) => $_setInt64(21, value);