username property

  1. @TagNumber.new(10)
String get username

@mandatory

@description The unique system-level login alias used by the actor to authenticate against the platform.

@example "jane.doe"

@regex .+

@format Must be a non-empty string and completely unique across the given business entity space.

Implementation

@$pb.TagNumber(10)
$core.String get username => $_getSZ(4);
  1. @TagNumber.new(10)
set username (String value)

Implementation

@$pb.TagNumber(10)
set username($core.String value) => $_setString(4, value);