workEmail property

  1. @TagNumber.new(17)
String get workEmail

@optional

@description A secondary, fallback, or corporate work email address for overlapping communication loops.

@example "j.doe@corporate-hub.com"

@regex ^a-zA-Z0-9._%+-+@a-zA-Z0-9.-+.a-zA-Z{2,}$

@format If provided, must be a valid email address string.

Implementation

@$pb.TagNumber(17)
$core.String get workEmail => $_getSZ(11);
  1. @TagNumber.new(17)
set workEmail (String value)

Implementation

@$pb.TagNumber(17)
set workEmail($core.String value) => $_setString(11, value);