UsersServiceFilterReq class

Describes the base request payload of a filter search

Available extensions

Constructors

UsersServiceFilterReq({BOOL_FILTER? isActive, Int64? count, Int64? offset, SORT_ORDER? sortOrder, USER_SORT_KEY? sortKey, USER_TYPE? userType, String? entityUuid, STANDARD_LIFECYCLE_STATUS? status, Int64? approvedOnStart, Int64? approvedOnEnd, Int64? approvedByUserId, Int64? approverRoleId, String? username, String? name, String? code, String? email, String? phone, Int64? roleId, Int64? shiftGroupId, Int64? attendanceUomId, Int64? departmentId, Int64? payrollGroupId, Int64? payrollTaxGroupId, Int64? payrollCurrencyId, Int64? basicPayUomId, String? workEmail, Int64? vendorId, Int64? clientId, Int64? creationTimestampStart, Int64? creationTimestampEnd, Int64? modificationTimestampStart, Int64? modificationTimestampEnd, Iterable<FormFieldDatumFilterRequest>? formData})
factory
UsersServiceFilterReq.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
UsersServiceFilterReq.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

approvedByUserId ↔ Int64
The ID of the approver
getter/setter pair
approvedOnEnd ↔ Int64
The end range of approved timestamp
getter/setter pair
approvedOnStart ↔ Int64
The start range of approved timestamp
getter/setter pair
approverRoleId ↔ Int64
The role ID of the approver
getter/setter pair
attendanceUomId ↔ Int64
The associated unit of material of the user's attendance record
getter/setter pair
basicPayUomId ↔ Int64
The associated unit of material for storing the basic pay amount
getter/setter pair
clientId ↔ Int64
Filter by the associated client ID (return all the users that belong to this client)
getter/setter pair
code String
The unique code by which the user is classified
getter/setter pair
count ↔ Int64
The number of records that need to be sent in the response. Returns all records if it is set to -1
getter/setter pair
creationTimestampEnd ↔ Int64
The maximum timestamp that needs to be considered to filter by creation
getter/setter pair
creationTimestampStart ↔ Int64
The minimum timestamp that needs to be considered to filter by creation
getter/setter pair
departmentId ↔ Int64
The associated department
getter/setter pair
email String
The primary email of the user
getter/setter pair
entityUuid String
The entity UUID that is to be used to filter records
getter/setter pair
formData → PbList<FormFieldDatumFilterRequest>
The list of form data filters
no setter
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
isActive BOOL_FILTER
If true, then returns only active records. If false, then returns only inactive records
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
modificationTimestampEnd ↔ Int64
The maximum timestamp that needs to be considered to filter by modification
getter/setter pair
modificationTimestampStart ↔ Int64
The minimum timestamp that needs to be considered to filter by modification
getter/setter pair
name String
The name of the user
getter/setter pair
offset ↔ Int64
The number that need to be offset by before fetching the records
getter/setter pair
payrollCurrencyId ↔ Int64
The associated currency ID of the user's payroll
getter/setter pair
payrollGroupId ↔ Int64
The associated payroll group ID of the user
getter/setter pair
payrollTaxGroupId ↔ Int64
The associated tax group ID using which the user's payroll needs to be calculated
getter/setter pair
phone String
The primary contact number of the user
getter/setter pair
roleId ↔ Int64
The associated role ID
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftGroupId ↔ Int64
The associated shift group ID
getter/setter pair
sortKey USER_SORT_KEY
The sort key that is to be used to fetch the pagination response
getter/setter pair
sortOrder SORT_ORDER
The sort order that is to be used to fetch the pagination response
getter/setter pair
status STANDARD_LIFECYCLE_STATUS
The status of this user
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
username String
The username of the user
getter/setter pair
userType USER_TYPE
Stores the user type
getter/setter pair
vendorId ↔ Int64
getter/setter pair
workEmail String
The optional work email of the user
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearApprovedByUserId() → void
clearApprovedOnEnd() → void
clearApprovedOnStart() → void
clearApproverRoleId() → void
clearAttendanceUomId() → void
clearBasicPayUomId() → void
clearClientId() → void
clearCode() → void
clearCount() → void
clearCreationTimestampEnd() → void
clearCreationTimestampStart() → void
clearDepartmentId() → void
clearEmail() → void
clearEntityUuid() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearIsActive() → void
clearModificationTimestampEnd() → void
clearModificationTimestampStart() → void
clearName() → void
clearOffset() → void
clearPayrollCurrencyId() → void
clearPayrollGroupId() → void
clearPayrollTaxGroupId() → void
clearPhone() → void
clearRoleId() → void
clearShiftGroupId() → void
clearSortKey() → void
clearSortOrder() → void
clearStatus() → void
clearUsername() → void
clearUserType() → void
clearVendorId() → void
clearWorkEmail() → void
clone() UsersServiceFilterReq
Creates a deep copy of the fields in this message.
copyWith(void updates(UsersServiceFilterReq)) UsersServiceFilterReq
Apply updates to a copy of this message.
createEmptyInstance() UsersServiceFilterReq
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasApprovedByUserId() bool
hasApprovedOnEnd() bool
hasApprovedOnStart() bool
hasApproverRoleId() bool
hasAttendanceUomId() bool
hasBasicPayUomId() bool
hasClientId() bool
hasCode() bool
hasCount() bool
hasCreationTimestampEnd() bool
hasCreationTimestampStart() bool
hasDepartmentId() bool
hasEmail() bool
hasEntityUuid() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasIsActive() bool
hasModificationTimestampEnd() bool
hasModificationTimestampStart() bool
hasName() bool
hasOffset() bool
hasPayrollCurrencyId() bool
hasPayrollGroupId() bool
hasPayrollTaxGroupId() bool
hasPhone() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRoleId() bool
hasShiftGroupId() bool
hasSortKey() bool
hasSortOrder() bool
hasStatus() bool
hasUsername() bool
hasUserType() bool
hasVendorId() bool
hasWorkEmail() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited