clientId property

  1. @TagNumber.new(71)
Int64 get clientId

@optional

@description Filter results to retrieve only the users associated with or belonging to a specific external Client profile.

@example 9107

@regex ^0-9*$

@format Non-negative 64-bit integer.

Implementation

@$pb.TagNumber(71)
$fixnum.Int64 get clientId => $_getI64(27);
  1. @TagNumber.new(71)
set clientId (Int64 value)

Implementation

@$pb.TagNumber(71)
set clientId($fixnum.Int64 value) => $_setInt64(27, value);