email property

  1. @TagNumber.new(23)
String get email

@optional

@description The primary communication or routing email address where structural system notifications are dispatched.

@example "jane.doe@example.com"

@regex ^a-zA-Z0-9._%+-+@a-zA-Z0-9.-+.a-zA-Z{2,}$

@format Must be a structurally sound and valid email address string.

Implementation

@$pb.TagNumber(23)
$core.String get email => $_getSZ(15);
  1. @TagNumber.new(23)
set email (String value)

Implementation

@$pb.TagNumber(23)
set email($core.String value) => $_setString(15, value);