username property

  1. @TagNumber.new(20)
String get username

@optional

@description The unique system-level login alias used by the actor to authenticate against the platform.

@example "jane.doe"

@regex .*

@format Must be a non-empty string and completely unique across the given business entity space.

Implementation

@$pb.TagNumber(20)
$core.String get username => $_getSZ(12);
  1. @TagNumber.new(20)
set username (String value)

Implementation

@$pb.TagNumber(20)
set username($core.String value) => $_setString(12, value);