deviceToken property
@mandatory
@description The unique hardware token generated by Firebase Cloud Messaging (FCM) or Apple Push Notification service (APNs).
@example "bk3RNwAz3B0:CI2gDEstbXGYadIDZsTY2s4YckCustomTokenString..."
@regex .*
@format Non-empty string constraint with a strict boundary enforcement between 1 and 300 characters.
Implementation
@$pb.TagNumber(13)
$core.String get deviceToken => $_getSZ(3);
Implementation
@$pb.TagNumber(13)
set deviceToken($core.String value) => $_setString(3, value);