UsersServiceUpdateRequest class

Request message for updating an existing User record. Only applicable for records in DRAFT or REVISION states. This message allows for modifying the code, name, role ID, mobile role ID, email, work email, phone, birthday, joining date, address, city, state, country, pin code, blood group, shift group ID, attendance uom ID, department ID, payroll group ID, payroll tax group ID, payroll currency ID, basic pay amount, basic pay uom ID and other custom form fields of an established User.

Note: Only fields provided in the request will typically be updated. The unique system ID is required to locate the target record.

Available extensions

Constructors

UsersServiceUpdateRequest({String? userComment, Int64? id, bool? notifyUsers, Int64? vaultFolderId, String? code, String? name, Int64? roleId, Int64? mobileRoleId, String? email, String? workEmail, String? phone, String? birthday, String? joiningDate, String? address, String? city, String? state, String? country, String? pinCode, String? bloodGroup, Int64? shiftGroupId, Int64? attendanceUomId, Int64? departmentId, Int64? payrollGroupId, Int64? payrollTaxGroupId, Int64? payrollCurrencyId, Int64? basicPayAmount, Int64? basicPayUomId, Iterable<FormFieldDatumCreateRequest>? formData})
factory
UsersServiceUpdateRequest.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
UsersServiceUpdateRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

address String
@optional
getter/setter pair
attendanceUomId ↔ Int64
@optional
getter/setter pair
basicPayAmount ↔ Int64
@optional
getter/setter pair
basicPayUomId ↔ Int64
@optional
getter/setter pair
birthday String
@optional
getter/setter pair
bloodGroup String
@optional
getter/setter pair
city String
@optional
getter/setter pair
code String
@optional
getter/setter pair
country String
@optional
getter/setter pair
departmentId ↔ Int64
@optional
getter/setter pair
email String
@optional
getter/setter pair
formData → PbList<FormFieldDatumCreateRequest>
@optional
no setter
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
id ↔ Int64
@mandatory
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
joiningDate String
@optional
getter/setter pair
mobileRoleId ↔ Int64
@optional
getter/setter pair
name String
@optional
getter/setter pair
notifyUsers bool
@optional
getter/setter pair
payrollCurrencyId ↔ Int64
@optional
getter/setter pair
payrollGroupId ↔ Int64
@optional
getter/setter pair
payrollTaxGroupId ↔ Int64
@optional
getter/setter pair
phone String
@optional
getter/setter pair
pinCode String
@optional
getter/setter pair
roleId ↔ Int64
@optional
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftGroupId ↔ Int64
@optional
getter/setter pair
state String
@optional
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
userComment String
@optional
getter/setter pair
vaultFolderId ↔ Int64
@optional
getter/setter pair
workEmail String
@optional
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAddress() → void
clearAttendanceUomId() → void
clearBasicPayAmount() → void
clearBasicPayUomId() → void
clearBirthday() → void
clearBloodGroup() → void
clearCity() → void
clearCode() → void
clearCountry() → void
clearDepartmentId() → void
clearEmail() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearId() → void
clearJoiningDate() → void
clearMobileRoleId() → void
clearName() → void
clearNotifyUsers() → void
clearPayrollCurrencyId() → void
clearPayrollGroupId() → void
clearPayrollTaxGroupId() → void
clearPhone() → void
clearPinCode() → void
clearRoleId() → void
clearShiftGroupId() → void
clearState() → void
clearUserComment() → void
clearVaultFolderId() → void
clearWorkEmail() → void
clone() UsersServiceUpdateRequest
Creates a deep copy of the fields in this message.
copyWith(void updates(UsersServiceUpdateRequest)) UsersServiceUpdateRequest
Apply updates to a copy of this message.
createEmptyInstance() UsersServiceUpdateRequest
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAddress() bool
hasAttendanceUomId() bool
hasBasicPayAmount() bool
hasBasicPayUomId() bool
hasBirthday() bool
hasBloodGroup() bool
hasCity() bool
hasCode() bool
hasCountry() bool
hasDepartmentId() bool
hasEmail() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasId() bool
hasJoiningDate() bool
hasMobileRoleId() bool
hasName() bool
hasNotifyUsers() bool
hasPayrollCurrencyId() bool
hasPayrollGroupId() bool
hasPayrollTaxGroupId() bool
hasPhone() bool
hasPinCode() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRoleId() bool
hasShiftGroupId() bool
hasState() bool
hasUserComment() bool
hasVaultFolderId() bool
hasWorkEmail() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited