email property
@optional
@description The primary communication or routing email address where structural system notifications are dispatched.
@example "jane.doe@example.com"
@regex ^a-zA-Z0-9._%+-+@a-zA-Z0-9.-+.a-zA-Z{2,}$
@format Must be a structurally sound and valid email address string.
Implementation
@$pb.TagNumber(16)
$core.String get email => $_getSZ(8);
Implementation
@$pb.TagNumber(16)
set email($core.String value) => $_setString(8, value);