USER_SORT_KEY class

Describes the available sort keys

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) USER_SORT_KEY?

Constants

USER_SORT_KEY_APPROVED_BY → const USER_SORT_KEY
Fetch ordered results by the approved by field
USER_SORT_KEY_APPROVED_ON → const USER_SORT_KEY
Fetch ordered results by the approved on timestamp
USER_SORT_KEY_APPROVER_ROLE_ID → const USER_SORT_KEY
Fetch ordered results by the approver's role ID
USER_SORT_KEY_CODE → const USER_SORT_KEY
Fetch ordered results by the code
USER_SORT_KEY_CREATED_AT → const USER_SORT_KEY
Fetch ordered results by the creation timestamp
USER_SORT_KEY_EMAIL → const USER_SORT_KEY
Fetch ordered results by the email address
USER_SORT_KEY_ID_UNSPECIFIED → const USER_SORT_KEY
Fetch ordered results by id
USER_SORT_KEY_MODIFIED_AT → const USER_SORT_KEY
Fetch ordered results by the modified timestamp
USER_SORT_KEY_NAME → const USER_SORT_KEY
Fetch ordered results by the name
USER_SORT_KEY_PHONE → const USER_SORT_KEY
Fetch ordered results by the phone number
USER_SORT_KEY_USERNAME → const USER_SORT_KEY
Fetch ordered results by the username
values → const List<USER_SORT_KEY>