USER_TYPE class

Describes the available user types

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) USER_TYPE?

Constants

USER_TYPE_ANY_UNSPECIFIED → const USER_TYPE
Useful for filter and count operation when this field needs to be ignored
USER_TYPE_CLIENT → const USER_TYPE
Denotes that the user is a client
USER_TYPE_EMPLOYEE → const USER_TYPE
Denotes that the user is an employee
USER_TYPE_VENDOR → const USER_TYPE
Denotes that the user is a vendor
values → const List<USER_TYPE>