sdk/users.scailo.pbgrpc
library
Classes
-
User
-
Describes the parameters that are part of a standard response
-
USER_SORT_KEY
-
Describes the available sort keys
-
USER_TYPE
-
Describes the available user types
-
UserPrimaryInfo
-
Describes the message that is used internally to validate user
-
UsersList
-
Describes the message consisting of the list of records
-
-
Describes the common methods applicable on each user
-
Describes the base request payload of a count search
-
Describes the parameters necessary to create a record
-
Describes the base request payload of a filter search
-
Describes a pagination request to retrieve records
-
Describes the response to a pagination request
-
Describes the message that is required to register a user's device
-
Describes the request payload for performing a generic search operation on records
-
Describes the parameters necessary to update a record