UsersServiceBase class abstract

Annotations
  • @GrpcServiceName.new('Scailo.UsersService')

Constructors

UsersServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
approve(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
approve_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
commentAdd(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
commentAdd_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
count(ServiceCall call, UsersServiceCountReq request) Future<CountResponse>
count_Pre(ServiceCall $call, Future<UsersServiceCountReq> $request) Future<CountResponse>
countInStatus(ServiceCall call, CountInSLCStatusRequest request) Future<CountResponse>
countInStatus_Pre(ServiceCall $call, Future<CountInSLCStatusRequest> $request) Future<CountResponse>
create(ServiceCall call, UsersServiceCreateRequest request) Future<IdentifierResponse>
create_Pre(ServiceCall $call, Future<UsersServiceCreateRequest> $request) Future<IdentifierResponse>
createMagicLinkForSignature(ServiceCall call, MagicLinksServiceCreateRequestForSpecificResource request) Future<MagicLink>
createMagicLinkForSignature_Pre(ServiceCall $call, Future<MagicLinksServiceCreateRequestForSpecificResource> $request) Future<MagicLink>
discard(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
discard_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
downloadAsCSV(ServiceCall call, UsersServiceFilterReq request) Future<StandardFile>
downloadAsCSV_Pre(ServiceCall $call, Future<UsersServiceFilterReq> $request) Future<StandardFile>
draft(ServiceCall call, UsersServiceCreateRequest request) Future<IdentifierResponse>
draft_Pre(ServiceCall $call, Future<UsersServiceCreateRequest> $request) Future<IdentifierResponse>
draftUpdate(ServiceCall call, UsersServiceUpdateRequest request) Future<IdentifierResponse>
draftUpdate_Pre(ServiceCall $call, Future<UsersServiceUpdateRequest> $request) Future<IdentifierResponse>
filter(ServiceCall call, UsersServiceFilterReq request) Future<UsersList>
filter_Pre(ServiceCall $call, Future<UsersServiceFilterReq> $request) Future<UsersList>
halt(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
halt_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
identifyCroppedFace(ServiceCall call, StandardFile request) Future<User>
identifyCroppedFace_Pre(ServiceCall $call, Future<StandardFile> $request) Future<User>
identifyFullFace(ServiceCall call, StandardFile request) Future<User>
identifyFullFace_Pre(ServiceCall $call, Future<StandardFile> $request) Future<User>
importFromCSV(ServiceCall call, StandardFile request) Future<IdentifierUUIDsList>
importFromCSV_Pre(ServiceCall $call, Future<StandardFile> $request) Future<IdentifierUUIDsList>
mFAEnable(ServiceCall call, IdentifierUUID request) Future<ImageResponse>
mFAEnable_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ImageResponse>
mFAReset(ServiceCall call, IdentifierUUID request) Future<IdentifierResponse>
mFAReset_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<IdentifierResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerMobileDevice(ServiceCall call, UsersServiceRegisterMobileDeviceRequest request) Future<IdentifierResponse>
registerMobileDevice_Pre(ServiceCall $call, Future<UsersServiceRegisterMobileDeviceRequest> $request) Future<IdentifierResponse>
restore(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
restore_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
revisionUpdate(ServiceCall call, UsersServiceUpdateRequest request) Future<IdentifierResponse>
revisionUpdate_Pre(ServiceCall $call, Future<UsersServiceUpdateRequest> $request) Future<IdentifierResponse>
searchAll(ServiceCall call, UsersServiceSearchAllReq request) Future<UsersList>
searchAll_Pre(ServiceCall $call, Future<UsersServiceSearchAllReq> $request) Future<UsersList>
sendForRevision(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForRevision_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
sendForVerification(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForVerification_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
toString() String
A string representation of this object.
inherited
updateOwnPassword(ServiceCall call, UpdateOwnPasswordReq request) Future<IdentifierResponse>
updateOwnPassword_Pre(ServiceCall $call, Future<UpdateOwnPasswordReq> $request) Future<IdentifierResponse>
updatePassword(ServiceCall call, UpdatePasswordReq request) Future<IdentifierResponse>
updatePassword_Pre(ServiceCall $call, Future<UpdatePasswordReq> $request) Future<IdentifierResponse>
updateProfilePicture(ServiceCall call, UploadPictureReq request) Future<IdentifierResponse>
updateProfilePicture_Pre(ServiceCall $call, Future<UploadPictureReq> $request) Future<IdentifierResponse>
updateSignature(ServiceCall call, UploadPictureReq request) Future<IdentifierResponse>
updateSignature_Pre(ServiceCall $call, Future<UploadPictureReq> $request) Future<IdentifierResponse>
verify(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
verify_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
viewAll(ServiceCall call, ActiveStatus request) Future<UsersList>
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request) Future<UsersList>
viewAllForEntityUUID(ServiceCall call, IdentifierUUID request) Future<UsersList>
viewAllForEntityUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<UsersList>
viewBirthdaysOn(ServiceCall call, MonthAndDayFilter request) Future<UsersList>
viewBirthdaysOn_Pre(ServiceCall $call, Future<MonthAndDayFilter> $request) Future<UsersList>
viewByCode(ServiceCall call, SimpleSearchReq request) Future<User>
viewByCode_Pre(ServiceCall $call, Future<SimpleSearchReq> $request) Future<User>
viewByID(ServiceCall call, IdentifierZeroable request) Future<User>
viewByID_Pre(ServiceCall $call, Future<IdentifierZeroable> $request) Future<User>
viewByUsername(ServiceCall call, SimpleSearchReq request) Future<User>
viewByUsername_Pre(ServiceCall $call, Future<SimpleSearchReq> $request) Future<User>
viewByUUID(ServiceCall call, IdentifierUUID request) Future<User>
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<User>
viewEssentialByID(ServiceCall call, Identifier request) Future<User>
viewEssentialByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<User>
viewEssentialByUUID(ServiceCall call, IdentifierUUID request) Future<User>
viewEssentialByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<User>
viewFromIDs(ServiceCall call, IdentifiersList request) Future<UsersList>
viewFromIDs_Pre(ServiceCall $call, Future<IdentifiersList> $request) Future<UsersList>
viewFromUsernames(ServiceCall call, StringsList request) Future<UsersList>
viewFromUsernames_Pre(ServiceCall $call, Future<StringsList> $request) Future<UsersList>
viewFromUUIDs(ServiceCall call, IdentifierUUIDsList request) Future<UsersList>
viewFromUUIDs_Pre(ServiceCall $call, Future<IdentifierUUIDsList> $request) Future<UsersList>
viewProfilePicture(ServiceCall call, IdentifierUUID request) Future<ImageResponse>
viewProfilePicture_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ImageResponse>
viewQRImage(ServiceCall call, IdentifierUUID request) Future<ImageResponse>
viewQRImage_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ImageResponse>
viewQRString(ServiceCall call, IdentifierUUID request) Future<StringResponse>
viewQRString_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<StringResponse>
viewSelf(ServiceCall call, Empty request) Future<User>
viewSelf_Pre(ServiceCall $call, Future<Empty> $request) Future<User>
viewSignature(ServiceCall call, IdentifierUUID request) Future<Base64String>
viewSignature_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<Base64String>
viewThumbnailPicture(ServiceCall call, IdentifierUUID request) Future<ImageResponse>
viewThumbnailPicture_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ImageResponse>
viewVCard(ServiceCall call, IdentifierUUID request) Future<ImageResponse>
viewVCard_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<ImageResponse>
viewWithPagination(ServiceCall call, UsersServicePaginationReq request) Future<UsersServicePaginationResponse>
viewWithPagination_Pre(ServiceCall $call, Future<UsersServicePaginationReq> $request) Future<UsersServicePaginationResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited