draft method
ResponseFuture<IdentifierResponse>
draft(
- UsersServiceCreateRequest request, {
- CallOptions? options,
Saves a new user record as a draft without triggering side effects.
Use this method when you have incomplete information but wish to persist
the record for later completion. The user cannot log in while the record is in a DRAFT state.
Note: Some strict validation rules may be relaxed in the backend for drafts
Implementation
$grpc.ResponseFuture<$1.IdentifierResponse> draft(
$0.UsersServiceCreateRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$draft, request, options: options);
}