identifyCroppedFace method
View user info on the basis of the provided image. The image should consist of only the user's face. Will return an error if the image has not been recognized.
Implementation
$grpc.ResponseFuture<$0.User> identifyCroppedFace(
$1.StandardFile request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$identifyCroppedFace, request, options: options);
}