identifyFullFace method

ResponseFuture<User> identifyFullFace(
  1. StandardFile request, {
  2. CallOptions? options,
})

View user info on the basis of the provided image. The image should consist of just the user (might be a full sized photo). The face will be cropped. Will return an error if the image has not been recognized.

Implementation

$grpc.ResponseFuture<$0.User> identifyFullFace(
  $1.StandardFile request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$identifyFullFace, request, options: options);
}