sdk/vault.scailo.pb library

Classes

GiXRelayHeader
Describes the message that stores the headers necessary for performing the RELAY request
GiXRelayReqWithBody
Describes the message that is required to execute a RELAY instruction for POST, PUT and PATCH requests (with payload)
GiXRelayReqWithoutBody
Describes the message that is required to execute a RELAY instruction for GET, DELETE and HEAD requests (without payload body)
GiXRelayResponse
Describes the payload that will be returned to the GiX Relay RPC
VaultResourcesList
Describes the message consisting of the list of vault resources

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.