VaultServiceClient class

Describes the available services in Vault

Annotations
  • @GrpcServiceName.new('Scailo.VaultService')

Constructors

VaultServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addEnclaveDomain(EnclaveDomainAddRequest request, {CallOptions? options}) → ResponseFuture<EnclaveDomain>
Add domain to enclave
addEnclaveEnvironmentVariable(EnclaveEnvironmentVariableAddRequest request, {CallOptions? options}) → ResponseFuture<EnclaveEnvironmentVariable>
Add environment variable to enclave
addEnclaveFrame(EnclaveFrameAddRequest request, {CallOptions? options}) → ResponseFuture<EnclaveFrame>
Adds an enclave as a dashboard frame. The file needs to be an enclave. Returns an error otherwise
addFileChunk(VaultFileAddChunkRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add chunk to a file version and returns the UUID of the added chunk
addFilePermission(VaultPermissionAddRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Permission APIs Add permission and returns the UUID of the added permission
addFolder(VaultFolderAddRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add folder
addFolderPermission(VaultPermissionAddRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Permission APIs Add permission and returns the UUID of the added permission
completeFile(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Complete file upload
countEnclaveIngresses(EnclaveIngressCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all enclave ingresses that match the given filter criteria
deleteEnclaveDomain(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete domain from enclave
deleteEnclaveEnvironmentVariable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete environment variable in enclave
deleteEnclaveFrame(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete the dashboard frame
deleteFile(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Delete file
deleteFilePermission(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Delete permission (returns the UUID of the file)
deleteFolder(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Delete folder
deleteFolderPermission(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Delete permission (returns the UUID of the folder)
doesFileExist(VaultDuplicateCheckReq request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Check if file already exists
doesFolderExist(VaultDuplicateCheckReq request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Check if folder already exists
downloadFile(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Downloads Download file with the given UUID
downloadFileVersion(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download file version with the given UUID
downloadFolder(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the vault folder
filterEnclaveDomains(EnclaveDomainsFilterReq request, {CallOptions? options}) → ResponseFuture<EnclaveDomainsList>
Filter all domains that match the given filter criteria
filterEnclaveIngresses(EnclaveIngressFilterReq request, {CallOptions? options}) → ResponseFuture<EnclaveIngressesList>
View all enclave ingresses that match the given filter criteria
giXCount(GiXAppRunCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all runs that match the given filter criteria
giXFilter(GiXAppRunFilterReq request, {CallOptions? options}) → ResponseFuture<GiXAppRunsList>
View all runs that match the given filter criteria
giXRelayDELETE(GiXRelayReqWithoutBody request, {CallOptions? options}) → ResponseFuture<GiXRelayResponse>
Relay a DELETE API
giXRelayGET(GiXRelayReqWithoutBody request, {CallOptions? options}) → ResponseFuture<GiXRelayResponse>
Relay a GET API
giXRelayHEAD(GiXRelayReqWithoutBody request, {CallOptions? options}) → ResponseFuture<GiXRelayResponse>
Relay a HEAD API
giXRelayPATCH(GiXRelayReqWithBody request, {CallOptions? options}) → ResponseFuture<GiXRelayResponse>
Relay a PATCH API
giXRelayPOST(GiXRelayReqWithBody request, {CallOptions? options}) → ResponseFuture<GiXRelayResponse>
Relay a POST API
giXRelayPUT(GiXRelayReqWithBody request, {CallOptions? options}) → ResponseFuture<GiXRelayResponse>
Relay a PUT API
initiateFile(VaultFileInitiateFileRequest request, {CallOptions? options}) → ResponseFuture<VaultFileInitiateFileResponse>
Initiate file upload
modifyFilePermission(VaultPermissionModifyRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Modify permission and returns the UUID of the added permission
modifyFolderPermission(VaultPermissionModifyRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Modify permission and returns the UUID of the modified permission
moveFile(VaultFileMoveFileRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Move file
moveFolder(VaultFolderMoveFolderRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Move folder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
persistFile(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Persist file
reconfigureEnclave(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Reconfigures the enclave (redeploys the enclave)
renameFile(VaultFileRenameFileRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Rename file
renameFolder(VaultFolderRenameFolderRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Rename folder
Search for files and folders
setupAllEnclaveFrames(Empty request, {CallOptions? options}) → ResponseFuture<EnclaveFrameSetupList>
Returns all the endpoints that could be used to render frames for the identified user. This can be primary used to render all the frames on a user's dashboard, for example.
setupEnclaveFrame(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<EnclaveFrameSetup>
Returns the endpoint that could be used to render a frame
setupEnclaveIngress(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<EnclaveIngress>
Setup Enclave Ingress
setupGiX(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GiXAppRun>
Setup GiX app
toString() String
A string representation of this object.
inherited
unzipFile(VaultFileUnzipRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Unzip file
updateEnclaveEnvironmentVariable(EnclaveEnvironmentVariableUpdateRequest request, {CallOptions? options}) → ResponseFuture<EnclaveEnvironmentVariable>
Update environment variable in enclave
updateEnclaveFrame(EnclaveFrameUpdateRequest request, {CallOptions? options}) → ResponseFuture<EnclaveFrame>
Update the properties of a frame
verifyEnclaveIngress(VerifyEnclaveIngressRequest request, {CallOptions? options}) → ResponseFuture<VerifyEnclaveIngressResponse>
Verifies the enclave ingress and returns the necessary information for subsequent requests
viewAccessibleFilesInFolder(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultFilesList>
View all files accessible by self in the given folder
viewAccessibleFoldersInFolder(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultFoldersList>
View all folders accessible by self in the given folder
viewAccessibleResourcesInFolder(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultResourcesList>
View all the resources accessible by self in the given folder
viewAllEnclaveDomains(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<EnclaveDomainsList>
View all domains for enclave for the enclave represented by the Identifier
viewAllEnclaveEnvironmentVariables(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<EnclaveEnvironmentVariablesList>
View all environment variables in enclave for the enclave represented by the Identifier
viewDomainSuffix(Empty request, {CallOptions? options}) → ResponseFuture<EnclaveDomainSuffixResp>
Retrieve the default domain suffix that could be used for creating a new domain
viewEnclaveDomain(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<EnclaveDomain>
View domain for enclave represented by the Identifier
viewEnclaveEnvironmentVariable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<EnclaveEnvironmentVariable>
View environment variable in enclave represented by the Identifier
viewEnclaveFrame(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<EnclaveFrame>
View the properties of a frame
viewFileAccessLogs(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultAccessLogsList>
View access logs of file
viewFileByID(Identifier request, {CallOptions? options}) → ResponseFuture<VaultFile>
View file by ID
viewFileByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultFile>
View file by UUID
viewFileChunk(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultFileVersionChunk>
View chunk with the given UUID
viewFileChunkMetadata(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultFileVersionChunk>
View chunk metadata
View logo
viewFilePermission(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultPermission>
View permission for file
viewFileVersions(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultFileVersionsList>
View all versions of file
viewFolderAccessLogs(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultAccessLogsList>
View access logs of folder
viewFolderByID(IdentifierZeroable request, {CallOptions? options}) → ResponseFuture<VaultFolder>
View folder by ID
viewFolderByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultFolder>
View folder by UUID
viewFolderDownloadStatus(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultFolderDownload>
View the status of the folder download
viewFolderPermission(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VaultPermission>
View permission for folder
viewPassthroughRolesForFolder(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<RolesList>
View passthrough roles for folder
zipFolder(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Zip folder and returns the UUID of the vault folder download

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.