isSecret property

  1. @TagNumber.new(13)
bool get isSecret

Denotes if the value should be stored as a secret (will not be visible to the user post creation)

Implementation

@$pb.TagNumber(13)
$core.bool get isSecret => $_getBF(3);
  1. @TagNumber.new(13)
set isSecret (bool value)

Implementation

@$pb.TagNumber(13)
set isSecret($core.bool value) => $_setBool(3, value);