VisitationsServiceClient class

Describes the common methods applicable on each visitation

Annotations
  • @GrpcServiceName.new('Scailo.VisitationsService')

Constructors

VisitationsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Officially approves the record.
associateHasOpenVisitation(Identifier request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if an associate (with the given identifier) has an open visitation (visitation with only entry and no exit)
attachVaultFolder(VaultFolderAttachRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Attaches a specified folder directly to a record without requiring a full revision workflow.
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Adds an audit comment to the record's history without changing its current lifecycle status.
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Marks the record as finalized and fully processed.
count(VisitationsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Returns the total count of records matching the given complex filter criteria.
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Returns the total number of records currently in a specific lifecycle status.
create(VisitationsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Generates a magic link for temporary, authenticated access to the resource.
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Permanently cancels the record.
downloadAsCSV(VisitationsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
draft(VisitationsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Saves a new record as a draft without triggering side effects.
draftUpdate(VisitationsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Updates an existing record that is currently in DRAFT status.
filter(VisitationsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<VisitationsList>
Performs a high-granularity search based on multiple specific field filters.
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Temporarily halts processing of the record.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordImageEntry(VisitationsServiceImageEntryRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Store entry time
recordImageExit(VisitationsServiceImageExitRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Store exit time
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Creates a new record based on an existing one (cloning).
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restores a previously DISCARDED or HALTED record.
revisionUpdate(VisitationsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Updates a record that has been sent back for REVISION.
searchAll(VisitationsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<VisitationsList>
Performs a free-text search across records using a search key.
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Sends the record back to the creator for corrections.
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Submits a record in DRAFT or REVISION status for verification.
toString() String
A string representation of this object.
inherited
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Marks a record as verified, signaling that it is ready for final approval.
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<VisitationsList>
Returns all records filtered by their active status.
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<VisitationsList>
Returns all records belonging to a specific organization/entity UUID.
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<Visitation>
Retrieves a single record by its internal numeric ID. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Visitation>
Retrieves a single record by its globally unique UUID. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewEntryGPSCoordinates(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GPSCoordinatesResponse>
View entry GPS coordinates for visitation UUID
viewEntryGPSStaticImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View entry GPS static image from Google Maps
viewEntryImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View entry image for visitation UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<Visitation>
Retrieves a record by ID excluding high-volume fields like logs for performance. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Visitation>
Retrieves a record by UUID excluding high-volume fields like logs. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewExitGPSCoordinates(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GPSCoordinatesResponse>
View exit GPS coordinates for visitation UUID
viewExitGPSStaticImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View exit GPS static image from Google Maps
viewExitImage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View exit image for visitation UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<VisitationsList>
Retrieves a list of records matching the provided array of internal IDs.
viewOpenVisitationForAssociate(Identifier request, {CallOptions? options}) → ResponseFuture<Visitation>
View the open visitation for an associate (with the given identifier), if available. Returns an empty instance if no visitation is available
viewQRCode(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ImageResponse>
View QR Code
viewWithPagination(VisitationsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<VisitationsServicePaginationResponse>
Retrieves a paginated list of records based on status, sort keys, and offsets.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.