logs property
Stores the logs of every operation performed on this work order
Implementation
@$pb.TagNumber(5)
$pb.PbList<$1.LogbookLogConciseSLC> get logs => $_getList(4);
Stores the logs of every operation performed on this work order
@$pb.TagNumber(5)
$pb.PbList<$1.LogbookLogConciseSLC> get logs => $_getList(4);