sdk/work_orders.scailo.pbgrpc library

Classes

WORK_ORDER_ITEM_SORT_KEY
Describes the available sort keys
WORK_ORDER_ITEM_STATUS
Describes the applicable statuses of work order items
WORK_ORDER_REF_FROM
Stores all the possible references from which a work order can be added
WORK_ORDER_SORT_KEY
Describes the available sort keys
WorkOrder
Describes the parameters that are part of a standard response
WorkOrderAncillaryParameters
Stores the UUID references of the record
WorkOrderItem
Describes the parameters that constitute an item associated to a work order
WorkOrderItemHistoryRequest
Describes the parameters that are required to retrieve the history of the record
WorkOrderItemProspectiveInfoRequest
Describes the parameters that are required to retrieve the info of a prospective work order item
WorkOrderItemsSearchRequest
Describes the request payload to retrieve approved or unapproved items.
WorkOrderProductionStatistics
Describes the production statistics of the work order
WorkOrderProductionStatisticsList
Describes the list of production statistics of the work order
WorkOrderRequirementStatistics
Describes the requirement statistics of the work order
WorkOrderRequirementStatisticsList
Describes the list of requirement statistics of the work order
WorkOrdersItemsList
Describes the message consisting of the list of work order items
WorkOrdersList
Describes the message consisting of the list of work orders
WorkOrdersServiceAutofillRequest
Describes the parameters necessary to perform an autofill request
WorkOrdersServiceBase
WorkOrdersServiceClient
Describes the common methods applicable on each work order
WorkOrdersServiceCountReq
Describes the base request payload of a count search
WorkOrdersServiceCreateRequest
Describes the parameters necessary to create a record
WorkOrdersServiceFilterReq
Describes the base request payload of a filter search
WorkOrdersServiceItemCreateRequest
Describes the parameters required to add an item to a work order
WorkOrdersServiceItemUpdateRequest
Describes the parameters required to update an item in a work order
WorkOrdersServicePaginatedItemsResponse
Describes the response to a pagination items request
WorkOrdersServicePaginationReq
Describes a pagination request to retrieve records
WorkOrdersServicePaginationResponse
Describes the response to a pagination request
WorkOrdersServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
WorkOrdersServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.