sdk/workflows_rules.scailo.pb library

Classes

WORKFLOW_RULE_EXECUTE_ON
Stores all the possible values for when the rule should be triggered. Possible values are Success and Failure.
WORKFLOW_RULE_MOMENT
Stores all the possible moments for which a workflow rule can be created
WORKFLOW_RULE_SERVICE_NAME
Stores all the possible service names for which a workflow rule can be created
WORKFLOW_RULE_SORT_KEY
Describes the available sort keys
WorkflowEvent
Describes the request payload that is sent to Redis whenever an event occurs
WorkflowRule
Describes the parameters that are part of a standard response
WorkflowsRulesList
Describes the message consisting of the list of workflows rules
WorkflowsRulesServiceCountReq
Describes the base request payload of a count search
WorkflowsRulesServiceCreateRequest
Describes the parameters necessary to create a record
WorkflowsRulesServiceFilterReq
Describes the base request payload of a filter search
WorkflowsRulesServicePaginationReq
Describes a pagination request to retrieve records
WorkflowsRulesServicePaginationResponse
Describes the response to a pagination request
WorkflowsRulesServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
WorkflowsRulesServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.