transactionPayload property
The payload of the transaction that just took place (could be sales order, etc.)
Implementation
@$pb.TagNumber(30)
$core.List<$core.int> get transactionPayload => $_getN(4);
The payload of the transaction that just took place (could be sales order, etc.)
@$pb.TagNumber(30)
$core.List<$core.int> get transactionPayload => $_getN(4);