userPayload property
The configured static user payload of the workflow rule
Implementation
@$pb.TagNumber(40)
$core.List<$core.int> get userPayload => $_getN(5);
The configured static user payload of the workflow rule
@$pb.TagNumber(40)
$core.List<$core.int> get userPayload => $_getN(5);