notifyUserId property
- @TagNumber.new(12)
The ID of the user who is to be notified when this rule is triggered. The notification will most likely be in the form of an email.
Implementation
@$pb.TagNumber(12)
$fixnum.Int64 get notifyUserId => $_getI64(4);
- @TagNumber.new(12)
Implementation
@$pb.TagNumber(12)
set notifyUserId($fixnum.Int64 value) => $_setInt64(4, value);