userPayload property

  1. @TagNumber.new(40)
List<int> get userPayload

Stores any additional static payload that is provided by the user and needs to be relayed in the rule

Implementation

@$pb.TagNumber(40)
$core.List<$core.int> get userPayload => $_getN(10);
  1. @TagNumber.new(40)
set userPayload (List<int> value)

Implementation

@$pb.TagNumber(40)
set userPayload($core.List<$core.int> value) => $_setBytes(10, value);