notifyUserId property

  1. @TagNumber.new(12)
Int64 get notifyUserId

The ID of the user who is to be notified when this rule is triggered. The notification will most likely be in the form of an email.

Implementation

@$pb.TagNumber(12)
$fixnum.Int64 get notifyUserId => $_getI64(5);
  1. @TagNumber.new(12)
set notifyUserId (Int64 value)

Implementation

@$pb.TagNumber(12)
set notifyUserId($fixnum.Int64 value) => $_setInt64(5, value);