userPayload property
Stores any additional static payload that is provided by the user and needs to be relayed in the rule
Implementation
@$pb.TagNumber(40)
$core.List<$core.int> get userPayload => $_getN(11);
Stores any additional static payload that is provided by the user and needs to be relayed in the rule
@$pb.TagNumber(40)
$core.List<$core.int> get userPayload => $_getN(11);