WorkflowsRulesServiceBase class abstract

Annotations
  • @GrpcServiceName.new('Scailo.WorkflowsRulesService')

Constructors

WorkflowsRulesServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
approve(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
approve_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
commentAdd(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
commentAdd_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
complete(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
complete_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
count(ServiceCall call, WorkflowsRulesServiceCountReq request) Future<CountResponse>
count_Pre(ServiceCall $call, Future<WorkflowsRulesServiceCountReq> $request) Future<CountResponse>
countInStatus(ServiceCall call, CountInSLCStatusRequest request) Future<CountResponse>
countInStatus_Pre(ServiceCall $call, Future<CountInSLCStatusRequest> $request) Future<CountResponse>
create(ServiceCall call, WorkflowsRulesServiceCreateRequest request) Future<IdentifierResponse>
create_Pre(ServiceCall $call, Future<WorkflowsRulesServiceCreateRequest> $request) Future<IdentifierResponse>
discard(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
discard_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
draft(ServiceCall call, WorkflowsRulesServiceCreateRequest request) Future<IdentifierResponse>
draft_Pre(ServiceCall $call, Future<WorkflowsRulesServiceCreateRequest> $request) Future<IdentifierResponse>
draftUpdate(ServiceCall call, WorkflowsRulesServiceUpdateRequest request) Future<IdentifierResponse>
draftUpdate_Pre(ServiceCall $call, Future<WorkflowsRulesServiceUpdateRequest> $request) Future<IdentifierResponse>
filter(ServiceCall call, WorkflowsRulesServiceFilterReq request) Future<WorkflowsRulesList>
filter_Pre(ServiceCall $call, Future<WorkflowsRulesServiceFilterReq> $request) Future<WorkflowsRulesList>
halt(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
halt_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
reopen_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
repeat(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
repeat_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
restore(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
restore_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
revisionUpdate(ServiceCall call, WorkflowsRulesServiceUpdateRequest request) Future<IdentifierResponse>
revisionUpdate_Pre(ServiceCall $call, Future<WorkflowsRulesServiceUpdateRequest> $request) Future<IdentifierResponse>
searchAll(ServiceCall call, WorkflowsRulesServiceSearchAllReq request) Future<WorkflowsRulesList>
searchAll_Pre(ServiceCall $call, Future<WorkflowsRulesServiceSearchAllReq> $request) Future<WorkflowsRulesList>
sendForRevision(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForRevision_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
sendForVerification(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
sendForVerification_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
toString() String
A string representation of this object.
inherited
verify(ServiceCall call, IdentifierUUIDWithUserComment request) Future<IdentifierResponse>
verify_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request) Future<IdentifierResponse>
viewAll(ServiceCall call, ActiveStatus request) Future<WorkflowsRulesList>
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request) Future<WorkflowsRulesList>
viewAllForEntityUUID(ServiceCall call, IdentifierUUID request) Future<WorkflowsRulesList>
viewAllForEntityUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<WorkflowsRulesList>
viewByID(ServiceCall call, Identifier request) Future<WorkflowRule>
viewByID_Pre(ServiceCall $call, Future<Identifier> $request) Future<WorkflowRule>
viewByUUID(ServiceCall call, IdentifierUUID request) Future<WorkflowRule>
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request) Future<WorkflowRule>
viewWithPagination(ServiceCall call, WorkflowsRulesServicePaginationReq request) Future<WorkflowsRulesServicePaginationResponse>
viewWithPagination_Pre(ServiceCall $call, Future<WorkflowsRulesServicePaginationReq> $request) Future<WorkflowsRulesServicePaginationResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited