utilities library

Properties

authToken String
Stores the auth token that is used to access the Scailo API
getter/setter pair
channel ↔ ClientChannel
Declaring the channel that maintains the connection to the Scailo API server
getter/setter pair

Functions

createClientChannel({required String domain}) → void
Create the client channel
getAuthToken() String
Returns the auth token
getClientChannel() → ClientChannel
Get the client channel
getScailoClientForAbsencesService() AbsencesServiceClient
Get the client to access the Absences service
getScailoClientForActionsCodesService() ActionsCodesServiceClient
Get the client to access the Actions Codes service
getScailoClientForActivitiesGroupsService() ActivitiesGroupsServiceClient
Get the client to access the Activities Groups service
getScailoClientForActivitiesService() ActivitiesServiceClient
Get the client to access the Activities service
getScailoClientForActivitiesStatusesService() ActivitiesStatusesServiceClient
Get the client to access the Activities Statuses service
getScailoClientForActivitiesTagsService() ActivitiesTagsServiceClient
Get the client to access the Activities Tags service
getScailoClientForAnnouncementsService() AnnouncementsServiceClient
Get the client to access the Announcements service
getScailoClientForAssetIndentsService() AssetIndentsServiceClient
Get the client to access the Asset Indents service
getScailoClientForAssociatesService() AssociatesServiceClient
Get the client to access the Associates service
getScailoClientForAttendancesAmendmentsService() AttendancesAmendmentsServiceClient
Get the client to access the Attendances Amendments service
getScailoClientForAttendancesService() AttendancesServiceClient
Get the client to access the Attendances service
getScailoClientForBankAccountsService() BankAccountsServiceClient
Get the client to access the Bank Accounts service
getScailoClientForClientsService() ClientsServiceClient
Get the client to access the Clients service
getScailoClientForClientStreamsService() ClientStreamsServiceClient
Get the client to access the Client Streams service
getScailoClientForComponentsService() ComponentsServiceClient
Get the client to access the Components service
getScailoClientForCreditNotesService() CreditNotesServiceClient
Get the client to access the Credit Notes service
getScailoClientForCurrenciesService() CurrenciesServiceClient
Get the client to access the Currencies service
getScailoClientForDebitNotesService() DebitNotesServiceClient
Get the client to access the Debit Notes service
getScailoClientForDepartmentsService() DepartmentsServiceClient
Get the client to access the Departments service
getScailoClientForEquationsFamiliesService() EquationsFamiliesServiceClient
Get the client to access the Equations Families service
getScailoClientForEquationsReplaceablesService() EquationsReplaceablesServiceClient
Get the client to access the Equations Replaceables service
getScailoClientForEquationsSalesBundlesService() EquationsSalesBundlesServiceClient
Get the client to access the Equations Sales Bundles service
getScailoClientForEquationsWorkOrdersService() EquationsWorkOrdersServiceClient
Get the client to access the Equations Work Orders service
getScailoClientForEquipmentsService() EquipmentsServiceClient
Get the client to access the Equipments service
getScailoClientForExpensesService() ExpensesServiceClient
Get the client to access the Expenses service
getScailoClientForFamiliesService() FamiliesServiceClient
Get the client to access the Families service
getScailoClientForFeedstocksService() FeedstocksServiceClient
Get the client to access the Feedstocks service
getScailoClientForFormsFieldsDataService() FormsFieldsDataServiceClient
Get the client to access the Forms Fields Data service
getScailoClientForFormsFieldsService() FormsFieldsServiceClient
Get the client to access the Forms Fields service
getScailoClientForFormsSectionsService() FormsSectionsServiceClient
Get the client to access the Forms Sections service
getScailoClientForGeneralSettingsService() GeneralSettingsServiceClient
Get the client to access the General Settings service
getScailoClientForGeneralStreamsService() GeneralStreamsServiceClient
Get the client to access the General Streams service
getScailoClientForGoalsService() GoalsServiceClient
Get the client to access the Goals service
getScailoClientForGoodsDispatchesService() GoodsDispatchesServiceClient
Get the client to access the Goods Dispatches service
getScailoClientForGoodsReceiptsService() GoodsReceiptsServiceClient
Get the client to access the Goods Receipts service
getScailoClientForHolidaysService() HolidaysServiceClient
Get the client to access the Holidays service
getScailoClientForInfrastructuresService() InfrastructuresServiceClient
Get the client to access the Infrastructures service
getScailoClientForInventoryService() InventoryServiceClient
Get the client to access the Inventory service
getScailoClientForInwardJobsFreeIssueMaterialsReturnsService() InwardJobsFreeIssueMaterialsReturnsServiceClient
Get the client to access the Inward Jobs Free Issue Materials Returns service
getScailoClientForInwardJobsFreeIssueMaterialsService() InwardJobsFreeIssueMaterialsServiceClient
Get the client to access the Inward Jobs Free Issue Materials service
getScailoClientForInwardJobsService() InwardJobsServiceClient
Get the client to access the Inward Jobs service
getScailoClientForLabelsService() LabelsServiceClient
Get the client to access the Labels service
getScailoClientForLeavesAdjustmentsService() LeavesAdjustmentsServiceClient
Get the client to access the Leaves Adjustments service
getScailoClientForLeavesLogsService() LeavesLogsServiceClient
Get the client to access the Leaves Logs service
getScailoClientForLeavesRequestsService() LeavesRequestsServiceClient
Get the client to access the Leaves Requests service
getScailoClientForLeavesTypesService() LeavesTypesServiceClient
Get the client to access the Leaves Types service
getScailoClientForLedgersService() LedgersServiceClient
Get the client to access the Ledgers service
getScailoClientForLocationsService() LocationsServiceClient
Get the client to access the Locations service
getScailoClientForLoginService() LoginServiceClient
Get the client to access the Login service
getScailoClientForMagicLinksService() MagicLinksServiceClient
Get the client to access the Magic Links service
getScailoClientForMeetingsService() MeetingsServiceClient
Get the client to access the Meetings service
getScailoClientForMerchandisesService() MerchandisesServiceClient
Get the client to access the Merchandises service
getScailoClientForNotesService() NotesServiceClient
Get the client to access the Notes service
getScailoClientForOnDutiesService() OnDutiesServiceClient
Get the client to access the On Duties service
getScailoClientForOutwardJobsFreeIssueMaterialsReturnsService() OutwardJobsFreeIssueMaterialsReturnsServiceClient
Get the client to access the Outward Jobs Free Issue Materials Returns service
getScailoClientForOutwardJobsFreeIssueMaterialsService() OutwardJobsFreeIssueMaterialsServiceClient
Get the client to access the Outward Jobs Free Issue Materials service
getScailoClientForOutwardJobsService() OutwardJobsServiceClient
Get the client to access the Outward Jobs service
getScailoClientForOvertimesService() OvertimesServiceClient
Get the client to access the Overtimes service
getScailoClientForPayrollGroupsService() PayrollGroupsServiceClient
Get the client to access the Payroll Groups service
getScailoClientForPayrollParamsService() PayrollParamsServiceClient
Get the client to access the Payroll Params service
getScailoClientForProductionIndentsService() ProductionIndentsServiceClient
Get the client to access the Production Indents service
getScailoClientForProductionPlansService() ProductionPlansServiceClient
Get the client to access the Production Plans service
getScailoClientForProductsService() ProductsServiceClient
Get the client to access the Products service
getScailoClientForProformaInvoicesService() ProformaInvoicesServiceClient
Get the client to access the Proforma Invoices service
getScailoClientForProjectsService() ProjectsServiceClient
Get the client to access the Projects service
getScailoClientForPurchasesEnquiriesService() PurchasesEnquiriesServiceClient
Get the client to access the Purchases Enquiries service
getScailoClientForPurchasesIndentsService() PurchasesIndentsServiceClient
Get the client to access the Purchases Indents service
getScailoClientForPurchasesOrdersService() PurchasesOrdersServiceClient
Get the client to access the Purchases Orders service
getScailoClientForPurchasesPaymentsService() PurchasesPaymentsServiceClient
Get the client to access the Purchases Payments service
getScailoClientForPurchasesReturnsService() PurchasesReturnsServiceClient
Get the client to access the Purchases Returns service
getScailoClientForQCGroupsService() QCGroupsServiceClient
Get the client to access the Qc Groups service
getScailoClientForQCParamsService() QCParamsServiceClient
Get the client to access the Qc Params service
getScailoClientForQCSamplesService() QCSamplesServiceClient
Get the client to access the Qc Samples service
getScailoClientForQuotationsRequestsService() QuotationsRequestsServiceClient
Get the client to access the Quotations Requests service
getScailoClientForQuotationsResponsesService() QuotationsResponsesServiceClient
Get the client to access the Quotations Responses service
getScailoClientForReplaceableIndentsService() ReplaceableIndentsServiceClient
Get the client to access the Replaceable Indents service
getScailoClientForRolesService() RolesServiceClient
Get the client to access the Roles service
getScailoClientForSalariesService() SalariesServiceClient
Get the client to access the Salaries service
getScailoClientForSalesEnquiriesService() SalesEnquiriesServiceClient
Get the client to access the Sales Enquiries service
getScailoClientForSalesInvoicesService() SalesInvoicesServiceClient
Get the client to access the Sales Invoices service
getScailoClientForSalesOrdersService() SalesOrdersServiceClient
Get the client to access the Sales Orders service
getScailoClientForSalesQuotationsService() SalesQuotationsServiceClient
Get the client to access the Sales Quotations service
getScailoClientForSalesReceiptsService() SalesReceiptsServiceClient
Get the client to access the Sales Receipts service
getScailoClientForSalesReturnsService() SalesReturnsServiceClient
Get the client to access the Sales Returns service
getScailoClientForShiftsGroupsService() ShiftsGroupsServiceClient
Get the client to access the Shifts Groups service
getScailoClientForShiftsService() ShiftsServiceClient
Get the client to access the Shifts service
getScailoClientForSkillsGroupsService() SkillsGroupsServiceClient
Get the client to access the Skills Groups service
getScailoClientForSkillsParamsService() SkillsParamsServiceClient
Get the client to access the Skills Params service
getScailoClientForStockAuditsService() StockAuditsServiceClient
Get the client to access the Stock Audits service
getScailoClientForStockIssuancesService() StockIssuancesServiceClient
Get the client to access the Stock Issuances service
getScailoClientForStockReturnsService() StockReturnsServiceClient
Get the client to access the Stock Returns service
getScailoClientForStoragesService() StoragesServiceClient
Get the client to access the Storages service
getScailoClientForStoresService() StoresServiceClient
Get the client to access the Stores service
getScailoClientForSupplyOffersService() SupplyOffersServiceClient
Get the client to access the Supply Offers service
getScailoClientForTaxGroupsService() TaxGroupsServiceClient
Get the client to access the Tax Groups service
getScailoClientForTaxParamsService() TaxParamsServiceClient
Get the client to access the Tax Params service
getScailoClientForTeamsService() TeamsServiceClient
Get the client to access the Teams service
getScailoClientForTransactionalEmailsService() TransactionalEmailsServiceClient
Get the client to access the Transactional Emails service
getScailoClientForUnitsOfMaterialsService() UnitsOfMaterialsServiceClient
Get the client to access the Units Of Materials service
getScailoClientForUsersService() UsersServiceClient
Get the client to access the Users service
getScailoClientForVaultService() VaultServiceClient
Get the client to access the Vault service
getScailoClientForVendorInvoicesService() VendorInvoicesServiceClient
Get the client to access the Vendor Invoices service
getScailoClientForVendorsService() VendorsServiceClient
Get the client to access the Vendors service
getScailoClientForVendorStreamsService() VendorStreamsServiceClient
Get the client to access the Vendor Streams service
getScailoClientForVisitationsService() VisitationsServiceClient
Get the client to access the Visitations service
getScailoClientForWorkflowsRulesService() WorkflowsRulesServiceClient
Get the client to access the Workflows Rules service
getScailoClientForWorkOrdersService() WorkOrdersServiceClient
Get the client to access the Work Orders service
setAuthToken({required String token}) → void
Sets the auth token