sdk/actions_codes.scailo.pb library

Classes

ACTION_CODE_SORT_KEY
Describes the available sort keys
ActionCode
Describes the parameters that are part of a standard response
ActionsCodesList
Describes the message consisting of the list of records
ActionsCodesServiceCountReq
Describes the base request payload of a count search
ActionsCodesServiceCreateRequest
Describes the parameters necessary to create a record
ActionsCodesServiceFilterReq
Describes the base request payload of a filter search
ActionsCodesServicePaginationReq
Describes a pagination request to retrieve records
ActionsCodesServicePaginationResponse
Describes the response to a pagination request
ActionsCodesServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
ActionsCodesServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.