code property
@description The unique alphanumeric identifier used for system classification. This is typically a short string or mnemonic used in logic and filtering.
@example "TECH_SUP_01"
Implementation
@$pb.TagNumber(11)
$core.String get code => $_getSZ(6);
Implementation
@$pb.TagNumber(11)
set code($core.String value) => $_setString(6, value);