code property
@mandatory
@description The unique alphanumeric identifier used for system classification. This is typically a short string or mnemonic used in logic and filtering.
@example "TECH_SUP_01"
@regex .+
@format May contain any UTF-8 characters.
Implementation
@$pb.TagNumber(11)
$core.String get code => $_getSZ(3);
Implementation
@$pb.TagNumber(11)
set code($core.String value) => $_setString(3, value);