description property
@optional
@description Detailed explanation of what this action code represents and when it should be used.
@example "Used for tracking inbound technical support tickets for Tier 1 issues."
@regex .*
@format May contain any UTF-8 characters or be left empty.
Implementation
@$pb.TagNumber(18)
$core.String get description => $_getSZ(8);
Implementation
@$pb.TagNumber(18)
set description($core.String value) => $_setString(8, value);