sdk/activities.scailo.pb library
Classes
- ActivitiesList
- Describes the message consisting of the list of records
- ActivitiesServiceActionCreateRequest
- Describes the parameters required to add an action to an activity
- ActivitiesServiceActionUpdateRequest
- Describes the parameters required to update an action in an activity
- ActivitiesServiceActionWithTimerCreateRequest
- Describes the parameters required to add an action along with an activity timer
- ActivitiesServiceActivityTagAssociationCreateRequest
- Describes the parameters necessary to create an activity tag association
- ActivitiesServiceCountReq
- Describes the base request payload of a count search
- ActivitiesServiceCreateRequest
- Describes the parameters necessary to create a record
- ActivitiesServiceFilterReq
- Describes the base request payload of a filter search
- ActivitiesServiceImportOwnersRequest
- Describes the data model to handle importing of employees from the given identifier representing a team or a department
- ActivitiesServiceOwnerCreateRequest
- Describes the parameters necessary to create an activity owner
- ActivitiesServicePaginatedActionsResponse
- Describes the response to a pagination actions request
- ActivitiesServicePaginatedTimersResponse
- Describes the response to a pagination timers request
- ActivitiesServicePaginationReq
- Describes a pagination request to retrieve records
- ActivitiesServicePaginationResponse
- Describes the response to a pagination request
- ActivitiesServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- ActivitiesServiceSupervisorCreateRequest
- Describes the parameters necessary to create an activity supervisor
- ActivitiesServiceTimerCreateRequest
- Describes the parameters necessary to create an activity timer
- ActivitiesServiceTimerEndRequest
- Describes the parameters necessary to end an activity timer
- ActivitiesServiceUpdateRequest
- Describes the parameters necessary to update a record
- Activity
- Describes the parameters that are part of a standard response
- ACTIVITY_ACTION_SORT_KEY
- Describes the available sort keys
- ACTIVITY_LIFECYCLE
- Describes the lifecycle status of each activity
- ACTIVITY_SORT_KEY
- Describes the available sort keys
- ACTIVITY_TIMER_SORT_KEY
- Describes the available sort keys
- ActivityAction
- Describes the parameters that constitute an action associated to an activity
- ActivityActionHistoryRequest
- Describes the parameters that are required to retrieve the history of the record
- ActivityActionsList
- Describes the message consisting of the list of activity actions
- ActivityActionsSearchRequest
- Describes the request payload to retrieve actions.
- ActivityActionStatistics
- Describes the parameters that are part of an activity action's statistics payload
- ActivityOwner
- Describes the parameters that constitute an activity owner
- ActivityOwnersList
- Describes the message consisting of the list of activity owners
- ActivityStatistics
- Describes the parameters that are part of an activity's statistics payload
- ActivitySupervisor
- Describes the parameters that constitute an activity supervisor
- ActivitySupervisorsList
- Describes the message consisting of the list of activity supervisors
- ActivityTagAssociation
- Describes the parameters that constitute an activity tag association
- ActivityTagAssociationsList
- Describes the message consisting of the list of activity tag associations
- ActivityTimer
- Describes the parameters that constitute an activity timer
- ActivityTimersList
- Describes the message consisting of the list of activity timers
- ActivityTimersSearchRequest
- Describes the request payload to retrieve timers.
- LogbookLogActivityLC
- Describes each parameter that's part of the logbook (does not include historical data of the object) with the operation being an activity lifecycle status
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.