deleteExisting property
Stores if the existing items in the target resource need to be deleted before cloning from the source resource
Implementation
@$pb.TagNumber(3)
$core.bool get deleteExisting => $_getBF(2);
Implementation
@$pb.TagNumber(3)
set deleteExisting($core.bool value) => $_setBool(2, value);