sdk/base.scailo.pbenum library
Classes
- AMENDMENT_LOG_REF_FOR
- Stores the possible values of an amendment log reference
- BOOL_FILTER
- Describes the filter applicable on boolean properties (true, false, or any)
- FORM_FIELD_ELEMENT
- Describes the available form field elements
- FORM_TYPE
- Describes the available form types
- INVENTORY_INTERACTION_CATEGORY
- Stores all the possible categories of inventory interactions
- INVENTORY_ISSUED_PURPOSE
- Stores all the possible issued purposes
- INVENTORY_LIFECYCLE
- Describes the lifecycle status of each inventory
- INVENTORY_SORT_KEY
- Describes the available sort keys
- LOGBOOK_OPERATION
- Describes all the possible values within a logbook operation
- SORT_ORDER
- Describes the order in which the records need to be returned
- STANDARD_LIFECYCLE_STATUS
- Describes the standard lifecycle status of each record