AMENDMENT_LOG_REF_FOR class
Stores the possible values of an amendment log reference
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → AMENDMENT_LOG_REF_FOR?
Constants
- AMENDMENT_LOG_REF_FOR_ANY_UNSPECIFIED → const AMENDMENT_LOG_REF_FOR
- Only used for filter operations
- AMENDMENT_LOG_REF_FOR_EQUATION_WORK_ORDER → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a work order equation
- AMENDMENT_LOG_REF_FOR_FAMILY → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a family
- AMENDMENT_LOG_REF_FOR_PROFORMA_INVOICE → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a proforma invoice
- AMENDMENT_LOG_REF_FOR_PURCHASE_ORDER → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a purchase order
- AMENDMENT_LOG_REF_FOR_SALES_ENQUIRY → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a sales enquiry
- AMENDMENT_LOG_REF_FOR_SALES_INVOICE → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a sales invoice
- AMENDMENT_LOG_REF_FOR_SALES_ORDER → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a sales order
- AMENDMENT_LOG_REF_FOR_SALES_QUOTATION → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a sales quotation
- AMENDMENT_LOG_REF_FOR_SUPPLY_OFFER → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a supply offer
- AMENDMENT_LOG_REF_FOR_WORK_ORDER → const AMENDMENT_LOG_REF_FOR
- Denotes that the log is made while amending a work order
-
values
→ const List<
AMENDMENT_LOG_REF_FOR>