FORM_TYPE class
Describes the available form types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- FORM_TYPE_ABSENCE_FORM → const FORM_TYPE
- The form type is "absence-form"
- FORM_TYPE_ANY_UNSPECIFIED → const FORM_TYPE
- Use this only in filter and search queries so as to retrieve all the records regardless of the form type that they are in
- FORM_TYPE_ASSET_INDENT_FORM → const FORM_TYPE
- The form type is "asset-indent-form"
- FORM_TYPE_ATTENDANCE_AMENDMENT_FORM → const FORM_TYPE
- The form type is "attendanceamendment-form"
- FORM_TYPE_ATTENDANCE_FORM → const FORM_TYPE
- The form type is "attendance-form"
- FORM_TYPE_BANK_ACCOUNT_FORM → const FORM_TYPE
- The form type is "bank-account-form"
- FORM_TYPE_CLIENT_FORM → const FORM_TYPE
- The form type is "client-form"
- FORM_TYPE_COMPONENT_FORM → const FORM_TYPE
- The form type is "component-form"
- FORM_TYPE_CREDIT_NOTE_FORM → const FORM_TYPE
- The form type is "credit-note-form"
- FORM_TYPE_DEBIT_NOTE_FORM → const FORM_TYPE
- The form type is "debit-note-form"
- FORM_TYPE_EQUIPMENT_FORM → const FORM_TYPE
- The form type is "equipment-form"
- FORM_TYPE_EXPENSE_FORM → const FORM_TYPE
- The form type is "expense-form"
- FORM_TYPE_FAMILY_FORM → const FORM_TYPE
- The form type is "family-form"
- FORM_TYPE_FEEDSTOCK_FORM → const FORM_TYPE
- The form type is "feedstock-form"
- FORM_TYPE_GENERAL_SETTINGS_FORM → const FORM_TYPE
- The form type is "general-settings-form"
- FORM_TYPE_GOAL_FORM → const FORM_TYPE
- The form type is "goal-form"
- FORM_TYPE_GOODS_DISPATCH_FORM → const FORM_TYPE
- The form type is "goods-dispatch-form"
- FORM_TYPE_GOODS_RECEIPT_FORM → const FORM_TYPE
- The form type is "goods-receipt-form"
- FORM_TYPE_INFRASTRUCTURE_FORM → const FORM_TYPE
- The form type is "infrastructure-form"
- FORM_TYPE_INWARD_JOB_FORM → const FORM_TYPE
- The form type is "inward-job-form"
- FORM_TYPE_INWARD_JOB_FREE_ISSUE_MATERIAL_FORM → const FORM_TYPE
- The form type is "inward-job-free-issue-material-form"
- FORM_TYPE_INWARD_JOB_FREE_ISSUE_MATERIAL_RETURN_FORM → const FORM_TYPE
- The form type is "inward-job-free-issue-material-return-form"
- FORM_TYPE_LEAVE_REQUEST_FORM → const FORM_TYPE
- The form type is "leave-request-form"
- FORM_TYPE_LOCATION_FORM → const FORM_TYPE
- The form type is "location-form"
- FORM_TYPE_MEETING_FORM → const FORM_TYPE
- The form type is "meeting-form"
- FORM_TYPE_MERCHANDISE_FORM → const FORM_TYPE
- The form type is "merchandise-form"
- FORM_TYPE_ONDUTY_FORM → const FORM_TYPE
- The form type is "onduty-form"
- FORM_TYPE_OUTWARD_JOB_FORM → const FORM_TYPE
- The form type is "outward-job-form"
- FORM_TYPE_OUTWARD_JOB_FREE_ISSUE_MATERIAL_FORM → const FORM_TYPE
- The form type is "outward-job-free-issue-material-form"
- FORM_TYPE_OUTWARD_JOB_FREE_ISSUE_MATERIAL_RETURN_FORM → const FORM_TYPE
- The form type is "outward-job-free-issue-material-return-form"
- FORM_TYPE_OVERTIME_FORM → const FORM_TYPE
- The form type is "overtime-form"
- FORM_TYPE_PRODUCT_FORM → const FORM_TYPE
- The form type is "product-form"
- FORM_TYPE_PRODUCTION_INDENT_FORM → const FORM_TYPE
- The form type is "production-indent-form"
- FORM_TYPE_PRODUCTION_PLAN_FORM → const FORM_TYPE
- The form type is "production-plan-form"
- FORM_TYPE_PROFORMA_INVOICE_FORM → const FORM_TYPE
- The form type is "proforma-invoice-form"
- FORM_TYPE_PROJECT_FORM → const FORM_TYPE
- The form type is "project-form"
- FORM_TYPE_PURCHASE_ENQUIRY_FORM → const FORM_TYPE
- The form type is "purchase-enquiry-form"
- FORM_TYPE_PURCHASE_INDENT_FORM → const FORM_TYPE
- The form type is "purchase-indent-form"
- FORM_TYPE_PURCHASE_ORDER_FORM → const FORM_TYPE
- The form type is "purchase-order-form"
- FORM_TYPE_PURCHASE_RETURN_FORM → const FORM_TYPE
- The form type is "purchase-return-form"
- FORM_TYPE_QC_GROUP_FORM → const FORM_TYPE
- The form type is "qc-group-form"
- FORM_TYPE_QUOTATION_REQUEST_FORM → const FORM_TYPE
- The form type is "quotation-request-form"
- FORM_TYPE_QUOTATION_RESPONSE_FORM → const FORM_TYPE
- The form type is "quotation-response-form"
- FORM_TYPE_REPLACEABLE_INDENT_FORM → const FORM_TYPE
- The form type is "replaceable-indent-form"
- FORM_TYPE_SALARY_FORM → const FORM_TYPE
- The form type is "salary-form"
- FORM_TYPE_SALES_ENQUIRY_FORM → const FORM_TYPE
- The form type is "sales-enquiry-form"
- FORM_TYPE_SALES_INVOICE_FORM → const FORM_TYPE
- The form type is "sales-invoice-form"
- FORM_TYPE_SALES_ORDER_FORM → const FORM_TYPE
- The form type is "sales-order-form"
- FORM_TYPE_SALES_QUOTATION_FORM → const FORM_TYPE
- The form type is "sales-quotation-form"
- FORM_TYPE_SALES_RETURN_FORM → const FORM_TYPE
- The form type is "sales-return-form"
- FORM_TYPE_SKILL_GROUP_FORM → const FORM_TYPE
- The form type is "skill-group-form"
- FORM_TYPE_SKILL_PARAM_FORM → const FORM_TYPE
- The form type is "skill-param-form"
- FORM_TYPE_STOCK_AUDIT_FORM → const FORM_TYPE
- The form type is "stock-audit-form"
- FORM_TYPE_STOCK_ISSUANCE_FORM → const FORM_TYPE
- The form type is "stock-issuance-form"
- FORM_TYPE_STOCK_RETURN_FORM → const FORM_TYPE
- The form type is "stock-return-form"
- FORM_TYPE_SUPPLY_OFFER_FORM → const FORM_TYPE
- The form type is "supply-offer-form"
- FORM_TYPE_USER_FORM → const FORM_TYPE
- The form type is "user-form"
- FORM_TYPE_VENDOR_FORM → const FORM_TYPE
- The form type is "vendor-form"
- FORM_TYPE_VENDOR_INVOICE_FORM → const FORM_TYPE
- The form type is "vendor-invoice-form"
- FORM_TYPE_VISITATION_FORM → const FORM_TYPE
- The form type is "visitation-form"
- FORM_TYPE_WORK_ORDER_FORM → const FORM_TYPE
- The form type is "work-order-form"
-
values
→ const List<
FORM_TYPE>