ClientStream class
Describes the parameters that are part of a standard response
- Available extensions
Constructors
-
ClientStream({String? entityUuid, EmployeeMetadata? metadata, CLIENT_STREAM_LIFECYCLE? status, Iterable<
LogbookLogClientStreamLC> ? logs, Int64? completedOn, Int64? vaultFolderId, String? title, Int64? clientId, CLIENT_STREAM_REF_FROM? refFrom, Int64? refId, String? refUuid, String? internalRef, Int64? unreadCount, Int64? messageCount, String? lastMessageBy, String? vaultFolderUuid}) -
factory
-
ClientStream.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- ClientStream.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- clientId ↔ Int64
-
The ID of the client
getter/setter pair
- completedOn ↔ Int64
-
The timestamp of when this client stream was marked as completed
getter/setter pair
- entityUuid ↔ String
-
Stores a globally unique entity UUID. This will be set at the organization level
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- internalRef ↔ String
-
Stores the internal reference that is automatically generated
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - lastMessageBy ↔ String
-
Stores the username of the user who added the last message
getter/setter pair
-
logs
→ PbList<
LogbookLogClientStreamLC> -
Stores the logs of every operation performed on this client stream
no setter
- messageCount ↔ Int64
-
Stores the total number of messages in the stream
getter/setter pair
- metadata ↔ EmployeeMetadata
-
Stores the metadata of this client stream
getter/setter pair
- refFrom ↔ CLIENT_STREAM_REF_FROM
-
The associated reference
getter/setter pair
- refId ↔ Int64
-
The associated reference ID
getter/setter pair
- refUuid ↔ String
-
The associated reference UUID
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ CLIENT_STREAM_LIFECYCLE
-
The status of this client stream
getter/setter pair
- title ↔ String
-
The title of the client stream
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- unreadCount ↔ Int64
-
Stores the number of unread messages in this stream for the specific user (on the basis of the auth token)
getter/setter pair
- vaultFolderId ↔ Int64
-
The associated vault folder ID
getter/setter pair
- vaultFolderUuid ↔ String
-
The associated vault folder UUID (will be empty if vault_folder_id is 0)
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearClientId(
) → void -
clearCompletedOn(
) → void -
clearEntityUuid(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearInternalRef(
) → void -
clearLastMessageBy(
) → void -
clearMessageCount(
) → void -
clearMetadata(
) → void -
clearRefFrom(
) → void -
clearRefId(
) → void -
clearRefUuid(
) → void -
clearStatus(
) → void -
clearTitle(
) → void -
clearUnreadCount(
) → void -
clearVaultFolderId(
) → void -
clearVaultFolderUuid(
) → void -
clone(
) → ClientStream - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(ClientStream)) → ClientStream -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → ClientStream - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureMetadata(
) → EmployeeMetadata -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasClientId(
) → bool -
hasCompletedOn(
) → bool -
hasEntityUuid(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasInternalRef(
) → bool -
hasLastMessageBy(
) → bool -
hasMessageCount(
) → bool -
hasMetadata(
) → bool -
hasRefFrom(
) → bool -
hasRefId(
) → bool -
hasRefUuid(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasStatus(
) → bool -
hasTitle(
) → bool -
hasUnreadCount(
) → bool -
hasVaultFolderId(
) → bool -
hasVaultFolderUuid(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → ClientStream -
getDefault(
) → ClientStream