ClientStreamsServiceClient class

Describes the common methods applicable on each client stream

Annotations
  • @GrpcServiceName.new('Scailo.ClientStreamsService')

Constructors

ClientStreamsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addClientSubscriber(ClientStreamsServiceClientSubscriberCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add a client subscriber
addInternalSubscriber(ClientStreamsServiceInternalSubscriberCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an internal subscriber
addMessage(ClientStreamsServiceMessageCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add a message to an client stream
attachVaultFolder(VaultFolderAttachRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Attaches a specified folder directly to a record without requiring a full revision workflow.
cancel(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Cancel
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Complete
count(ClientStreamsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Returns the total count of records matching the given complex filter criteria.
create(ClientStreamsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Create
deleteClientSubscriber(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete a client subscriber
deleteInternalSubscriber(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an internal subscriber
deleteMessage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Delete a message in an client stream
downloadAsCSV(ClientStreamsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request
filter(ClientStreamsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<ClientStreamsList>
Performs a high-granularity search based on multiple specific field filters.
importInternalSubscribersFromDepartment(ClientStreamsServiceImportInternalSubscribersRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Import users as internal subscribers from department and returns the ID of the client stream
importInternalSubscribersFromTeam(ClientStreamsServiceImportInternalSubscribersRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Import users as internal subscribers from team and returns the ID of the client stream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Reopen
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Repeat
saveMessageForLater(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Saves a message for viewing it later
searchAll(ClientStreamsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<ClientStreamsList>
Performs a free-text search across records using a search key.
searchMessagesWithPagination(ClientStreamMessagesSearchRequest request, {CallOptions? options}) → ResponseFuture<ClientStreamsServicePaginatedMessagesResponse>
Search through client stream messages with pagination
toString() String
A string representation of this object.
inherited
update(ClientStreamsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Update
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<ClientStreamsList>
Returns all records filtered by their active status.
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ClientStreamsList>
Returns all records belonging to a specific organization/entity UUID.
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<ClientStream>
Retrieves a single record by its internal numeric ID. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ClientStream>
Retrieves a single record by its globally unique UUID. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewClientSubscriberByID(Identifier request, {CallOptions? options}) → ResponseFuture<ClientStreamClientSubscriber>
View client subscriber for the given ID
viewClientSubscribers(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ClientStreamClientSubscribersList>
View all client subscribers for given client stream UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<ClientStream>
Retrieves a record by ID excluding high-volume fields like logs for performance. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ClientStream>
Retrieves a record by UUID excluding high-volume fields like logs. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<ClientStreamsList>
Retrieves a list of records matching the provided array of internal IDs.
viewInternalSubscriberByID(Identifier request, {CallOptions? options}) → ResponseFuture<ClientStreamInternalSubscriber>
View an internal subscriber for the given ID
viewInternalSubscribers(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ClientStreamInternalSubscribersList>
View all internal subscribers for given client stream UUID
viewMessageByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ClientStreamMessage>
View Client Stream Message by UUID
viewMessageReceipts(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ClientStreamMessageReceiptsList>
View all receipts for the given message UUID
viewMessages(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<ClientStreamMessagesList>
View all messages for given client stream UUID
viewPaginatedMessages(ClientStreamMessagesSearchRequest request, {CallOptions? options}) → ResponseFuture<ClientStreamsServicePaginatedMessagesResponse>
View client stream messages for given client stream ID with pagination
viewWithPagination(ClientStreamsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<ClientStreamsServicePaginationResponse>
Retrieves a paginated list of records based on status, sort keys, and offsets.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.