sdk/clients.scailo.pb library
Classes
- Client
- Describes the parameters that are part of a standard response
- CLIENT_SORT_KEY
- Describes the available sort keys
- CLIENT_USER_STATUS
- Describes the applicable statuses of client users
- ClientsList
- Describes the message consisting of the list of records
- ClientsServiceCountReq
- Describes the base request payload of a count search
- ClientsServiceCreateRequest
- Describes the parameters necessary to create a record
- ClientsServiceFilterReq
- Describes the base request payload of a filter search
- ClientsServicePaginatedUsersResponse
- Describes the response to a pagination items request
- ClientsServicePaginationReq
- Describes a pagination request to retrieve records
- ClientsServicePaginationResponse
- Describes the response to a pagination request
- ClientsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- ClientsServiceUpdateRequest
- Describes the parameters necessary to update a record
- ClientsServiceUserCreateRequest
- Describes the parameters necessary to create a client user
- ClientUser
- Describes the parameters that constitute a client user
- ClientUsersList
- Describes the message consisting of the list of client users
- ClientUsersSearchRequest
- Describes the request payload to search client users
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.