sdk/components.scailo.pb library
Classes
- Component
- Describes the parameters that are part of a standard response
- COMPONENT_REF_FROM
- Stores all the possible references from which a component can be added
- ComponentsList
- Describes the message consisting of the list of records
- ComponentsServiceCountReq
- Describes the base request payload of a count search
- ComponentsServiceCreateRequest
- Describes the parameters necessary to create a record
- ComponentsServiceFilterReq
- Describes the base request payload of a filter search
- ComponentsServicePaginationReq
- Describes a pagination request to retrieve records
- ComponentsServicePaginationResponse
- Describes the response to a pagination request
- ComponentsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- ComponentsServiceSendToStoreRequest
- Describes the parameters necessary to send a component to store
- ComponentsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.