COMPONENT_REF_FROM class
Stores all the possible references from which a component can be added
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → COMPONENT_REF_FROM?
Constants
- COMPONENT_REF_FROM_ANY_UNSPECIFIED → const COMPONENT_REF_FROM
- Used only in filters
- COMPONENT_REF_FROM_GOODS_RECEIPT → const COMPONENT_REF_FROM
- Denotes that the component originated from a goods receipt
- COMPONENT_REF_FROM_INITIAL_STOCK → const COMPONENT_REF_FROM
- Denotes that the component originated from initial stock
- COMPONENT_REF_FROM_INWARD_JOB_FREE_ISSUE_MATERIAL → const COMPONENT_REF_FROM
- Denotes that the component originated from an inward job free issue material
- COMPONENT_REF_FROM_OUTWARD_JOB_FREE_ISSUE_MATERIAL → const COMPONENT_REF_FROM
- Denotes that the component originated from an outward job free issue material
- COMPONENT_REF_FROM_PRODUCTION_PLAN → const COMPONENT_REF_FROM
- Denotes that the component originated from a production plan
-
values
→ const List<
COMPONENT_REF_FROM>