ComponentsServiceClient class
Describes the common methods applicable on each component
- Annotations
-
- @GrpcServiceName.new('Scailo.ComponentsService')
Constructors
-
ComponentsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
attachVaultFolder(
VaultFolderAttachRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Attaches a specified folder directly to a record without requiring a full revision workflow.
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Adds an audit comment to the record's history without changing its current lifecycle status.
-
consume(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Consume
-
count(
ComponentsServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Returns the total count of records matching the given complex filter criteria.
-
create(
ComponentsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create (and Send for QC)
-
createMagicLink(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Generates a magic link for temporary, authenticated access to the resource.
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
ComponentsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request
-
downloadImportTemplate(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload records
-
downloadLabelByID(
Identifier request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download Label for the given Identifier
-
downloadLabelByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download Label for the given IdentifierUUID (can be used to allow public downloads)
-
downloadQCReportByID(
Identifier request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download QC Report with the given Identifier
-
downloadQCReportByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download QC Report with the given IdentifierUUID (can be used to allow public downloads)
-
filter(
ComponentsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< ComponentsList> - Performs a high-granularity search based on multiple specific field filters.
-
filterFamiliesInProductionPlan(
FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture< FamiliesList> - Filter component families for the given production plan
-
importFromCSV(
StandardFile request, {CallOptions? options}) → ResponseFuture< IdentifierUUIDsList> - Bulk imports records from a provided CSV file. Behavior:
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
partition(
InventoryPartitionRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create a partition from the parent lot (and returns the identifier of the new partition)
-
reject(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reject
-
returnMaterial(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Return
-
scrap(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Scrap
-
searchAll(
ComponentsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< ComponentsList> - Performs a free-text search across records using a search key.
-
sendForQC(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for QC
-
sendForRework(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for Rework
-
sendToStore(
ComponentsServiceSendToStoreRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send to Store
-
splitLot(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Split into unit quantities
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
ComponentsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< ComponentsList> - Returns all records filtered by their active status.
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Component> - Retrieves a single record by its internal numeric ID. This operation is optimized for high-performance internal system logic and backend-to-backend communication
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Component> - Retrieves a single record by its globally unique UUID. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Component> - Retrieves a record by ID excluding high-volume fields like logs for performance. This operation is optimized for high-performance internal system logic and backend-to-backend communication
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Component> - Retrieves a record by UUID excluding high-volume fields like logs. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
-
viewFamiliesInProductionPlan(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< FamiliesList> - View component families for the given production plan
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< ComponentsList> - Retrieves a list of records matching the provided array of internal IDs.
-
viewFromUUIDs(
IdentifierUUIDsList request, {CallOptions? options}) → ResponseFuture< ComponentsList> - View all records with the given UUIDs
-
viewInventoryInteractions(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< InventoryInteractionsList> - View all inventory interactions for component with the given IdentifierUUID
-
viewVendorInvoiceUnitPrice(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< PriceResponse> - View the unit price at which the inventory item was purchased (the corresponding vendor invoice price)
-
viewWithPagination(
ComponentsServicePaginationReq request, {CallOptions? options}) → ResponseFuture< ComponentsServicePaginationResponse> - Retrieves a paginated list of records based on status, sort keys, and offsets.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.