CreditNotesServiceClient class
Describes the common methods applicable on each credit note
- Annotations
-
- @GrpcServiceName.new('Scailo.CreditNotesService')
Constructors
-
CreditNotesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
accruedValue(
CreditNotesServiceCountReq request, {CallOptions? options}) → ResponseFuture< SumResponse> - Returns the sum of the total value of all the records that match the given criteria
-
addCreditNoteItem(
CreditNotesServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an item to a credit note
-
addCreditNoteReference(
CreditNotesServiceReferenceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add a reference
-
addMultipleCreditNoteItems(
CreditNotesServiceMultipleItemsCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add multiple items to a credit note
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approveCreditNoteItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve an item in a credit note
-
approveCreditNoteReference(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve a reference
-
autofill(
CreditNotesServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Autofill the credit note
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
CreditNotesServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
CreditNotesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
createMagicLink(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Create a magic link
-
deleteCreditNoteItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an item in a credit note
-
deleteCreditNoteReference(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete a reference
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
CreditNotesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download credit note with the given IdentifierUUID (can be used to allow public downloads)
-
downloadItemsAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
-
downloadItemsTemplateAsCSV(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload items
-
draft(
CreditNotesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
CreditNotesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
CreditNotesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< CreditNotesList> - View all that match the given filter criteria
-
filterProspectiveFamilies(
FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture< FamiliesList> - Filter prospective families for the record represented by the given UUID identifier
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
isDownloadable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the record is downloadable (checks if the custom download function has been implemented)
-
modifyCreditNoteItem(
CreditNotesServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an item in a credit note
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderCreditNoteItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder items in a credit note
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
CreditNotesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
CreditNotesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< CreditNotesList> - View all that match the given search key
-
searchItemsWithPagination(
CreditNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< CreditNotesServicePaginatedItemsResponse> - Search through credit note items with pagination
-
sendEmail(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send Email
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadCreditNoteItems(
IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture< IdentifiersList> - Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAddedFamilyQuantityForSource(
CreditNotesServiceAlreadyAddedQuantityForSourceRequest request, {CallOptions? options}) → ResponseFuture< DualQuantitiesResponse> - View already added quantities
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< CreditNotesList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< CreditNotesList> - View all with the given entity UUID
-
viewAncillaryParametersByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< CreditNoteAncillaryParameters> - View the ancillary parameters (UUIDs of the internal references) by UUID
-
viewApprovedCreditNoteItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< CreditNoteItemsList> - View approved credit note items for given credit note ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< CreditNote> - View by ID
-
viewByReferenceID(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< CreditNote> - View by Reference ID (returns the latest record in case of duplicates)
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< CreditNote> - View by UUID
-
viewCreditNoteItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< CreditNoteItem> - View Credit Note Item by ID
-
viewCreditNoteItemHistory(
CreditNoteItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< CreditNoteItemsList> - View the history of the credit note item
-
viewCreditNoteReferenceByID(
Identifier request, {CallOptions? options}) → ResponseFuture< CreditNoteReference> - View a reference for the given ID
-
viewCreditNoteReferences(
Identifier request, {CallOptions? options}) → ResponseFuture< CreditNoteReferencesList> - View all references for given credit note ID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< CreditNote> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< CreditNote> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< CreditNotesList> - View all records with the given IDs
-
viewPaginatedApprovedCreditNoteItems(
CreditNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< CreditNotesServicePaginatedItemsResponse> - View approved credit note items for given credit note ID with pagination
-
viewPaginatedUnapprovedCreditNoteItems(
CreditNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< CreditNotesServicePaginatedItemsResponse> - View unapproved credit note items for given credit note ID with pagination
-
viewProspectiveCreditNoteItem(
CreditNoteItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture< CreditNotesServiceItemCreateRequest> - View prospective credit note item info for the given family ID and credit note ID
-
viewProspectiveFamilies(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< FamiliesList> - View prospective families for the given credit note
-
viewReturnedStatistics(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< CreditNoteReturnStatisticsList> - View returned (sales return) statistics of the credit note
-
viewUnapprovedCreditNoteItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< CreditNoteItemsList> - View unapproved credit note items for given credit note ID
-
viewWithPagination(
CreditNotesServicePaginationReq request, {CallOptions? options}) → ResponseFuture< CreditNotesServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.