sdk/currencies.scailo.pb library
Classes
- CurrenciesList
- Describes the message consisting of the list of records
- CurrenciesServiceCountReq
- Describes the base request payload of a count search
- CurrenciesServiceCreateRequest
- Describes the parameters necessary to create a record
- CurrenciesServiceFilterReq
- Describes the base request payload of a filter search
- CurrenciesServicePaginationReq
- Describes a pagination request to retrieve records
- CurrenciesServicePaginationResponse
- Describes the response to a pagination request
- CurrenciesServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- CurrenciesServiceUpdateRequest
- Describes the parameters necessary to update a record
- Currency
- Describes the parameters that are part of a standard response
- CURRENCY_SORT_KEY
- Describes the available sort keys
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.