DebitNotesServiceClient class
Describes the common methods applicable on each debit note
- Annotations
-
- @GrpcServiceName.new('Scailo.DebitNotesService')
Constructors
-
DebitNotesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
accruedValue(
DebitNotesServiceCountReq request, {CallOptions? options}) → ResponseFuture< SumResponse> - Returns the sum of the total value of all the records that match the given criteria
-
addDebitNoteItem(
DebitNotesServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an item to a debit note
-
addDebitNoteReference(
DebitNotesServiceReferenceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add a reference
-
addMultipleDebitNoteItems(
DebitNotesServiceMultipleItemsCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add multiple items to a debit note
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Officially approves the record.
-
approveDebitNoteItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve an item in a debit note
-
approveDebitNoteReference(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve a reference
-
attachVaultFolder(
VaultFolderAttachRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Attaches a specified folder directly to a record without requiring a full revision workflow.
-
autofill(
DebitNotesServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Automatically populates a record with line items and configurations derived from its linked references.
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Adds an audit comment to the record's history without changing its current lifecycle status.
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Marks the record as finalized and fully processed.
-
count(
DebitNotesServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Returns the total count of records matching the given complex filter criteria.
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Returns the total number of records currently in a specific lifecycle status.
-
create(
DebitNotesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
createMagicLink(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Generates a magic link for temporary, authenticated access to the resource.
-
deleteDebitNoteItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an item in a debit note
-
deleteDebitNoteReference(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete a reference
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Permanently cancels the record.
-
downloadAsCSV(
DebitNotesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Retrieves the underlying file or document payload associated with a specific entity using its universally unique identifier (UUID).
-
downloadItemsAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
-
downloadItemsTemplateAsCSV(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload items
-
draft(
DebitNotesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Saves a new record as a draft without triggering side effects.
-
draftUpdate(
DebitNotesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> -
Updates an existing record that is currently in
DRAFTstatus. -
filter(
DebitNotesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< DebitNotesList> - Performs a high-granularity search based on multiple specific field filters.
-
filterProspectiveFamilies(
FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture< FamiliesList> - Filter prospective families for the record represented by the given UUID identifier
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Temporarily halts processing of the record.
-
isDownloadable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Evaluates the download eligibility of a specific record using its universally unique identifier (UUID).
-
modifyDebitNoteItem(
DebitNotesServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an item in a debit note
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopens a finalized or closed record for further modifications.
-
reorderDebitNoteItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder items in a debit note
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Creates a new record based on an existing one (cloning).
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> -
Restores a previously
DISCARDEDorHALTEDrecord. -
revisionUpdate(
DebitNotesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> -
Updates a record that has been sent back for
REVISION. -
searchAll(
DebitNotesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< DebitNotesList> - Performs a free-text search across records using a search key.
-
searchItemsWithPagination(
DebitNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< DebitNotesServicePaginatedItemsResponse> - Search through debit note items with pagination
-
sendEmail(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Triggers an automated email notification related to the record.
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Sends the record back to the creator for corrections.
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> -
Submits a record in
DRAFTorREVISIONstatus for verification. -
toString(
) → String -
A string representation of this object.
inherited
-
uploadDebitNoteItems(
IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture< IdentifiersList> - Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Marks a record as verified, signaling that it is ready for final approval.
-
viewAddedFamilyQuantityForSource(
DebitNotesServiceAlreadyAddedQuantityForSourceRequest request, {CallOptions? options}) → ResponseFuture< DualQuantitiesResponse> - View already added quantities
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< DebitNotesList> - Returns all records filtered by their active status.
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< DebitNotesList> - Returns all records belonging to a specific organization/entity UUID.
-
viewAncillaryParametersByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< DebitNoteAncillaryParameters> - View the ancillary parameters (UUIDs of the internal references) by UUID
-
viewApprovedDebitNoteItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< DebitNoteItemsList> - View approved debit note items for given debit note ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< DebitNote> - Retrieves a single record by its internal numeric ID. This operation is optimized for high-performance internal system logic and backend-to-backend communication
-
viewByReferenceID(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< DebitNote> - Retrieves a single record based on its user-defined, external reference ID.
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< DebitNote> - Retrieves a single record by its globally unique UUID. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
-
viewDebitNoteItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< DebitNoteItem> - View Debit Note Item by ID
-
viewDebitNoteItemHistory(
DebitNoteItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< DebitNoteItemsList> - View the history of the debit note item
-
viewDebitNoteReferenceByID(
Identifier request, {CallOptions? options}) → ResponseFuture< DebitNoteReference> - View a reference for the given ID
-
viewDebitNoteReferences(
Identifier request, {CallOptions? options}) → ResponseFuture< DebitNoteReferencesList> - View all references for given debit note ID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< DebitNote> - Retrieves a record by ID excluding high-volume fields like logs for performance. This operation is optimized for high-performance internal system logic and backend-to-backend communication
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< DebitNote> - Retrieves a record by UUID excluding high-volume fields like logs. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< DebitNotesList> - Retrieves a list of records matching the provided array of internal IDs.
-
viewPaginatedApprovedDebitNoteItems(
DebitNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< DebitNotesServicePaginatedItemsResponse> - View approved debit note items for given debit note ID with pagination
-
viewPaginatedUnapprovedDebitNoteItems(
DebitNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< DebitNotesServicePaginatedItemsResponse> - View unapproved debit note items for given debit note ID with pagination
-
viewProspectiveDebitNoteItem(
DebitNoteItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture< DebitNotesServiceItemCreateRequest> - View prospective debit note item info for the given family ID and debit note ID
-
viewProspectiveFamilies(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< FamiliesList> - View prospective families for the given debit note
-
viewReturnedStatistics(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< DebitNoteReturnStatisticsList> - View returned (purchase return) statistics of the debit note
-
viewUnapprovedDebitNoteItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< DebitNoteItemsList> - View unapproved debit note items for given debit note ID
-
viewWithPagination(
DebitNotesServicePaginationReq request, {CallOptions? options}) → ResponseFuture< DebitNotesServicePaginationResponse> - Retrieves a paginated list of records based on status, sort keys, and offsets.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.