DebitNotesServiceClient class

Describes the common methods applicable on each debit note

Annotations
  • @GrpcServiceName.new('Scailo.DebitNotesService')

Constructors

DebitNotesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
accruedValue(DebitNotesServiceCountReq request, {CallOptions? options}) → ResponseFuture<SumResponse>
Returns the sum of the total value of all the records that match the given criteria
addDebitNoteItem(DebitNotesServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an item to a debit note
addDebitNoteReference(DebitNotesServiceReferenceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add a reference
addMultipleDebitNoteItems(DebitNotesServiceMultipleItemsCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add multiple items to a debit note
approve(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve
approveDebitNoteItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve an item in a debit note
approveDebitNoteReference(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Approve a reference
autofill(DebitNotesServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Autofill the debit note
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Complete
count(DebitNotesServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
countInStatus(CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count in status
create(DebitNotesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and send for verification
Create a magic link
deleteDebitNoteItem(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an item in a debit note
deleteDebitNoteReference(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete a reference
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard
downloadAsCSV(DebitNotesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
downloadByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download debit note with the given IdentifierUUID (can be used to allow public downloads)
downloadItemsAsCSV(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
downloadItemsTemplateAsCSV(Empty request, {CallOptions? options}) → ResponseFuture<StandardFile>
Download the CSV template that could be used to upload items
draft(DebitNotesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Create and save as draft
draftUpdate(DebitNotesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update draft
filter(DebitNotesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<DebitNotesList>
View all that match the given filter criteria
filterProspectiveFamilies(FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture<FamiliesList>
Filter prospective families for the record represented by the given UUID identifier
halt(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Halt
isDownloadable(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Checks if the record is downloadable (checks if the custom download function has been implemented)
modifyDebitNoteItem(DebitNotesServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Modify an item in a debit note
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reopen
reorderDebitNoteItems(ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Reorder items in a debit note
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Repeat
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore
revisionUpdate(DebitNotesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Update revision
searchAll(DebitNotesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<DebitNotesList>
View all that match the given search key
searchItemsWithPagination(DebitNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<DebitNotesServicePaginatedItemsResponse>
Search through debit note items with pagination
sendEmail(IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send Email
sendForRevision(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send For Revision
sendForVerification(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Send for verification
toString() String
A string representation of this object.
inherited
uploadDebitNoteItems(IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture<IdentifiersList>
Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
verify(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Verify
viewAddedFamilyQuantityForSource(DebitNotesServiceAlreadyAddedQuantityForSourceRequest request, {CallOptions? options}) → ResponseFuture<DualQuantitiesResponse>
View already added quantities
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<DebitNotesList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<DebitNotesList>
View all with the given entity UUID
viewAncillaryParametersByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<DebitNoteAncillaryParameters>
View the ancillary parameters (UUIDs of the internal references) by UUID
viewApprovedDebitNoteItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<DebitNoteItemsList>
View approved debit note items for given debit note ID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<DebitNote>
View by ID
viewByReferenceID(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<DebitNote>
View by Reference ID (returns the latest record in case of duplicates)
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<DebitNote>
View by UUID
viewDebitNoteItemByID(Identifier request, {CallOptions? options}) → ResponseFuture<DebitNoteItem>
View Debit Note Item by ID
viewDebitNoteItemHistory(DebitNoteItemHistoryRequest request, {CallOptions? options}) → ResponseFuture<DebitNoteItemsList>
View the history of the debit note item
viewDebitNoteReferenceByID(Identifier request, {CallOptions? options}) → ResponseFuture<DebitNoteReference>
View a reference for the given ID
viewDebitNoteReferences(Identifier request, {CallOptions? options}) → ResponseFuture<DebitNoteReferencesList>
View all references for given debit note ID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<DebitNote>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<DebitNote>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<DebitNotesList>
View all records with the given IDs
viewPaginatedApprovedDebitNoteItems(DebitNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<DebitNotesServicePaginatedItemsResponse>
View approved debit note items for given debit note ID with pagination
viewPaginatedUnapprovedDebitNoteItems(DebitNoteItemsSearchRequest request, {CallOptions? options}) → ResponseFuture<DebitNotesServicePaginatedItemsResponse>
View unapproved debit note items for given debit note ID with pagination
viewProspectiveDebitNoteItem(DebitNoteItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture<DebitNotesServiceItemCreateRequest>
View prospective debit note item info for the given family ID and debit note ID
viewProspectiveFamilies(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<FamiliesList>
View prospective families for the given debit note
viewReturnedStatistics(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<DebitNoteReturnStatisticsList>
View returned (purchase return) statistics of the debit note
viewUnapprovedDebitNoteItems(IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture<DebitNoteItemsList>
View unapproved debit note items for given debit note ID
viewWithPagination(DebitNotesServicePaginationReq request, {CallOptions? options}) → ResponseFuture<DebitNotesServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.