draftUpdate method
ResponseFuture<IdentifierResponse>
draftUpdate(
- DebitNotesServiceUpdateRequest request, {
- CallOptions? options,
Updates an existing record that is currently in DRAFT status.
This method allows modification of all primary attributes while the record is not yet verified.
Errors:
FAILED_PRECONDITION: If the record is not in aDRAFTstate.NOT_FOUND: If the provided ID does not exist.
Implementation
$grpc.ResponseFuture<$1.IdentifierResponse> draftUpdate(
$0.DebitNotesServiceUpdateRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$draftUpdate, request, options: options);
}