sdk/forms_fields.scailo.pb library
Classes
- FORM_FIELD_SORT_KEY
- Describes the available sort keys for retrieving forms fields
- FormField
- Describes the data structure of each form field on the platform
- FormFieldPaginationResp
- Describes the data structure that responds to a pagination request
- FormsFieldsList
- Describes the data structure that stores a list of forms fields
- FormsFieldsServiceCountReq
- Describes the base request payload of a count search
- FormsFieldsServiceCreateRequest
- Describes the necessary data structure during creation of a form field
- FormsFieldsServiceFilterReq
- Describes the base request payload of a filter search
- FormsFieldsServicePaginationReq
- Describes a pagination request to retrieve records
- FormsFieldsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on forms fields
- FormsFieldsServiceUpdateRequest
- Describes the data structure to perform the update (draft/revision) operation on a form field
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.