isReadonly property
Denotes if the field is readonly (changes shall not be allowed to be made on the UI). Any changes will still be made through the API
Implementation
@$pb.TagNumber(30)
$core.bool get isReadonly => $_getBF(11);
Implementation
@$pb.TagNumber(30)
set isReadonly($core.bool value) => $_setBool(11, value);