- Annotations
-
- @GrpcServiceName.new('Scailo.FormsFieldsService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
count(ServiceCall call, FormsFieldsServiceCountReq request)
→ Future<CountResponse>
-
-
count_Pre(ServiceCall $call, Future<FormsFieldsServiceCountReq> $request)
→ Future<CountResponse>
-
-
create(ServiceCall call, FormsFieldsServiceCreateRequest request)
→ Future<FormField>
-
-
create_Pre(ServiceCall $call, Future<FormsFieldsServiceCreateRequest> $request)
→ Future<FormField>
-
-
discard(ServiceCall call, IdentifierUUIDWithUserComment request)
→ Future<IdentifierResponse>
-
-
discard_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request)
→ Future<IdentifierResponse>
-
-
downloadAsCSV(ServiceCall call, FormsFieldsServiceFilterReq request)
→ Future<StandardFile>
-
-
downloadAsCSV_Pre(ServiceCall $call, Future<FormsFieldsServiceFilterReq> $request)
→ Future<StandardFile>
-
-
filter(ServiceCall call, FormsFieldsServiceFilterReq request)
→ Future<FormsFieldsList>
-
-
filter_Pre(ServiceCall $call, Future<FormsFieldsServiceFilterReq> $request)
→ Future<FormsFieldsList>
-
-
importFromCSV(ServiceCall call, StandardFile request)
→ Future<IdentifierUUIDsList>
-
-
importFromCSV_Pre(ServiceCall $call, Future<StandardFile> $request)
→ Future<IdentifierUUIDsList>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
restore(ServiceCall call, IdentifierUUIDWithUserComment request)
→ Future<IdentifierResponse>
-
-
restore_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request)
→ Future<IdentifierResponse>
-
-
searchAll(ServiceCall call, FormsFieldsServiceSearchAllReq request)
→ Future<FormsFieldsList>
-
-
searchAll_Pre(ServiceCall $call, Future<FormsFieldsServiceSearchAllReq> $request)
→ Future<FormsFieldsList>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(ServiceCall call, FormsFieldsServiceUpdateRequest request)
→ Future<FormField>
-
-
update_Pre(ServiceCall $call, Future<FormsFieldsServiceUpdateRequest> $request)
→ Future<FormField>
-
-
viewAll(ServiceCall call, ActiveStatus request)
→ Future<FormsFieldsList>
-
-
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request)
→ Future<FormsFieldsList>
-
-
viewAllForEntityUUID(ServiceCall call, IdentifierUUID request)
→ Future<FormsFieldsList>
-
-
viewAllForEntityUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request)
→ Future<FormsFieldsList>
-
-
viewByCode(ServiceCall call, SimpleSearchReq request)
→ Future<FormField>
-
-
viewByCode_Pre(ServiceCall $call, Future<SimpleSearchReq> $request)
→ Future<FormField>
-
-
viewByID(ServiceCall call, Identifier request)
→ Future<FormField>
-
-
viewByID_Pre(ServiceCall $call, Future<Identifier> $request)
→ Future<FormField>
-
-
viewByUUID(ServiceCall call, IdentifierUUID request)
→ Future<FormField>
-
-
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request)
→ Future<FormField>
-
-
viewEssentialByID(ServiceCall call, Identifier request)
→ Future<FormField>
-
-
viewEssentialByID_Pre(ServiceCall $call, Future<Identifier> $request)
→ Future<FormField>
-
-
viewEssentialByUUID(ServiceCall call, IdentifierUUID request)
→ Future<FormField>
-
-
viewEssentialByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request)
→ Future<FormField>
-
-
viewFromIDs(ServiceCall call, IdentifiersList request)
→ Future<FormsFieldsList>
-
-
viewFromIDs_Pre(ServiceCall $call, Future<IdentifiersList> $request)
→ Future<FormsFieldsList>
-
-
-