FormsFieldsServiceClient class

Describes the methods applicable on each form field

Annotations
  • @GrpcServiceName.new('Scailo.FormsFieldsService')

Constructors

FormsFieldsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
count(FormsFieldsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Returns the total count of records matching the given complex filter criteria.
create(FormsFieldsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<FormField>
Create a form field
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard the form field
downloadAsCSV(FormsFieldsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
filter(FormsFieldsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<FormsFieldsList>
Performs a high-granularity search based on multiple specific field filters.
importFromCSV(StandardFile request, {CallOptions? options}) → ResponseFuture<IdentifierUUIDsList>
Bulk imports records from a provided CSV file. Behavior:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore the form field
searchAll(FormsFieldsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<FormsFieldsList>
View all forms fields that match the given search key
toString() String
A string representation of this object.
inherited
update(FormsFieldsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<FormField>
Update a form field
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<FormsFieldsList>
View all forms fields
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<FormsFieldsList>
View all forms fields with the given entity UUID
viewByCode(SimpleSearchReq request, {CallOptions? options}) → ResponseFuture<FormField>
Retrieves a single record via the assigned internal code.
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<FormField>
Retrieves a single record by its internal numeric ID. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<FormField>
Retrieves a single record by its globally unique UUID. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<FormField>
Retrieves a record by ID excluding high-volume fields like logs for performance. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<FormField>
Retrieves a record by UUID excluding high-volume fields like logs. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<FormsFieldsList>
Retrieves a list of records matching the provided array of internal IDs.
viewWithPagination(FormsFieldsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<FormFieldPaginationResp>
View forms fields with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.