- Annotations
-
- @GrpcServiceName.new('Scailo.FormsSectionsService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
count(ServiceCall call, FormsSectionsServiceCountReq request)
→ Future<CountResponse>
-
-
count_Pre(ServiceCall $call, Future<FormsSectionsServiceCountReq> $request)
→ Future<CountResponse>
-
-
create(ServiceCall call, FormsSectionsServiceCreateRequest request)
→ Future<FormSection>
-
-
create_Pre(ServiceCall $call, Future<FormsSectionsServiceCreateRequest> $request)
→ Future<FormSection>
-
-
discard(ServiceCall call, IdentifierUUIDWithUserComment request)
→ Future<IdentifierResponse>
-
-
discard_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request)
→ Future<IdentifierResponse>
-
-
downloadAsCSV(ServiceCall call, FormsSectionsServiceFilterReq request)
→ Future<StandardFile>
-
-
downloadAsCSV_Pre(ServiceCall $call, Future<FormsSectionsServiceFilterReq> $request)
→ Future<StandardFile>
-
-
filter(ServiceCall call, FormsSectionsServiceFilterReq request)
→ Future<FormsSectionsList>
-
-
filter_Pre(ServiceCall $call, Future<FormsSectionsServiceFilterReq> $request)
→ Future<FormsSectionsList>
-
-
importFromCSV(ServiceCall call, StandardFile request)
→ Future<IdentifierUUIDsList>
-
-
importFromCSV_Pre(ServiceCall $call, Future<StandardFile> $request)
→ Future<IdentifierUUIDsList>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
restore(ServiceCall call, IdentifierUUIDWithUserComment request)
→ Future<IdentifierResponse>
-
-
restore_Pre(ServiceCall $call, Future<IdentifierUUIDWithUserComment> $request)
→ Future<IdentifierResponse>
-
-
searchAll(ServiceCall call, FormsSectionsServiceSearchAllReq request)
→ Future<FormsSectionsList>
-
-
searchAll_Pre(ServiceCall $call, Future<FormsSectionsServiceSearchAllReq> $request)
→ Future<FormsSectionsList>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(ServiceCall call, FormsSectionsServiceUpdateRequest request)
→ Future<FormSection>
-
-
update_Pre(ServiceCall $call, Future<FormsSectionsServiceUpdateRequest> $request)
→ Future<FormSection>
-
-
viewAll(ServiceCall call, ActiveStatus request)
→ Future<FormsSectionsList>
-
-
viewAll_Pre(ServiceCall $call, Future<ActiveStatus> $request)
→ Future<FormsSectionsList>
-
-
viewAllForEntityUUID(ServiceCall call, IdentifierUUID request)
→ Future<FormsSectionsList>
-
-
viewAllForEntityUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request)
→ Future<FormsSectionsList>
-
-
viewByID(ServiceCall call, Identifier request)
→ Future<FormSection>
-
-
viewByID_Pre(ServiceCall $call, Future<Identifier> $request)
→ Future<FormSection>
-
-
viewByUUID(ServiceCall call, IdentifierUUID request)
→ Future<FormSection>
-
-
viewByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request)
→ Future<FormSection>
-
-
viewEssentialByID(ServiceCall call, Identifier request)
→ Future<FormSection>
-
-
viewEssentialByID_Pre(ServiceCall $call, Future<Identifier> $request)
→ Future<FormSection>
-
-
viewEssentialByUUID(ServiceCall call, IdentifierUUID request)
→ Future<FormSection>
-
-
viewEssentialByUUID_Pre(ServiceCall $call, Future<IdentifierUUID> $request)
→ Future<FormSection>
-
-
viewFromIDs(ServiceCall call, IdentifiersList request)
→ Future<FormsSectionsList>
-
-
viewFromIDs_Pre(ServiceCall $call, Future<IdentifiersList> $request)
→ Future<FormsSectionsList>
-
-
-