sdk/general_settings.scailo.pb library
Classes
- GeneralSettings
- Describes the data structure of general settings on the platform
- GeneralSettingsServiceCreateRequest
- Describes the necessary data structure during creation of a general settings
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.