disableViCreationWithBillDateAfterPoApproval property
Stores if vendor invoices should not be created with bill date that is after the approval of a purchase order
Implementation
@$pb.TagNumber(70)
$core.bool get disableViCreationWithBillDateAfterPoApproval => $_getBF(22);
Implementation
@$pb.TagNumber(70)
set disableViCreationWithBillDateAfterPoApproval($core.bool value) =>
$_setBool(22, value);