sdk/general_streams.scailo.pb library
Classes
- GENERAL_STREAM_LIFECYCLE
- Describes the lifecycle status of each general stream
- GENERAL_STREAM_MESSAGE_SORT_KEY
- Describes the available sort keys
- GENERAL_STREAM_MESSAGE_TYPE
- Describes the available message types for a general stream message
- GENERAL_STREAM_SORT_KEY
- Describes the available sort keys
- GeneralStream
- Describes the parameters that are part of a standard response
- GeneralStreamInternalSubscriber
- Describes the parameters that constitute an internal subscriber
- GeneralStreamInternalSubscribersList
- Describes the message consisting of the list of internal subscribers
- GeneralStreamMessage
- Describes the parameters that constitute a message associated to an general stream
- GeneralStreamMessageReceipt
- Describes the parameters that constitute a message receipt
- GeneralStreamMessageReceiptsList
- Describes the message consisting of the list of general stream message receipts
- GeneralStreamMessagesList
- Describes the message consisting of the list of general stream messages
- GeneralStreamMessagesSearchRequest
- Describes the request payload to retrieve messages.
- GeneralStreamsList
- Describes the message consisting of the list of records
- GeneralStreamsServiceCountReq
- Describes the base request payload of a count search
- GeneralStreamsServiceCreateRequest
- Describes the parameters necessary to create a record
- GeneralStreamsServiceFilterReq
- Describes the base request payload of a filter search
- GeneralStreamsServiceImportInternalSubscribersRequest
- Describes the data model to handle importing of internal subscribers from the given identifier representing a team or a department
- GeneralStreamsServiceInternalSubscriberCreateRequest
- Describes the parameters necessary to create an internal subscriber
- GeneralStreamsServiceMessageCreateRequest
- Describes the parameters required to add a message to an general stream
- GeneralStreamsServicePaginatedMessagesResponse
- Describes the response to a pagination messages request
- GeneralStreamsServicePaginationReq
- Describes a pagination request to retrieve records
- GeneralStreamsServicePaginationResponse
- Describes the response to a pagination request
- GeneralStreamsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- GeneralStreamsServiceUpdateRequest
- Describes the parameters necessary to update a record
- LogbookLogGeneralStreamLC
- Describes each parameter that's part of the logbook (does not include historical data of the object) with the operation being an general stream lifecycle status
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.