GeneralStreamsServiceClient class

Describes the common methods applicable on each general stream

Annotations
  • @GrpcServiceName.new('Scailo.GeneralStreamsService')

Constructors

GeneralStreamsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addInternalSubscriber(GeneralStreamsServiceInternalSubscriberCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Add an internal subscriber
addMessage(GeneralStreamsServiceMessageCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add a message to an general stream
attachVaultFolder(VaultFolderAttachRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Attaches a specified folder directly to a record without requiring a full revision workflow.
cancel(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Cancel
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Complete
count(GeneralStreamsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Returns the total count of records matching the given complex filter criteria.
create(GeneralStreamsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Create
deleteInternalSubscriber(IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Delete an internal subscriber
deleteMessage(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Delete a message in an general stream
downloadAsCSV(GeneralStreamsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request
filter(GeneralStreamsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
Performs a high-granularity search based on multiple specific field filters.
importInternalSubscribersFromDepartment(GeneralStreamsServiceImportInternalSubscribersRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Import users as internal subscribers from department and returns the ID of the general stream
importInternalSubscribersFromTeam(GeneralStreamsServiceImportInternalSubscribersRequest request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Import users as internal subscribers from team and returns the ID of the general stream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Reopen
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Repeat
saveMessageForLater(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Saves a message for viewing it later
searchAll(GeneralStreamsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
Performs a free-text search across records using a search key.
searchMessagesWithPagination(GeneralStreamMessagesSearchRequest request, {CallOptions? options}) → ResponseFuture<GeneralStreamsServicePaginatedMessagesResponse>
Search through general stream messages with pagination
toString() String
A string representation of this object.
inherited
update(GeneralStreamsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Update
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
Returns all records filtered by their active status.
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
Returns all records belonging to a specific organization/entity UUID.
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<GeneralStream>
Retrieves a single record by its internal numeric ID. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStream>
Retrieves a single record by its globally unique UUID. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<GeneralStream>
Retrieves a record by ID excluding high-volume fields like logs for performance. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStream>
Retrieves a record by UUID excluding high-volume fields like logs. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<GeneralStreamsList>
Retrieves a list of records matching the provided array of internal IDs.
viewInternalSubscriberByID(Identifier request, {CallOptions? options}) → ResponseFuture<GeneralStreamInternalSubscriber>
View an internal subscriber for the given ID
viewInternalSubscribers(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamInternalSubscribersList>
View all internal subscribers for given general stream UUID
viewMessageByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamMessage>
View General Stream Message by UUID
viewMessageReceipts(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamMessageReceiptsList>
View all receipts for the given message UUID
viewMessages(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<GeneralStreamMessagesList>
View all messages for given general stream UUID
viewPaginatedMessages(GeneralStreamMessagesSearchRequest request, {CallOptions? options}) → ResponseFuture<GeneralStreamsServicePaginatedMessagesResponse>
View general stream messages for given general stream ID with pagination
viewWithPagination(GeneralStreamsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<GeneralStreamsServicePaginationResponse>
Retrieves a paginated list of records based on status, sort keys, and offsets.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.