sdk/goals.scailo.pb library
Classes
- Goal
- Describes the parameters that are part of a standard response
- GOAL_ITEM_INPUT_VALUE_TYPE
- Describes the available input types for a goal item (with possible vbalues being number-absolute, number-percentage, text-input, text-dropdown)
- GOAL_ITEM_SORT_KEY
- Describes the available sort keys
- GOAL_ITEM_STATUS
- Describes the applicable statuses of goal items
- GOAL_SORT_KEY
- Describes the available sort keys
- GoalItem
- Describes the parameters that constitute an item associated to a goal
- GoalItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the record
- GoalItemsSearchRequest
- Describes the request payload to retrieve approved or unapproved items.
- GoalsItemsList
- Describes the message consisting of the list of goal items
- GoalsList
- Describes the message consisting of the list of goals
- GoalsServiceCountReq
- Describes the base request payload of a count search
- GoalsServiceCreateRequest
- Describes the parameters necessary to create a record
- GoalsServiceFilterReq
- Describes the base request payload of a filter search
- GoalsServiceItemCreateRequest
- Describes the parameters required to add an item to a goal
- GoalsServiceItemUpdateRequest
- Describes the parameters required to update an item in a goal
- GoalsServicePaginatedItemsResponse
- Describes the response to a pagination items request
- GoalsServicePaginationReq
- Describes a pagination request to retrieve records
- GoalsServicePaginationResponse
- Describes the response to a pagination request
- GoalsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- GoalsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.