GoalsServiceClient class
Describes the common methods applicable on each goal
- Annotations
-
- @GrpcServiceName.new('Scailo.GoalsService')
Constructors
-
GoalsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addGoalItem(
GoalsServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an item to a goal
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approveGoalItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve an item in a goal
-
clone(
CloneRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Clone goal from an existing goal (denoted by the identifier)
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
GoalsServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
GoalsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
deleteGoalItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an item in a goal
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
GoalsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadItemsAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
-
downloadItemsTemplateAsCSV(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload items
-
draft(
GoalsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
GoalsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
GoalsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< GoalsList> - View all that match the given filter criteria
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
modifyGoalItem(
GoalsServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an item in a goal
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderGoalItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder items in a goal
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
GoalsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
GoalsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< GoalsList> - View all that match the given search key
-
searchItemsWithPagination(
GoalItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< GoalsServicePaginatedItemsResponse> - Search through goal items with pagination
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadGoalItems(
IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture< IdentifiersList> - Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< GoalsList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< GoalsList> - View all with the given entity UUID
-
viewApprovedGoalItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< GoalsItemsList> - View approved goal items for given goal ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Goal> - View by ID
-
viewByReferenceID(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< Goal> - View by Reference ID (returns the latest record in case of duplicates)
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Goal> - View by UUID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Goal> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Goal> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< GoalsList> - View all records with the given IDs
-
viewGoalItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< GoalItem> - View goal Item by ID
-
viewGoalItemHistory(
GoalItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< GoalsItemsList> - View the history of the goal item
-
viewPaginatedApprovedGoalItems(
GoalItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< GoalsServicePaginatedItemsResponse> - View approved goal items for given goal ID with pagination
-
viewPaginatedUnapprovedGoalItems(
GoalItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< GoalsServicePaginatedItemsResponse> - View unapproved goal items for given goal ID with pagination
-
viewUnapprovedGoalItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< GoalsItemsList> - View unapproved goal items for given goal ID
-
viewWithPagination(
GoalsServicePaginationReq request, {CallOptions? options}) → ResponseFuture< GoalsServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.