sdk/infrastructures.scailo.pb library
Classes
- Infrastructure
- Describes the parameters that are part of a standard response
- INFRASTRUCTURE_REF_FROM
- Stores all the possible references from which a infrastructure can be added
- InfrastructuresList
- Describes the message consisting of the list of records
- InfrastructuresServiceCountReq
- Describes the base request payload of a count search
- InfrastructuresServiceCreateRequest
- Describes the parameters necessary to create a record
- InfrastructuresServiceFilterReq
- Describes the base request payload of a filter search
- InfrastructuresServicePaginationReq
- Describes a pagination request to retrieve records
- InfrastructuresServicePaginationResponse
- Describes the response to a pagination request
- InfrastructuresServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- InfrastructuresServiceSendToStoreRequest
- Describes the parameters necessary to send a infrastructure to store
- InfrastructuresServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.