sdk/labels.scailo.pb
library
Classes
-
Label
-
Describes the data structure of each label on the platform
-
LABEL_SORT_KEY
-
Describes the available sort keys for retrieving labels
-
Describes the data structure that responds to a pagination request
-
LabelsList
-
Describes the data structure that stores a list of labels
-
LabelsServiceCountReq
-
Describes the base request payload of a count search
-
LabelsServiceCreateRequest
-
Describes the necessary data structure during creation of a label
-
LabelsServiceFilterReq
-
Describes the base request payload of a filter search
-
Describes a pagination request to retrieve records
-
LabelsServiceSearchAllReq
-
Describes the request payload for performing a generic search operation on labels
-
LabelsServiceUpdateRequest
-
Describes the data structure to perform the update (draft/revision) operation on a label