LabelsServiceClient class

Describes the methods applicable on each label

Annotations
  • @GrpcServiceName.new('Scailo.LabelsService')

Constructors

LabelsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
checkAddPermission(Empty request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Check if the user has permission to add an label
checkModifyPermission(Empty request, {CallOptions? options}) → ResponseFuture<BooleanResponse>
Check if the user has permission to modify an label
count(LabelsServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Returns the total count of records matching the given complex filter criteria.
create(LabelsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<Label>
Create a label
discard(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Discard the label
downloadAsCSV(LabelsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<StandardFile>
CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
filter(LabelsServiceFilterReq request, {CallOptions? options}) → ResponseFuture<LabelsList>
Performs a high-granularity search based on multiple specific field filters.
importFromCSV(StandardFile request, {CallOptions? options}) → ResponseFuture<IdentifierUUIDsList>
Bulk imports records from a provided CSV file. Behavior:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierResponse>
Restore the label
searchAll(LabelsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<LabelsList>
View all labels that match the given search key
toString() String
A string representation of this object.
inherited
update(LabelsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<Label>
Update a label
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<LabelsList>
View all labels
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<LabelsList>
View all labels with the given entity UUID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<Label>
Retrieves a single record by its internal numeric ID. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Label>
Retrieves a single record by its globally unique UUID. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<Label>
Retrieves a record by ID excluding high-volume fields like logs for performance. This operation is optimized for high-performance internal system logic and backend-to-backend communication
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Label>
Retrieves a record by UUID excluding high-volume fields like logs. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<LabelsList>
Retrieves a list of records matching the provided array of internal IDs.
viewWithPagination(LabelsServicePaginationReq request, {CallOptions? options}) → ResponseFuture<LabelPaginationResp>
View labels with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.