sdk/leaves_requests.scailo.pb library
Classes
- LEAVE_REQUEST_SORT_KEY
- Describes the available sort keys
- LeaveRequest
- Describes the parameters that are part of a standard response
- LeavesRequestsList
- Describes the message consisting of the list of records
- LeavesRequestsServiceCountReq
- Describes the base request payload of a count search
- LeavesRequestsServiceCreateRequest
- Describes the parameters necessary to create a record
- LeavesRequestsServiceFilterReq
- Describes the base request payload of a filter search
- LeavesRequestsServicePaginationReq
- Describes a pagination request to retrieve records
- LeavesRequestsServicePaginationResponse
- Describes the response to a pagination request
- LeavesRequestsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- LeavesRequestsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.