sdk/leaves_types.scailo.pbgrpc library
Classes
- LEAVE_TYPE_SORT_KEY
- Describes the available sort keys
- LeavesTypesList
- Describes the message consisting of the list of records
- LeavesTypesServiceBase
- LeavesTypesServiceClient
- Describes the common methods applicable on each leave type
- LeavesTypesServiceCountReq
- Describes the base request payload of a count search
- LeavesTypesServiceCreateRequest
- Describes the parameters necessary to create a record
- LeavesTypesServiceFilterReq
- Describes the base request payload of a filter search
- LeavesTypesServicePaginationReq
- Describes a pagination request to retrieve records
- LeavesTypesServicePaginationResponse
- Describes the response to a pagination request
- LeavesTypesServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- LeavesTypesServiceUpdateRequest
- Describes the parameters necessary to update a record
- LeaveType
- Describes the parameters that are part of a standard response
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.