sdk/ledgers.scailo.pb
library
Classes
-
Ledger
-
Describes the parameters that are part of a standard response
-
LEDGER_SORT_KEY
-
Describes the available sort keys
-
LedgersList
-
Describes the message consisting of the list of records
-
Describes the base request payload of a count search
-
Describes the parameters necessary to create a record
-
Describes the base request payload of a filter search
-
Describes a pagination request to retrieve records
-
Describes the response to a pagination request
-
Describes the request payload for performing a generic search operation on records
-
Describes the parameters necessary to update a record