sdk/locations.scailo.pbgrpc library
Classes
- Location
- Describes the parameters that are part of a standard response
- LOCATION_SORT_KEY
- Describes the available sort keys
- LocationsList
- Describes the message consisting of the list of records
- LocationsServiceBase
- LocationsServiceClient
- Describes the common methods applicable on each location
- LocationsServiceCountReq
- Describes the base request payload of a count search
- LocationsServiceCreateRequest
- Describes the parameters necessary to create a record
- LocationsServiceFilterReq
- Describes the base request payload of a filter search
- LocationsServicePaginationReq
- Describes a pagination request to retrieve records
- LocationsServicePaginationResponse
- Describes the response to a pagination request
- LocationsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- LocationsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.