maxViews property
- @TagNumber.new(31)
The number of times that the magic link can be viewed. If -1, then the link can be viewed any number of times. If 0, then the link cannot be viewed at all.
Implementation
@$pb.TagNumber(31)
$fixnum.Int64 get maxViews => $_getI64(3);
- @TagNumber.new(31)
Implementation
@$pb.TagNumber(31)
set maxViews($fixnum.Int64 value) => $_setInt64(3, value);