MeetingsServiceClient class
Describes the common methods applicable on each meeting
- Annotations
-
- @GrpcServiceName.new('Scailo.MeetingsService')
Constructors
-
MeetingsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addActionable(
MeetingsServiceActionableCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an actionable to a meeting
-
addAssociate(
MeetingsServiceAssociateCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an associate
-
addEmployee(
MeetingsServiceEmployeeCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an employee
-
cancel(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Cancel
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
MeetingsServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
create(
MeetingsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create
-
deleteActionable(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an actionable in a meeting
-
deleteAssociate(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an associate
-
deleteEmployee(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an employee
-
filter(
MeetingsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< MeetingsList> - View all that match the given filter criteria
-
importFromDepartment(
MeetingsServiceImportEmployeesRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Import employees from department and returns the ID of the meeting
-
importFromTeam(
MeetingsServiceImportEmployeesRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Import employees from team and returns the ID of the meeting
-
modifyActionable(
MeetingsServiceActionableUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an actionable in a meeting
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reorderActionables(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder actionables in a meeting
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
requestRSVP(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Request RSVPs from all the participants
-
searchActionablesWithPagination(
MeetingActionablesSearchRequest request, {CallOptions? options}) → ResponseFuture< MeetingsServicePaginatedActionablesResponse> - Search through meeting actionables with pagination
-
searchAll(
MeetingsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< MeetingsList> - View all that match the given search key
-
sendActionables(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send all the actionables in an email
-
sendEmail(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send Email
-
setAssociateRSVP(
MeetingsServiceSetRSVPRequest request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Set the RSVP of the associate with the given meeting associate UUID
-
setEmployeeRSVP(
MeetingsServiceSetRSVPRequest request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Set the RSVP of the employee with the given meeting employee UUID
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
MeetingsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update
-
viewActionableByID(
Identifier request, {CallOptions? options}) → ResponseFuture< MeetingActionable> - View Meeting Actionable by ID
-
viewActionableHistory(
MeetingActionableHistoryRequest request, {CallOptions? options}) → ResponseFuture< MeetingActionablesList> - View the history of the meeting actionable
-
viewActionables(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< MeetingActionablesList> - View all actionables for given meeting ID
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< MeetingsList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< MeetingsList> - View all with the given entity UUID
-
viewAssociateByID(
Identifier request, {CallOptions? options}) → ResponseFuture< MeetingAssociate> - View an associate for the given ID
-
viewAssociates(
Identifier request, {CallOptions? options}) → ResponseFuture< MeetingAssociatesList> - View all associates for given meeting ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Meeting> - View by ID
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Meeting> - View by UUID
-
viewEmployeeByID(
Identifier request, {CallOptions? options}) → ResponseFuture< MeetingEmployee> - View an employee for the given ID
-
viewEmployees(
Identifier request, {CallOptions? options}) → ResponseFuture< MeetingEmployeesList> - View all employees for given meeting ID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Meeting> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Meeting> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< MeetingsList> - View all records with the given IDs
-
viewPaginatedActionables(
MeetingActionablesSearchRequest request, {CallOptions? options}) → ResponseFuture< MeetingsServicePaginatedActionablesResponse> - View meeting actionables for given meeting ID with pagination
-
viewWithPagination(
MeetingsServicePaginationReq request, {CallOptions? options}) → ResponseFuture< MeetingsServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.