sdk/notes.scailo.pbgrpc library
Classes
- LogbookLogNoteLC
- Describes each parameter that's part of the logbook (does not include historical data of the object) with the operation being an note lifecycle status
- Note
- Describes the parameters that are part of a standard response
- NOTE_LIFECYCLE
- Describes the lifecycle status of each note
- NOTE_SORT_KEY
- Describes the available sort keys
- NotesList
- Describes the message consisting of the list of records
- NotesServiceBase
- NotesServiceClient
- Describes the common methods applicable on each note
- NotesServiceCountReq
- Describes the base request payload of a count search
- NotesServiceCreateRequest
- Describes the parameters necessary to create a record
- NotesServiceFilterReq
- Describes the base request payload of a filter search
- NotesServicePaginationReq
- Describes a pagination request to retrieve records
- NotesServicePaginationResponse
- Describes the response to a pagination request
- NotesServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- NotesServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.