NotesServiceClient class
Describes the common methods applicable on each note
- Annotations
-
- @GrpcServiceName.new('Scailo.NotesService')
Constructors
-
NotesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
attachVaultFolder(
VaultFolderAttachRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Attaches a specified folder directly to a record without requiring a full revision workflow.
-
cancel(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Cancel
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Complete
-
count(
NotesServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Returns the total count of records matching the given complex filter criteria.
-
create(
NotesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Create
-
filter(
NotesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< NotesList> - Performs a high-granularity search based on multiple specific field filters.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Reopen
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Repeat
-
searchAll(
NotesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< NotesList> - Performs a free-text search across records using a search key.
-
sendEmail(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Send Email
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
NotesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierUUID> - Update
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< NotesList> - Returns all records filtered by their active status.
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< NotesList> - Returns all records belonging to a specific organization/entity UUID.
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Note> - Retrieves a single record by its internal numeric ID. This operation is optimized for high-performance internal system logic and backend-to-backend communication
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Note> - Retrieves a single record by its globally unique UUID. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Note> - Retrieves a record by ID excluding high-volume fields like logs for performance. This operation is optimized for high-performance internal system logic and backend-to-backend communication
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Note> - Retrieves a record by UUID excluding high-volume fields like logs. This is intended for public-facing interfaces, since record identifiers aren't sequential and thus cannot be predicted.
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< NotesList> - Retrieves a list of records matching the provided array of internal IDs.
-
viewWithPagination(
NotesServicePaginationReq request, {CallOptions? options}) → ResponseFuture< NotesServicePaginationResponse> - Retrieves a paginated list of records based on status, sort keys, and offsets.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.