NotesServiceClient class

Describes the common methods applicable on each note

Annotations
  • @GrpcServiceName.new('Scailo.NotesService')

Constructors

NotesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
cancel(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Cancel
commentAdd(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Add comment
complete(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Complete
count(NotesServiceCountReq request, {CallOptions? options}) → ResponseFuture<CountResponse>
Count all that match the given criteria
create(NotesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Create
filter(NotesServiceFilterReq request, {CallOptions? options}) → ResponseFuture<NotesList>
View all that match the given filter criteria
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopen(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Reopen
repeat(IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Repeat
searchAll(NotesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture<NotesList>
View all that match the given search key
sendEmail(IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Send Email
toString() String
A string representation of this object.
inherited
update(NotesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture<IdentifierUUID>
Update
viewAll(ActiveStatus request, {CallOptions? options}) → ResponseFuture<NotesList>
View all
viewAllForEntityUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<NotesList>
View all with the given entity UUID
viewByID(Identifier request, {CallOptions? options}) → ResponseFuture<Note>
View by ID
viewByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Note>
View by UUID
viewEssentialByID(Identifier request, {CallOptions? options}) → ResponseFuture<Note>
View only essential components by ID (without logs)
viewEssentialByUUID(IdentifierUUID request, {CallOptions? options}) → ResponseFuture<Note>
View only essential components (without logs) that matches the given UUID
viewFromIDs(IdentifiersList request, {CallOptions? options}) → ResponseFuture<NotesList>
View all records with the given IDs
viewWithPagination(NotesServicePaginationReq request, {CallOptions? options}) → ResponseFuture<NotesServicePaginationResponse>
View with pagination

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.