sdk/overtimes.scailo.pbgrpc library
Classes
- Overtime
- Describes the parameters that are part of a standard response
- OVERTIME_SORT_KEY
- Describes the available sort keys
- OvertimesList
- Describes the message consisting of the list of records
- OvertimesServiceBase
- OvertimesServiceClient
- Describes the common methods applicable on each overtime
- OvertimesServiceCountReq
- Describes the base request payload of a count search
- OvertimesServiceCreateRequest
- Describes the parameters necessary to create a record
- OvertimesServiceFilterReq
- Describes the base request payload of a filter search
- OvertimesServicePaginationReq
- Describes a pagination request to retrieve records
- OvertimesServicePaginationResponse
- Describes the response to a pagination request
- OvertimesServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- OvertimesServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.