sdk/payroll_params.scailo.pb library
Classes
- PAYROLL_PARAM_SORT_KEY
- Describes the available sort keys
- PayrollParam
- Describes the parameters that are part of a standard response
- PayrollParamsList
- Describes the message consisting of the list of records
- PayrollParamsServiceCountReq
- Describes the base request payload of a count search
- PayrollParamsServiceCreateRequest
- Describes the parameters necessary to create a record
- PayrollParamsServiceFilterReq
- Describes the base request payload of a filter search
- PayrollParamsServicePaginationReq
- Describes a pagination request to retrieve records
- PayrollParamsServicePaginationResponse
- Describes the response to a pagination request
- PayrollParamsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- PayrollParamsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.