ProductionIndentsServiceClient class
Describes the common methods applicable on each production indent
- Annotations
-
- @GrpcServiceName.new('Scailo.ProductionIndentsService')
Constructors
-
ProductionIndentsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addProductionIndentItem(
ProductionIndentsServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an item to a production indent
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approveProductionIndentItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve an item in a production indent
-
autofill(
ProductionIndentsServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Autofill the production indent
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
ProductionIndentsServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
ProductionIndentsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
createMagicLink(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Create a magic link
-
deleteProductionIndentItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an item in a production indent
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
ProductionIndentsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download production indent with the given IdentifierUUID (can be used to allow public downloads)
-
downloadItemsAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
-
downloadItemsTemplateAsCSV(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload items
-
draft(
ProductionIndentsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
ProductionIndentsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
ProductionIndentsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< ProductionIndentsList> - View all that match the given filter criteria
-
filterProspectiveFamilies(
FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture< FamiliesList> - Filter prospective families for the record represented by the given UUID identifier
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
isCompletable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the Production Indent can be marked as completed
-
isDownloadable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the record is downloadable (checks if the custom download function has been implemented)
-
modifyProductionIndentItem(
ProductionIndentsServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an item in a production indent
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderProductionIndentItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder items in a production indent
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
ProductionIndentsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
ProductionIndentsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< ProductionIndentsList> - View all that match the given search key
-
searchItemsWithPagination(
ProductionIndentItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< ProductionIndentsServicePaginatedItemsResponse> - Search through production indent items with pagination
-
sendEmail(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send Email
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadProductionIndentItems(
IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture< IdentifiersList> - Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAddedQuantityForFamily(
ProductionIndentItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture< QuantityResponse> - View the added quantity for the family with the given request payload
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< ProductionIndentsList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ProductionIndentsList> - View all with the given entity UUID
-
viewApprovedProductionIndentItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< ProductionIndentsItemsList> - View approved production indent items for given production indent ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< ProductionIndent> - View by ID
-
viewByReferenceID(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< ProductionIndent> - View by Reference ID (returns the latest record in case of duplicates)
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ProductionIndent> - View by UUID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< ProductionIndent> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ProductionIndent> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< ProductionIndentsList> - View all records with the given IDs
-
viewIssuedStatistics(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ProductionIndentIssuedStatisticsList> - View issued (stock issuance) statistics of the production indent
-
viewPaginatedApprovedProductionIndentItems(
ProductionIndentItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< ProductionIndentsServicePaginatedItemsResponse> - View approved production indent items for given production indent ID with pagination
-
viewPaginatedUnapprovedProductionIndentItems(
ProductionIndentItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< ProductionIndentsServicePaginatedItemsResponse> - View unapproved production indent items for given production indent ID with pagination
-
viewProductionIndentItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< ProductionIndentItem> - View Production Indent Item by ID
-
viewProductionIndentItemHistory(
ProductionIndentItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< ProductionIndentsItemsList> - View the history of the production indent item
-
viewProspectiveFamilies(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< FamiliesList> - View prospective families for the given production indent
-
viewProspectiveProductionIndentItem(
ProductionIndentItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture< ProductionIndentsServiceItemCreateRequest> - View prospective production indent item info for the given family ID and production indent ID
-
viewUnapprovedProductionIndentItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< ProductionIndentsItemsList> - View unapproved production indent items for given production indent ID
-
viewWithPagination(
ProductionIndentsServicePaginationReq request, {CallOptions? options}) → ResponseFuture< ProductionIndentsServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.