sdk/products.scailo.pb library
Classes
- Product
- Describes the parameters that are part of a standard response
- PRODUCT_REF_FROM
- Stores all the possible references from which a product can be added
- ProductsList
- Describes the message consisting of the list of records
- ProductsServiceCountReq
- Describes the base request payload of a count search
- ProductsServiceCreateRequest
- Describes the parameters necessary to create a record
- ProductsServiceFilterReq
- Describes the base request payload of a filter search
- ProductsServicePaginationReq
- Describes a pagination request to retrieve records
- ProductsServicePaginationResponse
- Describes the response to a pagination request
- ProductsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- ProductsServiceSendToStoreRequest
- Describes the parameters necessary to send a product to store
- ProductsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.