logs property
@description Comprehensive audit trail of every operation performed on this record.
Implementation
@$pb.TagNumber(5)
$pb.PbList<$1.LogbookLogConciseSLC> get logs => $_getList(4);
@description Comprehensive audit trail of every operation performed on this record.
@$pb.TagNumber(5)
$pb.PbList<$1.LogbookLogConciseSLC> get logs => $_getList(4);