viewProjectContacts method
ResponseFuture<ProjectContactsList>
viewProjectContacts(
- IdentifierUUID request, {
- CallOptions? options,
Lists all contact associations mapped to a given project unique identifier.
This read-only query aggregates and returns the collection of personnel assigned to the project entity.
Implementation
$grpc.ResponseFuture<$0.ProjectContactsList> viewProjectContacts(
$1.IdentifierUUID request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$viewProjectContacts, request, options: options);
}