sdk/qc_params.scailo.pb library
Classes
- QC_PARAM_SORT_KEY
- Describes the available sort keys
- QCParam
- Describes the parameters that are part of a standard response
- QCParamsList
- Describes the message consisting of the list of records
- QCParamsServiceCountReq
- Describes the base request payload of a count search
- QCParamsServiceCreateRequest
- Describes the parameters necessary to create a record
- QCParamsServiceFilterReq
- Describes the base request payload of a filter search
- QCParamsServicePaginationReq
- Describes a pagination request to retrieve records
- QCParamsServicePaginationResponse
- Describes the response to a pagination request
- QCParamsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- QCParamsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.