sdk/qc_samples.scailo.pb library
Classes
- LogbookLogQCSampleLC
- Describes each parameter that's part of the logbook (does not include historical data of the object) with the operation being a qc sample lifecycle status
- QC_SAMPLE_LIFECYCLE
- Describes the lifecycle status of each qc sample
- QC_SAMPLE_PARAMETER_SORT_KEY
- Describes the available sort keys
- QC_SAMPLE_SORT_KEY
- Describes the available sort keys
- QCSample
- Describes the parameters that are part of a standard response
- QCSampleAncillaryParameters
- Stores the UUID references of the record
- QCSampleParameter
- Describes the parameters that constitute an parameter associated to a qc sample
- QCSampleParameterHistory
- Describes the parameters that are present in a history response
- QCSampleParameterHistoryList
- Describes the list of history parameters
- QCSampleParameterHistoryRequest
- Describes the parameters that are required to retrieve the history of the record
- QCSampleParametersList
- Describes the message consisting of the list of qc sample parameters
- QCSampleParametersSearchRequest
- Describes the request payload to retrieve parameters.
- QCSamplesCountStatistics
- Describes the payload that has the counts of all the QC samples for an inventory item
- QCSamplesList
- Describes the message consisting of the list of records
- QCSamplesServiceCountReq
- Describes the base request payload of a count search
- QCSamplesServiceCreateRequest
- Describes the parameters necessary to create a record
- QCSamplesServiceFilterReq
- Describes the base request payload of a filter search
- QCSamplesServicePaginatedParametersResponse
- Describes the response to a pagination parameters request
- QCSamplesServicePaginationReq
- Describes a pagination request to retrieve records
- QCSamplesServicePaginationResponse
- Describes the response to a pagination request
- QCSamplesServiceParameterUpdateRequest
- Describes the parameters required to update an parameter in a qc sample
- QCSamplesServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- QCSamplesServiceUpdateRequest
- Describes the parameters necessary to update a record
- QCSamplesWithMetadataList
- Describes the message consisting of the list of QC samples with metadata
- QCSampleWithMetadata
- Describes the parameters that are part of a standard response
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.