QCSampleParametersSearchRequest class
Describes the request payload to retrieve parameters.
- Available extensions
Constructors
- QCSampleParametersSearchRequest({BOOL_FILTER? isActive, Int64? count, Int64? offset, SORT_ORDER? sortOrder, QC_SAMPLE_PARAMETER_SORT_KEY? sortKey, String? entityUuid, String? checkedBy, Int64? checkedAtStart, Int64? checkedAtEnd, Int64? qcSampleId, Int64? qcParamId, Int64? uomId, Int64? numberObservedValueStart, Int64? numberObservedValueEnd, String? textObservedValue, String? searchKey, Int64? productionPlanId, Int64? goodsReceiptId, Int64? inwardJobFreeIssueMaterialId, Int64? vendorId, Int64? familyId})
-
factory
-
QCSampleParametersSearchRequest.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- QCSampleParametersSearchRequest.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
- checkedAtEnd ↔ Int64
-
The end range of checked timestamp
getter/setter pair
- checkedAtStart ↔ Int64
-
The start range of checked timestamp
getter/setter pair
- checkedBy ↔ String
-
Stores the username of the employee who performed the check
getter/setter pair
- count ↔ Int64
-
The number of records that need to be sent in the response. Returns all records if it is set to -1
getter/setter pair
- entityUuid ↔ String
-
The entity UUID that is to be used to filter records
getter/setter pair
- familyId ↔ Int64
-
The associated family ID
getter/setter pair
- goodsReceiptId ↔ Int64
-
The associated goods receipt ID
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- inwardJobFreeIssueMaterialId ↔ Int64
-
The associated inward job free issue material ID
getter/setter pair
- isActive ↔ BOOL_FILTER
-
If true, then returns only active records. If false, then returns only inactive records
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - numberObservedValueEnd ↔ Int64
-
The end range of number observed value
getter/setter pair
- numberObservedValueStart ↔ Int64
-
The start range of number observed value
getter/setter pair
- offset ↔ Int64
-
The number that need to be offset by before fetching the records
getter/setter pair
- productionPlanId ↔ Int64
-
getter/setter pair
- qcParamId ↔ Int64
-
The ID of the qc param that is a part of the qc sample
getter/setter pair
- qcSampleId ↔ Int64
-
The ID of the qc sample
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchKey ↔ String
-
Describes the key with which the search operation needs to be performed
getter/setter pair
- sortKey ↔ QC_SAMPLE_PARAMETER_SORT_KEY
-
The sort key that is to be used to fetch the pagination response
getter/setter pair
- sortOrder ↔ SORT_ORDER
-
The sort order that is to be used to fetch the pagination response
getter/setter pair
- textObservedValue ↔ String
-
The text observed value
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
- uomId ↔ Int64
-
The ID of the associated unit of material
getter/setter pair
- vendorId ↔ Int64
-
The associated vendor ID
getter/setter pair
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearCheckedAtEnd(
) → void -
clearCheckedAtStart(
) → void -
clearCheckedBy(
) → void -
clearCount(
) → void -
clearEntityUuid(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearFamilyId(
) → void -
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearGoodsReceiptId(
) → void -
clearInwardJobFreeIssueMaterialId(
) → void -
clearIsActive(
) → void -
clearNumberObservedValueEnd(
) → void -
clearNumberObservedValueStart(
) → void -
clearOffset(
) → void -
clearProductionPlanId(
) → void -
clearQcParamId(
) → void -
clearQcSampleId(
) → void -
clearSearchKey(
) → void -
clearSortKey(
) → void -
clearSortOrder(
) → void -
clearTextObservedValue(
) → void -
clearUomId(
) → void -
clearVendorId(
) → void -
clone(
) → QCSampleParametersSearchRequest - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(QCSampleParametersSearchRequest)) → QCSampleParametersSearchRequest -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → QCSampleParametersSearchRequest - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasCheckedAtEnd(
) → bool -
hasCheckedAtStart(
) → bool -
hasCheckedBy(
) → bool -
hasCount(
) → bool -
hasEntityUuid(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasFamilyId(
) → bool -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasGoodsReceiptId(
) → bool -
hasInwardJobFreeIssueMaterialId(
) → bool -
hasIsActive(
) → bool -
hasNumberObservedValueEnd(
) → bool -
hasNumberObservedValueStart(
) → bool -
hasOffset(
) → bool -
hasProductionPlanId(
) → bool -
hasQcParamId(
) → bool -
hasQcSampleId(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSearchKey(
) → bool -
hasSortKey(
) → bool -
hasSortOrder(
) → bool -
hasTextObservedValue(
) → bool -
hasUomId(
) → bool -
hasVendorId(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited