description property
@description A detailed text description outlining the purpose, context, or instructions specific to this section of the questionnaire.
@example "Section 1: Facility Safety and Compliance Guidelines"
Implementation
@$pb.TagNumber(20)
$core.String get description => $_getSZ(11);
Implementation
@$pb.TagNumber(20)
set description($core.String value) => $_setString(11, value);