sdk/quotations_responses.scailo.pb library
Classes
- QUOTATION_RESPONSE_ITEM_SORT_KEY
- Describes the available sort keys
- QUOTATION_RESPONSE_ITEM_STATUS
- Describes the applicable statuses of quotation response items
- QUOTATION_RESPONSE_SORT_KEY
- Describes the available sort keys
- QuotationResponse
- Describes the parameters that are part of a standard response
- QuotationResponseAncillaryParameters
- Stores the UUID references of the record
- QuotationResponseItem
- Describes the parameters that constitute an item associated to a quotation response
- QuotationResponseItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the record
- QuotationResponseItemsSearchRequest
- Describes the request payload to retrieve approved or unapproved items.
- QuotationsResponsesItemsList
- Describes the message consisting of the list of quotation response items
- QuotationsResponsesList
- Describes the message consisting of the list of quotations responses
- QuotationsResponsesServiceCountReq
- Describes the base response payload of a count search
- QuotationsResponsesServiceCreateRequest
- Describes the parameters necessary to create a record
- QuotationsResponsesServiceFilterReq
- Describes the base response payload of a filter search
- QuotationsResponsesServiceItemCreateRequest
- Describes the parameters required to add an item to a quotation response
- QuotationsResponsesServiceItemsFilterReq
- Describes the request payload to filter quotation response items
- QuotationsResponsesServiceItemUpdateRequest
- Describes the parameters required to update an item in a quotation response
- QuotationsResponsesServicePaginatedItemsResponse
- Describes the response to a pagination items request
- QuotationsResponsesServicePaginationReq
- Describes a pagination response to retrieve records
- QuotationsResponsesServicePaginationResponse
- Describes the response to a pagination response
- QuotationsResponsesServiceSearchAllReq
- Describes the response payload for performing a generic search operation on records
- QuotationsResponsesServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.