QuotationsResponsesServiceClient class
Describes the common methods applicable on each quotation response
- Annotations
-
- @GrpcServiceName.new('Scailo.QuotationsResponsesService')
Constructors
-
QuotationsResponsesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addQuotationResponseItem(
QuotationsResponsesServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an item to a quotation response
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approveQuotationResponseItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve an item in a quotation response
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
QuotationsResponsesServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
QuotationsResponsesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
createMagicLink(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Create a magic link
-
deleteQuotationResponseItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an item in a quotation response
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
QuotationsResponsesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download quotation response with the given IdentifierUUID (can be used to allow public downloads)
-
draft(
QuotationsResponsesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
QuotationsResponsesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
QuotationsResponsesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesList> - View all that match the given filter criteria
-
filterItems(
QuotationsResponsesServiceItemsFilterReq request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesItemsList> - View all the quotation response items that match the given filter criteria
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
isDownloadable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the record is downloadable (checks if the custom download function has been implemented)
-
modifyQuotationResponseItem(
QuotationsResponsesServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an item in a quotation response
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderQuotationResponseItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder items in a quotation response
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
QuotationsResponsesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
QuotationsResponsesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesList> - View all that match the given search key
-
searchItemsWithPagination(
QuotationResponseItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesServicePaginatedItemsResponse> - Search through quotation response items with pagination
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesList> - View all with the given entity UUID
-
viewAncillaryParametersByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< QuotationResponseAncillaryParameters> - View the ancillary parameters (UUIDs of the internal references) by UUID
-
viewApprovedQuotationResponseItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesItemsList> - View approved quotation response items for given quotation response ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< QuotationResponse> - View by ID
-
viewByReferenceID(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< QuotationResponse> - View by Reference ID (returns the latest record in case of duplicates)
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< QuotationResponse> - View by UUID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< QuotationResponse> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< QuotationResponse> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesList> - View all records with the given IDs
-
viewPaginatedApprovedQuotationResponseItems(
QuotationResponseItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesServicePaginatedItemsResponse> - View approved quotation response items for given quotation response ID with pagination
-
viewPaginatedUnapprovedQuotationResponseItems(
QuotationResponseItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesServicePaginatedItemsResponse> - View unapproved quotation response items for given quotation response ID with pagination
-
viewQuotationResponseItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< QuotationResponseItem> - View quotation response Item by ID
-
viewQuotationResponseItemHistory(
QuotationResponseItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesItemsList> - View the history of the quotation response item
-
viewUnapprovedQuotationResponseItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesItemsList> - View unapproved quotation response items for given quotation response ID
-
viewWithPagination(
QuotationsResponsesServicePaginationReq request, {CallOptions? options}) → ResponseFuture< QuotationsResponsesServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.