sdk/salaries.scailo.pbgrpc library
Classes
- SalariesAdditionItemsList
- Describes the message consisting of the list of salary addition items
- SalariesDeductionItemsList
- Describes the message consisting of the list of salary deduction items
- SalariesList
- Describes the message consisting of the list of salaries
- SalariesReimbursementItemsList
- Describes the message consisting of the list of salary reimbursement items
- SalariesServiceAdditionItemCreateRequest
- Describes the parameters required to add an addition item to a salary
- SalariesServiceAdditionItemUpdateRequest
- Describes the parameters required to update an addition item in a salary
- SalariesServiceAutofillRequest
- Describes the parameters necessary to perform an autofill request
- SalariesServiceBase
- SalariesServiceClient
- Describes the common methods applicable on each salary
- SalariesServiceCountReq
- Describes the base request payload of a count search
- SalariesServiceCreateRequest
- Describes the parameters necessary to create a record
- SalariesServiceDeductionItemCreateRequest
- Describes the parameters required to add an deduction item to a salary
- SalariesServiceDeductionItemUpdateRequest
- Describes the parameters required to update an deduction item in a salary
- SalariesServiceFilterReq
- Describes the base request payload of a filter search
- SalariesServicePaginationReq
- Describes a pagination request to retrieve records
- SalariesServicePaginationResponse
- Describes the response to a pagination request
- SalariesServiceReimbursementItemCreateRequest
- Describes the parameters required to add an reimbursement item to a salary
- SalariesServiceReimbursementItemUpdateRequest
- Describes the parameters required to update an reimbursement item in a salary
- SalariesServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- SalariesServiceUpdateRequest
- Describes the parameters necessary to update a record
- Salary
- Describes the parameters that are part of a standard response
- SALARY_SORT_KEY
- Describes the available sort keys
- SalaryAdditionItem
- Describes the parameters that constitute an addition item associated to a salary
- SalaryAdditionItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the addition record
- SalaryAdditionItemProspectiveInfoRequest
- Describes the parameters that are required to retrieve the info of a prospective salary addition item
- SalaryDeductionItem
- Describes the parameters that constitute an deduction item associated to a salary
- SalaryDeductionItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the deduction record
- SalaryDeductionItemProspectiveInfoRequest
- Describes the parameters that are required to retrieve the info of a prospective salary deduction item
- SalaryReimbursementItem
- Describes the parameters that constitute an reimbursement item associated to a salary
- SalaryReimbursementItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the reimbursement record
- SalaryReimbursementItemProspectiveInfoRequest
- Describes the parameters that are required to retrieve the info of a prospective salary reimbursement item
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.