sdk/skills_groups.scailo.pb library
Classes
- SKILL_GROUP_ITEM_INPUT_VALUE_TYPE
- Describes the available input types for a skill group item (with possible vbalues being number-absolute, number-percentage, text-input, text-dropdown)
- SKILL_GROUP_SORT_KEY
- Describes the available sort keys
- SkillGroup
- Describes the parameters that are part of a standard response
- SkillGroupItem
- Describes the parameters that constitute a param associated to a skill group
- SkillGroupItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the record
- SkillsGroupsItemsList
- Describes the message consisting of the list of skill group params
- SkillsGroupsList
- Describes the message consisting of the list of skills groups
- SkillsGroupsServiceCountReq
- Describes the base request payload of a count search
- SkillsGroupsServiceCreateRequest
- Describes the parameters necessary to create a record
- SkillsGroupsServiceFilterReq
- Describes the base request payload of a filter search
- SkillsGroupsServiceItemCreateRequest
- Describes the parameters required to add a param to a skill group
- SkillsGroupsServiceItemUpdateRequest
- Describes the parameters required to update a param in a skill group
- SkillsGroupsServicePaginationReq
- Describes a pagination request to retrieve records
- SkillsGroupsServicePaginationResponse
- Describes the response to a pagination request
- SkillsGroupsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- SkillsGroupsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.