sdk/skills_params.scailo.pb library
Classes
- SKILL_PARAM_SORT_KEY
- Describes the available sort keys
- SkillParam
- Describes the parameters that are part of a standard response
- SkillsParamsList
- Describes the message consisting of the list of records
- SkillsParamsServiceCountReq
- Describes the base request payload of a count search
- SkillsParamsServiceCreateRequest
- Describes the parameters necessary to create a record
- SkillsParamsServiceFilterReq
- Describes the base request payload of a filter search
- SkillsParamsServicePaginationReq
- Describes a pagination request to retrieve records
- SkillsParamsServicePaginationResponse
- Describes the response to a pagination request
- SkillsParamsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- SkillsParamsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.