StockIssuancesServiceClient class
Describes the common methods applicable on each stock issuance
- Annotations
-
- @GrpcServiceName.new('Scailo.StockIssuancesService')
Constructors
-
StockIssuancesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addStockIssuanceItem(
StockIssuancesServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an item to a stock issuance
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approveStockIssuanceItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve an item in a stock issuance
-
autofill(
StockIssuancesServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Autofill the stock issuance
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
StockIssuancesServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
StockIssuancesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
createMagicLink(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Create a magic link
-
deleteStockIssuanceItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an item in a stock issuance
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
StockIssuancesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download stock issuance with the given IdentifierUUID
-
downloadItemsAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
-
downloadItemsTemplateAsCSV(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload items
-
downloadLabelByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the label for the stock issuance with the given IdentifierUUID
-
draft(
StockIssuancesServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
StockIssuancesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
StockIssuancesServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StockIssuancesList> - View all that match the given filter criteria
-
filterProspectiveFamilies(
FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture< FamiliesList> - Filter prospective families for the record represented by the given UUID identifier
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
isCompletable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the Stock Issuance can be marked as completed
-
isDownloadable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the record is downloadable (checks if the custom download function has been implemented)
-
modifyStockIssuanceItem(
StockIssuancesServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an item in a stock issuance
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderStockIssuanceItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder items in a stock issuance
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
StockIssuancesServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
StockIssuancesServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< StockIssuancesList> - View all that match the given search key
-
searchItemsWithPagination(
StockIssuanceItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< StockIssuancesServicePaginatedItemsResponse> - Search through stock issuance items with pagination
-
sendEmail(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send Email
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAddedFamilyQuantityForSource(
StockIssuancesServiceAlreadyAddedQuantityForSourceRequest request, {CallOptions? options}) → ResponseFuture< QuantityResponse> - View already added quantities
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< StockIssuancesList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StockIssuancesList> - View all with the given entity UUID
-
viewApprovedStockIssuanceItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< StockIssuancesItemsList> - View approved stock issuance items for given stock issuance ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< StockIssuance> - View by ID
-
viewByReferenceID(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< StockIssuance> - View by Reference ID (returns the latest record in case of duplicates)
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StockIssuance> - View by UUID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< StockIssuance> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StockIssuance> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< StockIssuancesList> - View all records with the given IDs
-
viewPaginatedApprovedStockIssuanceItems(
StockIssuanceItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< StockIssuancesServicePaginatedItemsResponse> - View approved stock issuance items for given stock issuance ID with pagination
-
viewPaginatedUnapprovedStockIssuanceItems(
StockIssuanceItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< StockIssuancesServicePaginatedItemsResponse> - View unapproved stock issuance items for given stock issuance ID with pagination
-
viewProspectiveFamilies(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< FamiliesList> - View prospective families for the given stock issuance
-
viewProspectiveStockIssuanceItem(
StockIssuanceItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture< StockIssuancesServiceItemCreateRequest> - View prospective stock issuance item info for the given family ID and stock issuance ID
-
viewStockIssuanceItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< StockIssuanceItem> - View Stock Issuance Item by ID
-
viewStockIssuanceItemByInventoryHash(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< StockIssuanceItem> - View Stock Issuance Item by Inventory Hash
-
viewStockIssuanceItemHistory(
StockIssuanceItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< StockIssuancesItemsList> - View the history of the stock issuance item
-
viewUnapprovedStockIssuanceItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< StockIssuancesItemsList> - View unapproved stock issuance items for given stock issuance ID
-
viewWithPagination(
StockIssuancesServicePaginationReq request, {CallOptions? options}) → ResponseFuture< StockIssuancesServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.