sdk/stock_returns.scailo.pb library
Classes
- STOCK_RETURN_ITEM_SORT_KEY
- Describes the available sort keys
- STOCK_RETURN_ITEM_STATUS
- Describes the applicable statuses of stock return items
- STOCK_RETURN_REF_FROM
- Stores all the possible references from which a stock return can be added
- STOCK_RETURN_SORT_KEY
- Describes the available sort keys
- StockReturn
- Describes the parameters that are part of a standard response
- StockReturnItem
- Describes the parameters that constitute an item associated to a stock return
- StockReturnItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the record
- StockReturnItemProspectiveInfoRequest
- Describes the parameters that are required to retrieve the info of a prospective stock return item
- StockReturnItemsSearchRequest
- Describes the request payload to retrieve approved or unapproved items.
- StockReturnsItemsList
- Describes the message consisting of the list of stock return items
- StockReturnsList
- Describes the message consisting of the list of stock returns
- StockReturnsServiceAlreadyAddedQuantityForSourceRequest
- Describes the request payload to retrieve the quantity that has already been added for the specific ref_from, ref_id and family_id
- StockReturnsServiceCountReq
- Describes the base request payload of a count search
- StockReturnsServiceCreateRequest
- Describes the parameters necessary to create a record
- StockReturnsServiceFilterReq
- Describes the base request payload of a filter search
- StockReturnsServiceItemCreateRequest
- Describes the parameters required to add an item to a stock return
- StockReturnsServiceItemUpdateRequest
- Describes the parameters required to update an item in a stock return
- StockReturnsServicePaginatedItemsResponse
- Describes the response to a pagination items request
- StockReturnsServicePaginationReq
- Describes a pagination request to retrieve records
- StockReturnsServicePaginationResponse
- Describes the response to a pagination request
- StockReturnsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- StockReturnsServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.