sdk/stores.scailo.pb library
Classes
- Store
- Describes the parameters that are part of a standard response
- STORE_SORT_KEY
- Describes the available sort keys
- StoresList
- Describes the message consisting of the list of records
- StoresServiceCountReq
- Describes the base request payload of a count search
- StoresServiceCreateRequest
- Describes the parameters necessary to create a record
- StoresServiceFilterReq
- Describes the base request payload of a filter search
- StoresServicePaginationReq
- Describes a pagination request to retrieve records
- StoresServicePaginationResponse
- Describes the response to a pagination request
- StoresServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- StoresServiceUpdateRequest
- Describes the parameters necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.