sdk/supply_offers.scailo.pb
library
Classes
-
SUPPLY_OFFER_ITEM_SORT_KEY
-
Describes the available sort keys
-
SUPPLY_OFFER_ITEM_STATUS
-
Describes the applicable statuses of supply offer items
-
SUPPLY_OFFER_SORT_KEY
-
Describes the available sort keys
-
SupplyOffer
-
Describes the parameters that are part of a standard response
-
SupplyOfferAncillaryParameters
-
Stores the UUID references of the record
-
SupplyOfferItem
-
Describes the parameters that constitute an item associated to a supply offer
-
SupplyOfferItemHistoryRequest
-
Describes the parameters that are required to retrieve the history of the record
-
SupplyOfferItemProspectiveInfoRequest
-
Describes the parameters that are required to retrieve the info of a prospective supply offer item
-
SupplyOfferItemsList
-
Describes the message consisting of the list of supply offer items
-
SupplyOfferItemsSearchRequest
-
Describes the request payload to retrieve approved or unapproved items.
-
SupplyOffersList
-
Describes the message consisting of the list of supply offers
-
Describes the parameters necessary to perform an autofill request
-
Describes the base request payload of a count search
-
Describes the parameters necessary to create a record
-
Describes the base request payload of a filter search
-
Describes the parameters required to add an item to a supply offer
-
Describes the parameters required to update an item in a supply offer
-
Describes the response to a pagination items request
-
Describes a pagination request to retrieve records
-
Describes the response to a pagination request
-
Describes the request payload for performing a generic search operation on records
-
Describes the parameters necessary to update a record