sdk/tax_groups.scailo.pb library
Classes
- TAX_GROUP_CATEGORY
- Describes the available categories for a tax group
- TAX_GROUP_SORT_KEY
- Describes the available sort keys
- TaxGroup
- Describes the groups that are part of a standard response
- TaxGroupItem
- Describes the parameters that constitute a param associated to a tax group
- TaxGroupItemHistoryRequest
- Describes the parameters that are required to retrieve the history of the record
- TaxGroupsItemsList
- Describes the message consisting of the list of tax group params
- TaxGroupsList
- Describes the message consisting of the list of records
- TaxGroupsServiceCountReq
- Describes the base request payload of a count search
- TaxGroupsServiceCreateRequest
- Describes the groups necessary to create a record
- TaxGroupsServiceFilterReq
- Describes the base request payload of a filter search
- TaxGroupsServiceItemCreateRequest
- Describes the parameters required to add a param to a tax group
- TaxGroupsServiceItemUpdateRequest
- Describes the parameters required to update a param in a tax group
- TaxGroupsServicePaginationReq
- Describes a pagination request to retrieve records
- TaxGroupsServicePaginationResponse
- Describes the response to a pagination request
- TaxGroupsServiceSearchAllReq
- Describes the request payload for performing a generic search operation on records
- TaxGroupsServiceUpdateRequest
- Describes the groups necessary to update a record
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.