TeamsServiceClient class
Describes the common methods applicable on each team
- Annotations
-
- @GrpcServiceName.new('Scailo.TeamsService')
Constructors
-
TeamsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addTeamMember(
TeamsServiceMemberCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add a member to a team
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approveTeamMember(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve a member in a team
-
clone(
CloneRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Clone team from an existing team (denoted by the identifier)
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
TeamsServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
TeamsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
deleteTeamMember(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete a member in a team
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
TeamsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
draft(
TeamsServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
TeamsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
TeamsServiceFilterReq request, {CallOptions? options}) → ResponseFuture< TeamsList> - View all that match the given filter criteria
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
importFromCSV(
StandardFile request, {CallOptions? options}) → ResponseFuture< IdentifierUUIDsList> - Import records using a CSV file (duplicate codes will be skipped)
-
modifyTeamMember(
TeamsServiceMemberUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify a member in a team
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderTeamMembers(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder members in a team
-
repeat(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
TeamsServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
TeamsServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< TeamsList> - View all that match the given search key
-
searchMembersWithPagination(
TeamMembersSearchRequest request, {CallOptions? options}) → ResponseFuture< TeamsServicePaginatedMembersResponse> - Search through team members with pagination
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< TeamsList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< TeamsList> - View all with the given entity UUID
-
viewApprovedTeamMembers(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< TeamsMembersList> - View approved team members for given team ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Team> - View by ID
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Team> - View by UUID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< Team> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Team> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< TeamsList> - View all records with the given IDs
-
viewPaginatedApprovedTeamMembers(
TeamMembersSearchRequest request, {CallOptions? options}) → ResponseFuture< TeamsServicePaginatedMembersResponse> - View approved team members for given team ID with pagination
-
viewPaginatedUnapprovedTeamMembers(
TeamMembersSearchRequest request, {CallOptions? options}) → ResponseFuture< TeamsServicePaginatedMembersResponse> - View unapproved team members for given team ID with pagination
-
viewTeamMemberByID(
Identifier request, {CallOptions? options}) → ResponseFuture< TeamMember> - View Team Member by ID
-
viewTeamMemberHistory(
TeamMemberHistoryRequest request, {CallOptions? options}) → ResponseFuture< TeamsMembersList> - View the history of the team member
-
viewTeamsForMember(
Identifier request, {CallOptions? options}) → ResponseFuture< TeamsList> - View all the teams that the member is part of (and not the team lead)
-
viewUnapprovedTeamMembers(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< TeamsMembersList> - View unapproved team members for given team ID
-
viewWithPagination(
TeamsServicePaginationReq request, {CallOptions? options}) → ResponseFuture< TeamsServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.