sdk/users.scailo.pb library

Classes

User
Describes the parameters that are part of a standard response
USER_SORT_KEY
Describes the available sort keys
USER_TYPE
Describes the available user types
UserPrimaryInfo
Describes the message that is used internally to validate user
UsersList
Describes the message consisting of the list of records
UsersServiceCountReq
Describes the base request payload of a count search
UsersServiceCreateRequest
Describes the parameters necessary to create a record
UsersServiceFilterReq
Describes the base request payload of a filter search
UsersServicePaginationReq
Describes a pagination request to retrieve records
UsersServicePaginationResponse
Describes the response to a pagination request
UsersServiceRegisterMobileDeviceRequest
Describes the message that is required to register a user's device
UsersServiceSearchAllReq
Describes the request payload for performing a generic search operation on records
UsersServiceUpdateRequest
Describes the parameters necessary to update a record

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.