basicPayAmount property
- @TagNumber.new(56)
@description The raw volume integer representing basic salary compensation. Critical: Value must be defined in the minor unit of the currency.
@example 500000
Implementation
@$pb.TagNumber(56)
$fixnum.Int64 get basicPayAmount => $_getI64(29);
- @TagNumber.new(56)
Implementation
@$pb.TagNumber(56)
set basicPayAmount($fixnum.Int64 value) => $_setInt64(29, value);