joiningDate property
@description The formal start or contract initialization date marking when the individual officially joins the team roster.
@example "Wed Oct 25 2023"
Implementation
@$pb.TagNumber(31)
$core.String get joiningDate => $_getSZ(16);
Implementation
@$pb.TagNumber(31)
set joiningDate($core.String value) => $_setString(16, value);