password property
@description The securely salted and compiled binary representation of the user's password hash.
@example "\x24\x32\x61\x24\x31\x32\x24\x4b\x53..."
@format Byte array containing the evaluated cryptographic digest (e.g., bcrypt payload).
Implementation
@$pb.TagNumber(12)
$core.List<$core.int> get password => $_getN(3);