payrollCurrencyId property
- @TagNumber.new(55)
@optional
@description The internal identifier matching the currency context in which the user's base salary and line compensation amounts are denominated.
@example 3
@regex ^0-9+$
@format Non-negative 64-bit integer. Defaults to 0 if unassigned.
Implementation
@$pb.TagNumber(55)
$fixnum.Int64 get payrollCurrencyId => $_getI64(26);
- @TagNumber.new(55)
Implementation
@$pb.TagNumber(55)
set payrollCurrencyId($fixnum.Int64 value) => $_setInt64(26, value);