payrollGroupId property
- @TagNumber.new(53)
@optional
@description The unique internal identifier of the designated payroll distribution group used for localized batch processing and compensation disbursement.
@example 88
@regex ^0-9+$
@format Non-negative 64-bit integer. Defaults to 0 if unassigned.
Implementation
@$pb.TagNumber(53)
$fixnum.Int64 get payrollGroupId => $_getI64(24);
- @TagNumber.new(53)
Implementation
@$pb.TagNumber(53)
set payrollGroupId($fixnum.Int64 value) => $_setInt64(24, value);