joiningDate property
@optional
@description The formal start or contract initialization date marking when the individual officially joins the team roster.
@example "Wed Oct 25 2023"
@regex .*
@format Must follow the specific string syntax format: Day Month Date Year.
Implementation
@$pb.TagNumber(31)
$core.String get joiningDate => $_getSZ(12);
Implementation
@$pb.TagNumber(31)
set joiningDate($core.String value) => $_setString(12, value);