UsersServiceClient class
Describes the common methods applicable on each user
- Annotations
-
- @GrpcServiceName.new('Scailo.UsersService')
Constructors
-
UsersServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
count(
UsersServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
UsersServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
createMagicLinkForSignature(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Create a magic link that allows user to upload their signature
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
UsersServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
draft(
UsersServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
UsersServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
UsersServiceFilterReq request, {CallOptions? options}) → ResponseFuture< UsersList> - View all that match the given filter criteria
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
identifyCroppedFace(
StandardFile request, {CallOptions? options}) → ResponseFuture< User> - View user info on the basis of the provided image. The image should consist of only the user's face. Will return an error if the image has not been recognized.
-
identifyFullFace(
StandardFile request, {CallOptions? options}) → ResponseFuture< User> - View user info on the basis of the provided image. The image should consist of just the user (might be a full sized photo). The face will be cropped. Will return an error if the image has not been recognized.
-
importFromCSV(
StandardFile request, {CallOptions? options}) → ResponseFuture< IdentifierUUIDsList> - Import records using a CSV file (duplicate codes will be skipped)
-
mFAEnable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ImageResponse> - Enable MFA for user
-
mFAReset(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reset MFA for user
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerMobileDevice(
UsersServiceRegisterMobileDeviceRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Register user's mobile device for push notifications. Returns the ID of the user device record
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
UsersServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
UsersServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< UsersList> - View all that match the given search key
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
updateOwnPassword(
UpdateOwnPasswordReq request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update user's own password
-
updatePassword(
UpdatePasswordReq request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update user's password by another user (such as an administrator)
-
updateProfilePicture(
UploadPictureReq request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update the user's profile picture
-
updateSignature(
UploadPictureReq request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update the user's signature
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< UsersList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< UsersList> - View all with the given entity UUID
-
viewBirthdaysOn(
MonthAndDayFilter request, {CallOptions? options}) → ResponseFuture< UsersList> - View all users with birthdays on the given date
-
viewByCode(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< User> - View by user's code (logs aren't returned)
-
viewByID(
IdentifierZeroable request, {CallOptions? options}) → ResponseFuture< User> - View by ID (returns the entire information about the user, including the logs)
-
viewByUsername(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< User> - View by username (logs aren't returned)
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< User> - View by UUID (logs aren't returned)
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< User> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< User> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< UsersList> - View all users with the given IDs
-
viewFromUsernames(
StringsList request, {CallOptions? options}) → ResponseFuture< UsersList> - View all users with the given usernames
-
viewFromUUIDs(
IdentifierUUIDsList request, {CallOptions? options}) → ResponseFuture< UsersList> - View all users with the given UUIDs
-
viewProfilePicture(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ImageResponse> - View user's profile picture
-
viewQRImage(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ImageResponse> - View user's QR Code as image
-
viewQRString(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StringResponse> - View user's QR Code as string
-
viewSelf(
Empty request, {CallOptions? options}) → ResponseFuture< User> - View self user (the profile of the logged in user)
-
viewSignature(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< Base64String> - View user's signature
-
viewThumbnailPicture(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ImageResponse> - View user's thumbnail picture
-
viewVCard(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< ImageResponse> - View user's VCard
-
viewWithPagination(
UsersServicePaginationReq request, {CallOptions? options}) → ResponseFuture< UsersServicePaginationResponse> - View with pagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.