create method
ResponseFuture<IdentifierResponse>
create(
- UsersServiceCreateRequest request, {
- CallOptions? options,
Creates a new user and initiates the verification workflow.
This method validates all required fields.
The user record is created with a STANDARD_LIFECYCLE_STATUS.PREVERIFY status.
Side Effects:
- Generates a unique system UUID.
- Records an audit log for the "Create" action.
Errors: // - ALREADY_EXISTS: If the username, code, or email is already taken.
INVALID_ARGUMENT: If validation rules (e.g.,buf.validate) fail.
Implementation
$grpc.ResponseFuture<$1.IdentifierResponse> create(
$0.UsersServiceCreateRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$create, request, options: options);
}