updateOwnPassword method
ResponseFuture<IdentifierResponse>
updateOwnPassword(
- UpdateOwnPasswordReq request, {
- CallOptions? options,
Allows the currently authenticated user to update their own account password.
This method strictly enforces a check against the user's current password to prevent hijacking.
Side Effects:
- Updates the password hash in the secure identity vault.
- Revokes all other active login tokens/sessions except for the current operational session.
Errors:
INVALID_ARGUMENT: If the new password fails system complexity guidelines.
Implementation
$grpc.ResponseFuture<$1.IdentifierResponse> updateOwnPassword(
$1.UpdateOwnPasswordReq request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$updateOwnPassword, request, options: options);
}