sdk/vault_commons.scailo.pb library
Classes
- ENCLAVE_DOMAIN_SORT_KEY
- Describes the available sort keys for enclave domains
- EnclaveDomain
- Denotes an individual domain that is part of an enclave
- EnclaveDomainAddRequest
- Stores the payload that is necessary to create a custom domain for an enclave
- EnclaveDomainsFilterReq
- Describes the request payload of a enclave domains filter search
- EnclaveDomainsList
- Denotes the list of domains that are part of an enclave
- EnclaveDomainSuffixResp
- The response that contains the default domain suffix that is used for creating enclave domains
- EnclaveEnvironmentVariable
- Denotes an individual environment variable that is part of an enclave
- EnclaveEnvironmentVariableAddRequest
- Stores the payload that is necessary to create a custom environment variable for an enclave
- EnclaveEnvironmentVariablesList
- Denotes the list of environment variables that are part of an enclave
- EnclaveEnvironmentVariableUpdateRequest
- Stores the payload that is necessary to update a custom environment variable for an enclave
- EnclaveIngress
- Describes the parameters that are a part of each enclave ingress
- EnclaveIngressCountReq
- Describes the request payload of a count filter for enclave runs
- EnclaveIngressesList
- Describes the message consisting of the list of enclave ingresses
- EnclaveIngressFilterReq
- Describes the base request payload of a filter search for enclave runs
- EnclaveManifest
- Describes the manifest file of an Enclave. Stores the attributes that can be a part of the MANIFEST.yaml file, that is present in the root folder of an Enclave
- EnclaveManifestEnvVariable
- Describes each environment variable that is defined in the Manifest of an Enclave
- EnclaveResources
- Describes the resources section of an Enclave
- GiXAppRun
- Describes the parameters that are a part of each vault app execution (GiX app execution)
- GiXAppRunCountReq
- Describes the request payload of a count filter for app runs
- GiXAppRunFilterReq
- Describes the base request payload of a filter search for gix app runs
- GiXAppRunsList
- Describes the message consisting of the list of gix app runs
- GiXManifest
- Describes the manifest file of a GiX app. Stores the attributes that can be a part of the MANIFEST.yaml file, that is present in the root folder of a GiX app
- GixResources
- Describes the resources section of a GiX app
- VAULT_ACCESS_LOG_OPERATION
- Describes the available access log operations
- VAULT_PERMISSION_CODE
- Describes the available permission codes
- VAULT_REF_FOR
- Describes the available references for permissions
- VAULT_SORT_KEY
- Describes the available sort keys
- VaultAccessLog
- Describes the access log of every file or folder
- VaultAccessLogCreateRequest
- Describes the necessary parameters to create an access log
- VaultAccessLogsList
- Describes the message consisting of the list of access logs
- VaultDuplicateCheckReq
- Describes the message to test if the file or folder already exists in the given folder UUID
- VaultPermission
- Describes the parameters of a permission related to a vault file or folder
- VaultPermissionAddRequest
- Describes the parameters required to create a vault permission
- VaultPermissionModifyRequest
- Describes the parameters required to modify a vault permission
- VaultSearchReq
- VaultSearchResponse
- Describes the search information of vault files and folders into a single message
- VaultSearchResponsesList
- Describes the message consisting of the list of vault search response
- VerifyEnclaveIngressRequest
- The request payload to verify an enclave ingress
- VerifyEnclaveIngressResponse
- The response payload to verify an enclave ingress
Extensions
- GeneratedMessageGenericExtensions on T
-
Extensions on
GeneratedMessages.