isSecret property
Denotes if the value should be stored as a secret (will not be visible to the user post creation)
Implementation
@$pb.TagNumber(13)
$core.bool get isSecret => $_getBF(3);
Implementation
@$pb.TagNumber(13)
set isSecret($core.bool value) => $_setBool(3, value);