sdk/vendors.scailo.pb
library
Classes
-
Vendor
-
Describes the parameters that are part of a standard response
-
VENDOR_ITEM_PRICE_DEVIATION_LIMIT_TYPE
-
Describes the price deviation limit type for an item associated to a vendor
-
VENDOR_ITEM_SORT_KEY
-
Describes the available sort keys
-
VENDOR_ITEM_STATUS
-
Describes the applicable statuses of vendor items
-
VENDOR_SORT_KEY
-
Describes the available sort keys
-
VENDOR_USER_STATUS
-
Describes the applicable statuses of vendor users
-
VendorItem
-
Describes the parameters that constitute an item associated to a vendor
-
VendorItemHistoryRequest
-
Describes the parameters that are required to retrieve the history of the record
-
VendorItemRequired
-
Describes the vendor item that also stores the quantity that is required
-
VendorItemsList
-
Describes the message consisting of the list of vendor items
-
VendorItemsSearchRequest
-
Describes the request payload to retrieve approved or unapproved items.
-
VendorsList
-
Describes the message consisting of the list of vendors
-
Describes the base request payload of a count search
-
Describes the parameters necessary to create a record
-
Describes the base request payload of a filter search
-
Describes the parameters required to add an item to a vendor
-
Describes the parameters required to update an item in a vendor
-
Describes the response to a pagination items request
-
Describes the response to a pagination items request for items with applicable required quantities
-
Describes the response to a pagination items request
-
Describes a pagination request to retrieve records
-
Describes the response to a pagination request
-
Describes the request payload for performing a generic search operation on records
-
Describes the parameters necessary to update a record
-
Describes the parameters necessary to create a vendor user
-
VendorUser
-
Describes the parameters that constitute a vendor user
-
VendorUsersList
-
Describes the message consisting of the list of vendor users
-
Describes the request payload to search vendor users