WorkOrdersServiceClient class
Describes the common methods applicable on each work order
- Annotations
-
- @GrpcServiceName.new('Scailo.WorkOrdersService')
Constructors
-
WorkOrdersServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
addWorkOrderItem(
WorkOrdersServiceItemCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add an item to a work order
-
amend(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Amend the work order and send for revision
-
approve(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve
-
approveWorkOrderItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Approve an item in a work order
-
autofill(
WorkOrdersServiceAutofillRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Autofill the work order
-
commentAdd(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Add comment
-
complete(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Complete
-
count(
WorkOrdersServiceCountReq request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count all that match the given criteria
-
countInStatus(
CountInSLCStatusRequest request, {CallOptions? options}) → ResponseFuture< CountResponse> - Count in status
-
create(
WorkOrdersServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and send for verification
-
createMagicLink(
MagicLinksServiceCreateRequestForSpecificResource request, {CallOptions? options}) → ResponseFuture< MagicLink> - Create a magic link
-
deleteWorkOrderItem(
IdentifierWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Delete an item in a work order
-
discard(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Discard
-
downloadAsCSV(
WorkOrdersServiceFilterReq request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file that consists of the list of records according to the given filter request. The same file could also be used as a template for uploading records
-
downloadByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download work order with the given IdentifierUUID (can be used to allow public downloads)
-
downloadItemsAsCSV(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< StandardFile> - CSV operations Download the CSV file with the associated line items. The same file could then be used to upload line items.
-
downloadItemsTemplateAsCSV(
Empty request, {CallOptions? options}) → ResponseFuture< StandardFile> - Download the CSV template that could be used to upload items
-
draft(
WorkOrdersServiceCreateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Create and save as draft
-
draftUpdate(
WorkOrdersServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update draft
-
filter(
WorkOrdersServiceFilterReq request, {CallOptions? options}) → ResponseFuture< WorkOrdersList> - View all that match the given filter criteria
-
filterProspectiveFamilies(
FilterFamiliesReqForIdentifier request, {CallOptions? options}) → ResponseFuture< FamiliesList> - Filter prospective families for the record represented by the given UUID identifier
-
halt(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Halt
-
isCompletable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the Work Order can be marked as completed
-
isDownloadable(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< BooleanResponse> - Checks if the record is downloadable (checks if the custom download function has been implemented)
-
modifyWorkOrderItem(
WorkOrdersServiceItemUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Modify an item in a work order
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reopen(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reopen
-
reorderWorkOrderItems(
ReorderItemsRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Reorder items in a work order
-
repeat(
RepeatWithDeliveryDate request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Repeat
-
restore(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Restore
-
revisionUpdate(
WorkOrdersServiceUpdateRequest request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Update revision
-
searchAll(
WorkOrdersServiceSearchAllReq request, {CallOptions? options}) → ResponseFuture< WorkOrdersList> - View all that match the given search key
-
searchItemsWithPagination(
WorkOrderItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< WorkOrdersServicePaginatedItemsResponse> - Search through work order items with pagination
-
sendEmail(
IdentifierWithEmailAttributes request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send Email
-
sendForRevision(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send For Revision
-
sendForVerification(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Send for verification
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadWorkOrderItems(
IdentifierUUIDWithFile request, {CallOptions? options}) → ResponseFuture< IdentifiersList> - Upload items using a CSV file. This is an idempotent operation. All the existing items are deleted before adding the items from the file.
-
verify(
IdentifierUUIDWithUserComment request, {CallOptions? options}) → ResponseFuture< IdentifierResponse> - Verify
-
viewAll(
ActiveStatus request, {CallOptions? options}) → ResponseFuture< WorkOrdersList> - View all
-
viewAllForEntityUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< WorkOrdersList> - View all with the given entity UUID
-
viewAmendments(
Identifier request, {CallOptions? options}) → ResponseFuture< AmendmentLogsList> - View all the amendments made
-
viewAncillaryParametersByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< WorkOrderAncillaryParameters> - View the ancillary parameters (UUIDs of the internal references) by UUID
-
viewApprovedWorkOrderItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< WorkOrdersItemsList> - View approved work order items for given work order ID
-
viewByID(
Identifier request, {CallOptions? options}) → ResponseFuture< WorkOrder> - View by ID
-
viewByReferenceID(
SimpleSearchReq request, {CallOptions? options}) → ResponseFuture< WorkOrder> - View by Reference ID (returns the latest record in case of duplicates)
-
viewByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< WorkOrder> - View by UUID
-
viewEssentialByID(
Identifier request, {CallOptions? options}) → ResponseFuture< WorkOrder> - View only essential components by ID (without logs)
-
viewEssentialByUUID(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< WorkOrder> - View only essential components (without logs) that matches the given UUID
-
viewFromIDs(
IdentifiersList request, {CallOptions? options}) → ResponseFuture< WorkOrdersList> - View all records with the given IDs
-
viewPaginatedApprovedWorkOrderItems(
WorkOrderItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< WorkOrdersServicePaginatedItemsResponse> - View approved work order items for given work order ID with pagination
-
viewPaginatedUnapprovedWorkOrderItems(
WorkOrderItemsSearchRequest request, {CallOptions? options}) → ResponseFuture< WorkOrdersServicePaginatedItemsResponse> - View unapproved work order items for given work order ID with pagination
-
viewProductionStatistics(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< WorkOrderProductionStatisticsList> - View production statistics (match with all the associated production plans) of the work order
-
viewProspectiveFamilies(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< FamiliesList> - View prospective families for the given work order
-
viewProspectiveWorkOrderItem(
WorkOrderItemProspectiveInfoRequest request, {CallOptions? options}) → ResponseFuture< WorkOrdersServiceItemCreateRequest> - View prospective work order item info for the given family ID and work order ID
-
viewRequirementStatistics(
IdentifierUUID request, {CallOptions? options}) → ResponseFuture< WorkOrderRequirementStatisticsList> - View requirement statistics (match with the selected sales order) of the work order
-
viewUnapprovedWorkOrderItems(
IdentifierWithSearchKey request, {CallOptions? options}) → ResponseFuture< WorkOrdersItemsList> - View unapproved work order items for given work order ID
-
viewWithPagination(
WorkOrdersServicePaginationReq request, {CallOptions? options}) → ResponseFuture< WorkOrdersServicePaginationResponse> - View with pagination
-
viewWorkOrderItemByID(
Identifier request, {CallOptions? options}) → ResponseFuture< WorkOrderItem> - View Work Order Item by ID
-
viewWorkOrderItemHistory(
WorkOrderItemHistoryRequest request, {CallOptions? options}) → ResponseFuture< WorkOrdersItemsList> - View the history of the work order item
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.